@@ -1,34 +1,10 @@
-*> \brief \b LSAMETST
+      PROGRAM TEST1
 *
-*  =========== DOCUMENTATION ===========
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     February 29, 1992 
 *
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*      PROGRAM LSAMETST
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup auxOTHERauxiliary
-*
-*  =====================================================================      PROGRAM LSAMETST
-*
-*  -- LAPACK test routine --
-*
-*  -- LAPACK computational routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*
-*  =====================================================================
 *     .. Local Scalars ..
       INTEGER            I1, I2
 *     ..
@@ -54,13 +30,13 @@
 *
 *     Test LSAME.
 *
-      IF( .NOT. LSAME( 'A', 'A' ) )
+      IF( .NOT.LSAME( 'A', 'A' ) )
      $   WRITE( *, 9999 )'A', 'A'
-      IF( .NOT. LSAME( 'A', 'a' ) )
+      IF( .NOT.LSAME( 'A', 'a' ) )
      $   WRITE( *, 9999 )'A', 'a'
-      IF( .NOT. LSAME( 'a', 'A' ) )
+      IF( .NOT.LSAME( 'a', 'A' ) )
      $   WRITE( *, 9999 )'a', 'A'
-      IF( .NOT. LSAME( 'a', 'a' ) )
+      IF( .NOT.LSAME( 'a', 'a' ) )
      $   WRITE( *, 9999 )'a', 'a'
       IF( LSAME( 'A', 'B' ) )
      $   WRITE( *, 9998 )'A', 'B'
