@@ -1,186 +1,10 @@
-*> \brief \b CLALSD uses the singular value decomposition of A to solve the least squares problem.
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*> \htmlonly
-*> Download CLALSD + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/clalsd.f">
-*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/clalsd.f">
-*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/clalsd.f">
-*> [TXT]</a>
-*> \endhtmlonly
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE CLALSD( UPLO, SMLSIZ, N, NRHS, D, E, B, LDB, RCOND,
-*                          RANK, WORK, RWORK, IWORK, INFO )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER          UPLO
-*       INTEGER            INFO, LDB, N, NRHS, RANK, SMLSIZ
-*       REAL               RCOND
-*       ..
-*       .. Array Arguments ..
-*       INTEGER            IWORK( * )
-*       REAL               D( * ), E( * ), RWORK( * )
-*       COMPLEX            B( LDB, * ), WORK( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> CLALSD uses the singular value decomposition of A to solve the least
-*> squares problem of finding X to minimize the Euclidean norm of each
-*> column of A*X-B, where A is N-by-N upper bidiagonal, and X and B
-*> are N-by-NRHS. The solution X overwrites B.
-*>
-*> The singular values of A smaller than RCOND times the largest
-*> singular value are treated as zero in solving the least squares
-*> problem; in this case a minimum norm solution is returned.
-*> The actual singular values are returned in D in ascending order.
-*>
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] UPLO
-*> \verbatim
-*>          UPLO is CHARACTER*1
-*>         = 'U': D and E define an upper bidiagonal matrix.
-*>         = 'L': D and E define a  lower bidiagonal matrix.
-*> \endverbatim
-*>
-*> \param[in] SMLSIZ
-*> \verbatim
-*>          SMLSIZ is INTEGER
-*>         The maximum size of the subproblems at the bottom of the
-*>         computation tree.
-*> \endverbatim
-*>
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>         The dimension of the  bidiagonal matrix.  N >= 0.
-*> \endverbatim
-*>
-*> \param[in] NRHS
-*> \verbatim
-*>          NRHS is INTEGER
-*>         The number of columns of B. NRHS must be at least 1.
-*> \endverbatim
-*>
-*> \param[in,out] D
-*> \verbatim
-*>          D is REAL array, dimension (N)
-*>         On entry D contains the main diagonal of the bidiagonal
-*>         matrix. On exit, if INFO = 0, D contains its singular values.
-*> \endverbatim
-*>
-*> \param[in,out] E
-*> \verbatim
-*>          E is REAL array, dimension (N-1)
-*>         Contains the super-diagonal entries of the bidiagonal matrix.
-*>         On exit, E has been destroyed.
-*> \endverbatim
-*>
-*> \param[in,out] B
-*> \verbatim
-*>          B is COMPLEX array, dimension (LDB,NRHS)
-*>         On input, B contains the right hand sides of the least
-*>         squares problem. On output, B contains the solution X.
-*> \endverbatim
-*>
-*> \param[in] LDB
-*> \verbatim
-*>          LDB is INTEGER
-*>         The leading dimension of B in the calling subprogram.
-*>         LDB must be at least max(1,N).
-*> \endverbatim
-*>
-*> \param[in] RCOND
-*> \verbatim
-*>          RCOND is REAL
-*>         The singular values of A less than or equal to RCOND times
-*>         the largest singular value are treated as zero in solving
-*>         the least squares problem. If RCOND is negative,
-*>         machine precision is used instead.
-*>         For example, if diag(S)*X=B were the least squares problem,
-*>         where diag(S) is a diagonal matrix of singular values, the
-*>         solution would be X(i) = B(i) / S(i) if S(i) is greater than
-*>         RCOND*max(S), and X(i) = 0 if S(i) is less than or equal to
-*>         RCOND*max(S).
-*> \endverbatim
-*>
-*> \param[out] RANK
-*> \verbatim
-*>          RANK is INTEGER
-*>         The number of singular values of A greater than RCOND times
-*>         the largest singular value.
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX array, dimension (N * NRHS).
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is REAL array, dimension at least
-*>         (9*N + 2*N*SMLSIZ + 8*N*NLVL + 3*SMLSIZ*NRHS +
-*>         MAX( (SMLSIZ+1)**2, N*(1+NRHS) + 2*NRHS ),
-*>         where
-*>         NLVL = MAX( 0, INT( LOG_2( MIN( M,N )/(SMLSIZ+1) ) ) + 1 )
-*> \endverbatim
-*>
-*> \param[out] IWORK
-*> \verbatim
-*>          IWORK is INTEGER array, dimension (3*N*NLVL + 11*N).
-*> \endverbatim
-*>
-*> \param[out] INFO
-*> \verbatim
-*>          INFO is INTEGER
-*>         = 0:  successful exit.
-*>         < 0:  if INFO = -i, the i-th argument had an illegal value.
-*>         > 0:  The algorithm failed to compute a singular value while
-*>               working on the submatrix lying in rows and columns
-*>               INFO/(N+1) through MOD(INFO,N+1).
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup lalsd
-*
-*> \par Contributors:
-*  ==================
-*>
-*>     Ming Gu and Ren-Cang Li, Computer Science Division, University of
-*>       California at Berkeley, USA \n
-*>     Osni Marques, LBNL/NERSC, USA \n
-*
-*  =====================================================================
       SUBROUTINE CLALSD( UPLO, SMLSIZ, N, NRHS, D, E, B, LDB, RCOND,
      $                   RANK, WORK, RWORK, IWORK, INFO )
 *
-*  -- LAPACK computational routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -193,6 +17,99 @@
       COMPLEX            B( LDB, * ), WORK( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  CLALSD uses the singular value decomposition of A to solve the least
+*  squares problem of finding X to minimize the Euclidean norm of each
+*  column of A*X-B, where A is N-by-N upper bidiagonal, and X and B
+*  are N-by-NRHS. The solution X overwrites B.
+*
+*  The singular values of A smaller than RCOND times the largest
+*  singular value are treated as zero in solving the least squares
+*  problem; in this case a minimum norm solution is returned.
+*  The actual singular values are returned in D in ascending order.
+*
+*  This code makes very mild assumptions about floating point
+*  arithmetic. It will work on machines with a guard digit in
+*  add/subtract, or on those binary machines without guard digits
+*  which subtract like the Cray XMP, Cray YMP, Cray C 90, or Cray 2.
+*  It could conceivably fail on hexadecimal or decimal machines
+*  without guard digits, but we know of none.
+*
+*  Arguments
+*  =========
+*
+*  UPLO   (input) CHARACTER*1
+*         = 'U': D and E define an upper bidiagonal matrix.
+*         = 'L': D and E define a  lower bidiagonal matrix.
+*
+*  SMLSIZ (input) INTEGER
+*         The maximum size of the subproblems at the bottom of the
+*         computation tree.
+*
+*  N      (input) INTEGER
+*         The dimension of the  bidiagonal matrix.  N >= 0.
+*
+*  NRHS   (input) INTEGER
+*         The number of columns of B. NRHS must be at least 1.
+*
+*  D      (input/output) REAL array, dimension (N)
+*         On entry D contains the main diagonal of the bidiagonal
+*         matrix. On exit, if INFO = 0, D contains its singular values.
+*
+*  E      (input) REAL array, dimension (N-1)
+*         Contains the super-diagonal entries of the bidiagonal matrix.
+*         On exit, E has been destroyed.
+*
+*  B      (input/output) COMPLEX array, dimension (LDB,NRHS)
+*         On input, B contains the right hand sides of the least
+*         squares problem. On output, B contains the solution X.
+*
+*  LDB    (input) INTEGER
+*         The leading dimension of B in the calling subprogram.
+*         LDB must be at least max(1,N).
+*
+*  RCOND  (input) REAL
+*         The singular values of A less than or equal to RCOND times
+*         the largest singular value are treated as zero in solving
+*         the least squares problem. If RCOND is negative,
+*         machine precision is used instead.
+*         For example, if diag(S)*X=B were the least squares problem,
+*         where diag(S) is a diagonal matrix of singular values, the
+*         solution would be X(i) = B(i) / S(i) if S(i) is greater than
+*         RCOND*max(S), and X(i) = 0 if S(i) is less than or equal to
+*         RCOND*max(S).
+*
+*  RANK   (output) INTEGER
+*         The number of singular values of A greater than RCOND times
+*         the largest singular value.
+*
+*  WORK   (workspace) COMPLEX array, dimension at least
+*         (N * NRHS).
+*
+*  RWORK  (workspace) REAL array, dimension at least
+*         (2 * N + 2 * N * SMLSIZ + 8 * N * NLVL + MAX( SMLSIZ*NRHS*3,
+*         6*N ) ), where NLVL = INT(log_2 (N/(SMLSIZ+1))) + 1.
+*
+*  IWORK  (workspace) INTEGER array, dimension at least
+*         (3 * N * NLVL + 11 * N).
+*
+*  INFO   (output) INTEGER
+*         = 0:  successful exit.
+*         < 0:  if INFO = -i, the i-th argument had an illegal value.
+*         > 0:  The algorithm failed to compute an singular value while
+*               working on the submatrix lying in rows and columns
+*               INFO/(N+1) through MOD(INFO,N+1).
+*
+*  Further Details
+*  ===============
+*
+*  Based on contributions by
+*     Ming Gu and Ren-Cang Li, Computer Science Division, University of
+*       California at Berkeley, USA
+*     Osni Marques, LBNL/NERSC, USA
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -208,7 +125,7 @@
      $                   JREAL, JROW, K, NLVL, NM1, NRWORK, NSIZE, NSUB,
      $                   PERM, POLES, S, SIZEI, SMLSZP, SQRE, ST, ST1,
      $                   U, VT, Z
-      REAL               CS, EPS, ORGNRM, R, RCND, SN, TOL
+      REAL               CS, EPS, ORGNRM, R, SN, TOL
 *     ..
 *     .. External Functions ..
       INTEGER            ISAMAX
@@ -216,8 +133,7 @@
       EXTERNAL           ISAMAX, SLAMCH, SLANST
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CCOPY, CLACPY, CLALSA, CLASCL, CLASET,
-     $                   CSROT,
+      EXTERNAL           CCOPY, CLACPY, CLALSA, CLASCL, CLASET, CSROT,
      $                   SGEMM, SLARTG, SLASCL, SLASDA, SLASDQ, SLASET,
      $                   SLASRT, XERBLA
 *     ..
@@ -247,9 +163,7 @@
 *     Set up the tolerance.
 *
       IF( ( RCOND.LE.ZERO ) .OR. ( RCOND.GE.ONE ) ) THEN
-         RCND = EPS
-      ELSE
-         RCND = RCOND
+         RCOND = EPS
       END IF
 *
       RANK = 0
@@ -263,8 +177,7 @@
             CALL CLASET( 'A', 1, NRHS, CZERO, CZERO, B, LDB )
          ELSE
             RANK = 1
-            CALL CLASCL( 'G', 0, 0, D( 1 ), ONE, 1, NRHS, B, LDB,
-     $                   INFO )
+            CALL CLASCL( 'G', 0, 0, D( 1 ), ONE, 1, NRHS, B, LDB, INFO )
             D( 1 ) = ABS( D( 1 ) )
          END IF
          RETURN
@@ -290,8 +203,7 @@
                DO 20 J = 1, N - 1
                   CS = RWORK( J*2-1 )
                   SN = RWORK( J*2 )
-                  CALL CSROT( 1, B( J, I ), 1, B( J+1, I ), 1, CS,
-     $                        SN )
+                  CALL CSROT( 1, B( J, I ), 1, B( J+1, I ), 1, CS, SN )
    20          CONTINUE
    30       CONTINUE
          END IF
@@ -329,7 +241,7 @@
          END IF
 *
 *        In the real version, B is passed to SLASDQ and multiplied
-*        internally by Q**H. Here B is complex and that product is
+*        internally by Q'. Here B is complex and that product is
 *        computed below in two steps (real and imaginary parts).
 *
          J = IRWB - 1
@@ -360,14 +272,12 @@
    80       CONTINUE
    90    CONTINUE
 *
-         TOL = RCND*ABS( D( ISAMAX( N, D, 1 ) ) )
+         TOL = RCOND*ABS( D( ISAMAX( N, D, 1 ) ) )
          DO 100 I = 1, N
             IF( D( I ).LE.TOL ) THEN
-               CALL CLASET( 'A', 1, NRHS, CZERO, CZERO, B( I, 1 ),
-     $                      LDB )
+               CALL CLASET( 'A', 1, NRHS, CZERO, CZERO, B( I, 1 ), LDB )
             ELSE
-               CALL CLASCL( 'G', 0, 0, D( I ), ONE, 1, NRHS, B( I,
-     $                      1 ),
+               CALL CLASCL( 'G', 0, 0, D( I ), ONE, 1, NRHS, B( I, 1 ),
      $                      LDB, INFO )
                RANK = RANK + 1
             END IF
@@ -375,7 +285,7 @@
 *
 *        Since B is complex, the following call to SGEMM is performed
 *        in two steps (real and imaginary parts). That is for V * B
-*        (in the real version of the code V**H is stored in WORK).
+*        (in the real version of the code V' is stored in WORK).
 *
 *        CALL SGEMM( 'T', 'N', N, NRHS, N, ONE, WORK, N, B, LDB, ZERO,
 *    $               WORK( NWORK ), N )
@@ -411,7 +321,6 @@
 *        Unscale.
 *
          CALL SLASCL( 'G', 0, 0, ONE, ORGNRM, N, 1, D, N, INFO )
-         CALL SLASRT( 'D', N, D, INFO )
          CALL CLASCL( 'G', 0, 0, ORGNRM, ONE, N, NRHS, B, LDB, INFO )
 *
          RETURN
@@ -515,7 +424,7 @@
                END IF
 *
 *              In the real version, B is passed to SLASDQ and multiplied
-*              internally by Q**H. Here B is complex and that product is
+*              internally by Q'. Here B is complex and that product is
 *              computed below in two steps (real and imaginary parts).
 *
                J = IRWB - 1
@@ -587,7 +496,7 @@
 *
 *     Apply the singular values and treat the tiny ones as zero.
 *
-      TOL = RCND*ABS( D( ISAMAX( N, D, 1 ) ) )
+      TOL = RCOND*ABS( D( ISAMAX( N, D, 1 ) ) )
 *
       DO 250 I = 1, N
 *
@@ -595,8 +504,7 @@
 *        subproblems were not solved explicitly.
 *
          IF( ABS( D( I ) ).LE.TOL ) THEN
-            CALL CLASET( 'A', 1, NRHS, CZERO, CZERO, WORK( BX+I-1 ),
-     $                   N )
+            CALL CLASET( 'A', 1, NRHS, CZERO, CZERO, WORK( BX+I-1 ), N )
          ELSE
             RANK = RANK + 1
             CALL CLASCL( 'G', 0, 0, D( I ), ONE, 1, NRHS,
@@ -659,8 +567,7 @@
   300          CONTINUE
   310       CONTINUE
          ELSE
-            CALL CLALSA( ICMPQ2, SMLSIZ, NSIZE, NRHS, WORK( BXST ),
-     $                   N,
+            CALL CLALSA( ICMPQ2, SMLSIZ, NSIZE, NRHS, WORK( BXST ), N,
      $                   B( ST, 1 ), LDB, RWORK( U+ST1 ), N,
      $                   RWORK( VT+ST1 ), IWORK( K+ST1 ),
      $                   RWORK( DIFL+ST1 ), RWORK( DIFR+ST1 ),
