@@ -1,151 +1,9 @@
-*> \brief \b DLAED4 used by DSTEDC. Finds a single root of the secular equation.
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*> \htmlonly
-*> Download DLAED4 + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dlaed4.f">
-*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dlaed4.f">
-*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dlaed4.f">
-*> [TXT]</a>
-*> \endhtmlonly
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE DLAED4( N, I, D, Z, DELTA, RHO, DLAM, INFO )
-*
-*       .. Scalar Arguments ..
-*       INTEGER            I, INFO, N
-*       DOUBLE PRECISION   DLAM, RHO
-*       ..
-*       .. Array Arguments ..
-*       DOUBLE PRECISION   D( * ), DELTA( * ), Z( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> This subroutine computes the I-th updated eigenvalue of a symmetric
-*> rank-one modification to a diagonal matrix whose elements are
-*> given in the array d, and that
-*>
-*>            D(i) < D(j)  for  i < j
-*>
-*> and that RHO > 0.  This is arranged by the calling routine, and is
-*> no loss in generality.  The rank-one modified system is thus
-*>
-*>            diag( D )  +  RHO * Z * Z_transpose.
-*>
-*> where we assume the Euclidean norm of Z is 1.
-*>
-*> The method consists of approximating the rational functions in the
-*> secular equation by simpler interpolating rational functions.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>         The length of all arrays.
-*> \endverbatim
-*>
-*> \param[in] I
-*> \verbatim
-*>          I is INTEGER
-*>         The index of the eigenvalue to be computed.  1 <= I <= N.
-*> \endverbatim
-*>
-*> \param[in] D
-*> \verbatim
-*>          D is DOUBLE PRECISION array, dimension (N)
-*>         The original eigenvalues.  It is assumed that they are in
-*>         order, D(I) < D(J)  for I < J.
-*> \endverbatim
-*>
-*> \param[in] Z
-*> \verbatim
-*>          Z is DOUBLE PRECISION array, dimension (N)
-*>         The components of the updating vector.
-*> \endverbatim
-*>
-*> \param[out] DELTA
-*> \verbatim
-*>          DELTA is DOUBLE PRECISION array, dimension (N)
-*>         If N > 2, DELTA contains (D(j) - lambda_I) in its  j-th
-*>         component.  If N = 1, then DELTA(1) = 1. If N = 2, see DLAED5
-*>         for detail. The vector DELTA contains the information necessary
-*>         to construct the eigenvectors by DLAED3 and DLAED9.
-*> \endverbatim
-*>
-*> \param[in] RHO
-*> \verbatim
-*>          RHO is DOUBLE PRECISION
-*>         The scalar in the symmetric updating formula.
-*> \endverbatim
-*>
-*> \param[out] DLAM
-*> \verbatim
-*>          DLAM is DOUBLE PRECISION
-*>         The computed lambda_I, the I-th updated eigenvalue.
-*> \endverbatim
-*>
-*> \param[out] INFO
-*> \verbatim
-*>          INFO is INTEGER
-*>         = 0:  successful exit
-*>         > 0:  if INFO = 1, the updating process failed.
-*> \endverbatim
-*
-*> \par Internal Parameters:
-*  =========================
-*>
-*> \verbatim
-*>  Logical variable ORGATI (origin-at-i?) is used for distinguishing
-*>  whether D(i) or D(i+1) is treated as the origin.
-*>
-*>            ORGATI = .true.    origin at i
-*>            ORGATI = .false.   origin at i+1
-*>
-*>   Logical variable SWTCH3 (switch-for-3-poles?) is for noting
-*>   if we are working with THREE poles!
-*>
-*>   MAXIT is the maximum number of iterations allowed for each
-*>   eigenvalue.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup laed4
-*
-*> \par Contributors:
-*  ==================
-*>
-*>     Ren-Cang Li, Computer Science Division, University of California
-*>     at Berkeley, USA
-*>
-*  =====================================================================
       SUBROUTINE DLAED4( N, I, D, Z, DELTA, RHO, DLAM, INFO )
 *
-*  -- LAPACK computational routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK routine (version 3.0) --
+*     Univ. of Tennessee, Oak Ridge National Lab, Argonne National Lab,
+*     Courant Institute, NAG Ltd., and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       INTEGER            I, INFO, N
@@ -155,11 +13,84 @@
       DOUBLE PRECISION   D( * ), DELTA( * ), Z( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  This subroutine computes the I-th updated eigenvalue of a symmetric
+*  rank-one modification to a diagonal matrix whose elements are
+*  given in the array d, and that
+*
+*             D(i) < D(j)  for  i < j
+*
+*  and that RHO > 0.  This is arranged by the calling routine, and is
+*  no loss in generality.  The rank-one modified system is thus
+*
+*             diag( D )  +  RHO *  Z * Z_transpose.
+*
+*  where we assume the Euclidean norm of Z is 1.
+*
+*  The method consists of approximating the rational functions in the
+*  secular equation by simpler interpolating rational functions.
+*
+*  Arguments
+*  =========
+*
+*  N      (input) INTEGER
+*         The length of all arrays.
+*
+*  I      (input) INTEGER
+*         The index of the eigenvalue to be computed.  1 <= I <= N.
+*
+*  D      (input) DOUBLE PRECISION array, dimension (N)
+*         The original eigenvalues.  It is assumed that they are in
+*         order, D(I) < D(J)  for I < J.
+*
+*  Z      (input) DOUBLE PRECISION array, dimension (N)
+*         The components of the updating vector.
+*
+*  DELTA  (output) DOUBLE PRECISION array, dimension (N)
+*         If N .ne. 1, DELTA contains (D(j) - lambda_I) in its  j-th
+*         component.  If N = 1, then DELTA(1) = 1.  The vector DELTA
+*         contains the information necessary to construct the
+*         eigenvectors.
+*
+*  RHO    (input) DOUBLE PRECISION
+*         The scalar in the symmetric updating formula.
+*
+*  DLAM   (output) DOUBLE PRECISION
+*         The computed lambda_I, the I-th updated eigenvalue.
+*
+*  INFO   (output) INTEGER
+*         = 0:  successful exit
+*         > 0:  if INFO = 1, the updating process failed.
+*
+*  Internal Parameters
+*  ===================
+*
+*  Logical variable ORGATI (origin-at-i?) is used for distinguishing
+*  whether D(i) or D(i+1) is treated as the origin.
+*
+*            ORGATI = .true.    origin at i
+*            ORGATI = .false.   origin at i+1
+*
+*   Logical variable SWTCH3 (switch-for-3-poles?) is for noting
+*   if we are working with THREE poles!
+*
+*   MAXIT is the maximum number of iterations allowed for each
+*   eigenvalue.
+*
+*  Further Details
+*  ===============
+*
+*  Based on contributions by
+*     Ren-Cang Li, Computer Science Division, University of California
+*     at Berkeley, USA
+*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            MAXIT
-      PARAMETER          ( MAXIT = 30 )
+      PARAMETER          ( MAXIT = 20 )
       DOUBLE PRECISION   ZERO, ONE, TWO, THREE, FOUR, EIGHT, TEN
       PARAMETER          ( ZERO = 0.0D0, ONE = 1.0D0, TWO = 2.0D0,
      $                   THREE = 3.0D0, FOUR = 4.0D0, EIGHT = 8.0D0,
@@ -168,9 +99,8 @@
 *     .. Local Scalars ..
       LOGICAL            ORGATI, SWTCH, SWTCH3
       INTEGER            II, IIM1, IIP1, IP1, ITER, J, NITER
-      DOUBLE PRECISION   A, B, C, DEL, DLTLB, DLTUB, DPHI, DPSI, DW,
-     $                   EPS, ERRETM, ETA, MIDPT, PHI, PREW, PSI,
-     $                   RHOINV, TAU, TEMP, TEMP1, W
+      DOUBLE PRECISION   A, B, C, DEL, DPHI, DPSI, DW, EPS, ERRETM, ETA,
+     $                   PHI, PREW, PSI, RHOINV, TAU, TEMP, TEMP1, W
 *     ..
 *     .. Local Arrays ..
       DOUBLE PRECISION   ZZ( 3 )
@@ -183,7 +113,7 @@
       EXTERNAL           DLAED5, DLAED6
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ABS, MAX, MIN, SQRT
+      INTRINSIC          ABS, SQRT
 *     ..
 *     .. Executable Statements ..
 *
@@ -222,13 +152,13 @@
 *
 *        Calculate initial guess
 *
-         MIDPT = RHO / TWO
+         TEMP = RHO / TWO
 *
 *        If ||Z||_2 is not one, then TEMP should be set to
 *        RHO * ||Z||_2^2 / TWO
 *
          DO 10 J = 1, N
-            DELTA( J ) = ( D( J )-D( I ) ) - MIDPT
+            DELTA( J ) = ( D( J )-D( I ) ) - TEMP
    10    CONTINUE
 *
          PSI = ZERO
@@ -259,8 +189,6 @@
 *           It can be proved that
 *               D(N)+RHO/2 <= LAMBDA(N) < D(N)+TAU <= D(N)+RHO
 *
-            DLTLB = MIDPT
-            DLTUB = RHO
          ELSE
             DEL = D( N ) - D( N-1 )
             A = -C*DEL + Z( N-1 )*Z( N-1 ) + Z( N )*Z( N )
@@ -274,8 +202,6 @@
 *           It can be proved that
 *               D(N) < D(N)+TAU < LAMBDA(N) < D(N)+RHO/2
 *
-            DLTLB = ZERO
-            DLTUB = MIDPT
          END IF
 *
          DO 30 J = 1, N
@@ -311,12 +237,6 @@
             DLAM = D( I ) + TAU
             GO TO 250
          END IF
-*
-         IF( W.LE.ZERO ) THEN
-            DLTLB = MAX( DLTLB, TAU )
-         ELSE
-            DLTUB = MIN( DLTUB, TAU )
-         END IF
 *
 *        Calculate the new step
 *
@@ -328,12 +248,8 @@
          IF( C.LT.ZERO )
      $      C = ABS( C )
          IF( C.EQ.ZERO ) THEN
-*           ETA = B/A
-*           ETA = RHO - TAU
-*           ETA = DLTUB - TAU
-*
-*           Update proposed by Li, Ren-Cang:
-            ETA = -W / ( DPSI+DPHI )
+*          ETA = B/A
+            ETA = RHO - TAU
          ELSE IF( A.GE.ZERO ) THEN
             ETA = ( A+SQRT( ABS( A*A-FOUR*B*C ) ) ) / ( TWO*C )
          ELSE
@@ -349,13 +265,8 @@
          IF( W*ETA.GT.ZERO )
      $      ETA = -W / ( DPSI+DPHI )
          TEMP = TAU + ETA
-         IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
-            IF( W.LT.ZERO ) THEN
-               ETA = ( DLTUB-TAU ) / TWO
-            ELSE
-               ETA = ( DLTLB-TAU ) / TWO
-            END IF
-         END IF
+         IF( TEMP.GT.RHO )
+     $      ETA = RHO - TAU
          DO 50 J = 1, N
             DELTA( J ) = DELTA( J ) - ETA
    50    CONTINUE
@@ -397,12 +308,6 @@
                DLAM = D( I ) + TAU
                GO TO 250
             END IF
-*
-            IF( W.LE.ZERO ) THEN
-               DLTLB = MAX( DLTLB, TAU )
-            ELSE
-               DLTUB = MIN( DLTUB, TAU )
-            END IF
 *
 *           Calculate the new step
 *
@@ -425,13 +330,8 @@
             IF( W*ETA.GT.ZERO )
      $         ETA = -W / ( DPSI+DPHI )
             TEMP = TAU + ETA
-            IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
-               IF( W.LT.ZERO ) THEN
-                  ETA = ( DLTUB-TAU ) / TWO
-               ELSE
-                  ETA = ( DLTLB-TAU ) / TWO
-               END IF
-            END IF
+            IF( TEMP.LE.ZERO )
+     $         ETA = ETA / TWO
             DO 70 J = 1, N
                DELTA( J ) = DELTA( J ) - ETA
    70       CONTINUE
@@ -479,10 +379,9 @@
 *
 *        Calculate initial guess
 *
-         DEL = D( IP1 ) - D( I )
-         MIDPT = DEL / TWO
+         TEMP = ( D( IP1 )-D( I ) ) / TWO
          DO 100 J = 1, N
-            DELTA( J ) = ( D( J )-D( I ) ) - MIDPT
+            DELTA( J ) = ( D( J )-D( I ) ) - TEMP
   100    CONTINUE
 *
          PSI = ZERO
@@ -505,6 +404,7 @@
 *           We choose d(i) as origin.
 *
             ORGATI = .TRUE.
+            DEL = D( IP1 ) - D( I )
             A = C*DEL + Z( I )*Z( I ) + Z( IP1 )*Z( IP1 )
             B = Z( I )*Z( I )*DEL
             IF( A.GT.ZERO ) THEN
@@ -512,8 +412,6 @@
             ELSE
                TAU = ( A-SQRT( ABS( A*A-FOUR*B*C ) ) ) / ( TWO*C )
             END IF
-            DLTLB = ZERO
-            DLTUB = MIDPT
          ELSE
 *
 *           (d(i)+d(i+1))/2 <= the ith eigenvalue < d(i+1)
@@ -521,6 +419,7 @@
 *           We choose d(i+1) as origin.
 *
             ORGATI = .FALSE.
+            DEL = D( IP1 ) - D( I )
             A = C*DEL - Z( I )*Z( I ) - Z( IP1 )*Z( IP1 )
             B = Z( IP1 )*Z( IP1 )*DEL
             IF( A.LT.ZERO ) THEN
@@ -528,8 +427,6 @@
             ELSE
                TAU = -( A+SQRT( ABS( A*A+FOUR*B*C ) ) ) / ( TWO*C )
             END IF
-            DLTLB = -MIDPT
-            DLTUB = ZERO
          END IF
 *
          IF( ORGATI ) THEN
@@ -606,12 +503,6 @@
             END IF
             GO TO 250
          END IF
-*
-         IF( W.LE.ZERO ) THEN
-            DLTLB = MAX( DLTLB, TAU )
-         ELSE
-            DLTUB = MIN( DLTUB, TAU )
-         END IF
 *
 *        Calculate the new step
 *
@@ -681,16 +572,22 @@
          IF( W*ETA.GE.ZERO )
      $      ETA = -W / DW
          TEMP = TAU + ETA
-         IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
-            IF( W.LT.ZERO ) THEN
-               ETA = ( DLTUB-TAU ) / TWO
-            ELSE
-               ETA = ( DLTLB-TAU ) / TWO
-            END IF
+         DEL = ( D( IP1 )-D( I ) ) / TWO
+         IF( ORGATI ) THEN
+            IF( TEMP.GE.DEL )
+     $         ETA = DEL - TAU
+            IF( TEMP.LE.ZERO )
+     $         ETA = ETA / TWO
+         ELSE
+            IF( TEMP.LE.-DEL )
+     $         ETA = -DEL - TAU
+            IF( TEMP.GE.ZERO )
+     $         ETA = ETA / TWO
          END IF
 *
          PREW = W
 *
+  170    CONTINUE
          DO 180 J = 1, N
             DELTA( J ) = DELTA( J ) - ETA
   180    CONTINUE
@@ -753,12 +650,6 @@
                END IF
                GO TO 250
             END IF
-*
-            IF( W.LE.ZERO ) THEN
-               DLTLB = MAX( DLTLB, TAU )
-            ELSE
-               DLTUB = MIN( DLTUB, TAU )
-            END IF
 *
 *           Calculate the new step
 *
@@ -832,8 +723,7 @@
                      ZZ( 3 ) = Z( IIP1 )*Z( IIP1 )
                   END IF
                END IF
-               CALL DLAED6( NITER, ORGATI, C, DELTA( IIM1 ), ZZ, W,
-     $                      ETA,
+               CALL DLAED6( NITER, ORGATI, C, DELTA( IIM1 ), ZZ, W, ETA,
      $                      INFO )
                IF( INFO.NE.0 )
      $            GO TO 250
@@ -848,12 +738,17 @@
             IF( W*ETA.GE.ZERO )
      $         ETA = -W / DW
             TEMP = TAU + ETA
-            IF( TEMP.GT.DLTUB .OR. TEMP.LT.DLTLB ) THEN
-               IF( W.LT.ZERO ) THEN
-                  ETA = ( DLTUB-TAU ) / TWO
-               ELSE
-                  ETA = ( DLTLB-TAU ) / TWO
-               END IF
+            DEL = ( D( IP1 )-D( I ) ) / TWO
+            IF( ORGATI ) THEN
+               IF( TEMP.GE.DEL )
+     $            ETA = DEL - TAU
+               IF( TEMP.LE.ZERO )
+     $            ETA = ETA / TWO
+            ELSE
+               IF( TEMP.LE.-DEL )
+     $            ETA = -DEL - TAU
+               IF( TEMP.GE.ZERO )
+     $            ETA = ETA / TWO
             END IF
 *
             DO 210 J = 1, N
@@ -910,7 +805,6 @@
       END IF
 *
   250 CONTINUE
-*
       RETURN
 *
 *     End of DLAED4
