@@ -1,203 +1,9 @@
-*> \brief \b DSYTF2 computes the factorization of a real symmetric indefinite matrix, using the diagonal pivoting method (unblocked algorithm).
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*> \htmlonly
-*> Download DSYTF2 + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsytf2.f">
-*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsytf2.f">
-*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsytf2.f">
-*> [TXT]</a>
-*> \endhtmlonly
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE DSYTF2( UPLO, N, A, LDA, IPIV, INFO )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER          UPLO
-*       INTEGER            INFO, LDA, N
-*       ..
-*       .. Array Arguments ..
-*       INTEGER            IPIV( * )
-*       DOUBLE PRECISION   A( LDA, * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> DSYTF2 computes the factorization of a real symmetric matrix A using
-*> the Bunch-Kaufman diagonal pivoting method:
-*>
-*>    A = U*D*U**T  or  A = L*D*L**T
-*>
-*> where U (or L) is a product of permutation and unit upper (lower)
-*> triangular matrices, U**T is the transpose of U, and D is symmetric and
-*> block diagonal with 1-by-1 and 2-by-2 diagonal blocks.
-*>
-*> This is the unblocked version of the algorithm, calling Level 2 BLAS.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] UPLO
-*> \verbatim
-*>          UPLO is CHARACTER*1
-*>          Specifies whether the upper or lower triangular part of the
-*>          symmetric matrix A is stored:
-*>          = 'U':  Upper triangular
-*>          = 'L':  Lower triangular
-*> \endverbatim
-*>
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>          The order of the matrix A.  N >= 0.
-*> \endverbatim
-*>
-*> \param[in,out] A
-*> \verbatim
-*>          A is DOUBLE PRECISION array, dimension (LDA,N)
-*>          On entry, the symmetric matrix A.  If UPLO = 'U', the leading
-*>          n-by-n upper triangular part of A contains the upper
-*>          triangular part of the matrix A, and the strictly lower
-*>          triangular part of A is not referenced.  If UPLO = 'L', the
-*>          leading n-by-n lower triangular part of A contains the lower
-*>          triangular part of the matrix A, and the strictly upper
-*>          triangular part of A is not referenced.
-*>
-*>          On exit, the block diagonal matrix D and the multipliers used
-*>          to obtain the factor U or L (see below for further details).
-*> \endverbatim
-*>
-*> \param[in] LDA
-*> \verbatim
-*>          LDA is INTEGER
-*>          The leading dimension of the array A.  LDA >= max(1,N).
-*> \endverbatim
-*>
-*> \param[out] IPIV
-*> \verbatim
-*>          IPIV is INTEGER array, dimension (N)
-*>          Details of the interchanges and the block structure of D.
-*>
-*>          If UPLO = 'U':
-*>             If IPIV(k) > 0, then rows and columns k and IPIV(k) were
-*>             interchanged and D(k,k) is a 1-by-1 diagonal block.
-*>
-*>             If IPIV(k) = IPIV(k-1) < 0, then rows and columns
-*>             k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
-*>             is a 2-by-2 diagonal block.
-*>
-*>          If UPLO = 'L':
-*>             If IPIV(k) > 0, then rows and columns k and IPIV(k) were
-*>             interchanged and D(k,k) is a 1-by-1 diagonal block.
-*>
-*>             If IPIV(k) = IPIV(k+1) < 0, then rows and columns
-*>             k+1 and -IPIV(k) were interchanged and D(k:k+1,k:k+1)
-*>             is a 2-by-2 diagonal block.
-*> \endverbatim
-*>
-*> \param[out] INFO
-*> \verbatim
-*>          INFO is INTEGER
-*>          = 0: successful exit
-*>          < 0: if INFO = -k, the k-th argument had an illegal value
-*>          > 0: if INFO = k, D(k,k) is exactly zero.  The factorization
-*>               has been completed, but the block diagonal matrix D is
-*>               exactly singular, and division by zero will occur if it
-*>               is used to solve a system of equations.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \date December 2016
-*
-*> \ingroup doubleSYcomputational
-*
-*> \par Further Details:
-*  =====================
-*>
-*> \verbatim
-*>
-*>  If UPLO = 'U', then A = U*D*U**T, where
-*>     U = P(n)*U(n)* ... *P(k)U(k)* ...,
-*>  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
-*>  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*>  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
-*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*>
-*>             (   I    v    0   )   k-s
-*>     U(k) =  (   0    I    0   )   s
-*>             (   0    0    I   )   n-k
-*>                k-s   s   n-k
-*>
-*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
-*>  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
-*>  and A(k,k), and v overwrites A(1:k-2,k-1:k).
-*>
-*>  If UPLO = 'L', then A = L*D*L**T, where
-*>     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
-*>  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
-*>  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*>  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
-*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*>
-*>             (   I    0     0   )  k-1
-*>     L(k) =  (   0    I     0   )  s
-*>             (   0    v     I   )  n-k-s+1
-*>                k-1   s  n-k-s+1
-*>
-*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
-*>  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
-*>  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
-*> \endverbatim
-*
-*> \par Contributors:
-*  ==================
-*>
-*> \verbatim
-*>
-*>  09-29-06 - patch from
-*>    Bobby Cheng, MathWorks
-*>
-*>    Replace l.204 and l.372
-*>         IF( MAX( ABSAKK, COLMAX ).EQ.ZERO ) THEN
-*>    by
-*>         IF( (MAX( ABSAKK, COLMAX ).EQ.ZERO) .OR. DISNAN(ABSAKK) ) THEN
-*>
-*>  01-01-96 - Based on modifications by
-*>    J. Lewis, Boeing Computer Services Company
-*>    A. Petitet, Computer Science Dept., Univ. of Tenn., Knoxville, USA
-*>  1-96 - Based on modifications by J. Lewis, Boeing Computer Services
-*>         Company
-*> \endverbatim
-*
-*  =====================================================================
       SUBROUTINE DSYTF2( UPLO, N, A, LDA, IPIV, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
+*  -- LAPACK routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -208,6 +14,105 @@
       DOUBLE PRECISION   A( LDA, * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  DSYTF2 computes the factorization of a real symmetric matrix A using
+*  the Bunch-Kaufman diagonal pivoting method:
+*
+*     A = U*D*U'  or  A = L*D*L'
+*
+*  where U (or L) is a product of permutation and unit upper (lower)
+*  triangular matrices, U' is the transpose of U, and D is symmetric and
+*  block diagonal with 1-by-1 and 2-by-2 diagonal blocks.
+*
+*  This is the unblocked version of the algorithm, calling Level 2 BLAS.
+*
+*  Arguments
+*  =========
+*
+*  UPLO    (input) CHARACTER*1
+*          Specifies whether the upper or lower triangular part of the
+*          symmetric matrix A is stored:
+*          = 'U':  Upper triangular
+*          = 'L':  Lower triangular
+*
+*  N       (input) INTEGER
+*          The order of the matrix A.  N >= 0.
+*
+*  A       (input/output) DOUBLE PRECISION array, dimension (LDA,N)
+*          On entry, the symmetric matrix A.  If UPLO = 'U', the leading
+*          n-by-n upper triangular part of A contains the upper
+*          triangular part of the matrix A, and the strictly lower
+*          triangular part of A is not referenced.  If UPLO = 'L', the
+*          leading n-by-n lower triangular part of A contains the lower
+*          triangular part of the matrix A, and the strictly upper
+*          triangular part of A is not referenced.
+*
+*          On exit, the block diagonal matrix D and the multipliers used
+*          to obtain the factor U or L (see below for further details).
+*
+*  LDA     (input) INTEGER
+*          The leading dimension of the array A.  LDA >= max(1,N).
+*
+*  IPIV    (output) INTEGER array, dimension (N)
+*          Details of the interchanges and the block structure of D.
+*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were
+*          interchanged and D(k,k) is a 1-by-1 diagonal block.
+*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and
+*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
+*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =
+*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were
+*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
+*
+*  INFO    (output) INTEGER
+*          = 0: successful exit
+*          < 0: if INFO = -k, the k-th argument had an illegal value
+*          > 0: if INFO = k, D(k,k) is exactly zero.  The factorization
+*               has been completed, but the block diagonal matrix D is
+*               exactly singular, and division by zero will occur if it
+*               is used to solve a system of equations.
+*
+*  Further Details
+*  ===============
+*
+*  1-96 - Based on modifications by J. Lewis, Boeing Computer Services
+*         Company
+*
+*  If UPLO = 'U', then A = U*D*U', where
+*     U = P(n)*U(n)* ... *P(k)U(k)* ...,
+*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
+*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
+*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*
+*             (   I    v    0   )   k-s
+*     U(k) =  (   0    I    0   )   s
+*             (   0    0    I   )   n-k
+*                k-s   s   n-k
+*
+*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
+*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
+*  and A(k,k), and v overwrites A(1:k-2,k-1:k).
+*
+*  If UPLO = 'L', then A = L*D*L', where
+*     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
+*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
+*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
+*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*
+*             (   I    0     0   )  k-1
+*     L(k) =  (   0    I     0   )  s
+*             (   0    v     I   )  n-k-s+1
+*                k-1   s  n-k-s+1
+*
+*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
+*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
+*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -223,9 +128,9 @@
      $                   ROWMAX, T, WK, WKM1, WKP1
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME, DISNAN
+      LOGICAL            LSAME
       INTEGER            IDAMAX
-      EXTERNAL           LSAME, IDAMAX, DISNAN
+      EXTERNAL           LSAME, IDAMAX
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           DSCAL, DSWAP, DSYR, XERBLA
@@ -257,7 +162,7 @@
 *
       IF( UPPER ) THEN
 *
-*        Factorize A as U*D*U**T using the upper triangle of A
+*        Factorize A as U*D*U' using the upper triangle of A
 *
 *        K is the main loop index, decreasing from N to 1 in steps of
 *        1 or 2
@@ -277,8 +182,7 @@
          ABSAKK = ABS( A( K, K ) )
 *
 *        IMAX is the row-index of the largest off-diagonal element in
-*        column K, and COLMAX is its absolute value.
-*        Determine both COLMAX and IMAX.
+*        column K, and COLMAX is its absolute value
 *
          IF( K.GT.1 ) THEN
             IMAX = IDAMAX( K-1, A( 1, K ), 1 )
@@ -287,10 +191,9 @@
             COLMAX = ZERO
          END IF
 *
-         IF( (MAX( ABSAKK, COLMAX ).EQ.ZERO) .OR. DISNAN(ABSAKK) ) THEN
+         IF( MAX( ABSAKK, COLMAX ).EQ.ZERO ) THEN
 *
-*           Column K is zero or underflow, or contains a NaN:
-*           set INFO and continue
+*           Column K is zero: set INFO and continue
 *
             IF( INFO.EQ.0 )
      $         INFO = K
@@ -365,7 +268,7 @@
 *
 *              Perform a rank-1 update of A(1:k-1,1:k-1) as
 *
-*              A := A - U(k)*D(k)*U(k)**T = A - W(k)*1/D(k)*W(k)**T
+*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)'
 *
                R1 = ONE / A( K, K )
                CALL DSYR( UPLO, K-1, -R1, A( 1, K ), 1, A, LDA )
@@ -384,8 +287,8 @@
 *
 *              Perform a rank-2 update of A(1:k-2,1:k-2) as
 *
-*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )**T
-*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )**T
+*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'
+*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )'
 *
                IF( K.GT.2 ) THEN
 *
@@ -427,7 +330,7 @@
 *
       ELSE
 *
-*        Factorize A as L*D*L**T using the lower triangle of A
+*        Factorize A as L*D*L' using the lower triangle of A
 *
 *        K is the main loop index, increasing from 1 to N in steps of
 *        1 or 2
@@ -447,8 +350,7 @@
          ABSAKK = ABS( A( K, K ) )
 *
 *        IMAX is the row-index of the largest off-diagonal element in
-*        column K, and COLMAX is its absolute value.
-*        Determine both COLMAX and IMAX.
+*        column K, and COLMAX is its absolute value
 *
          IF( K.LT.N ) THEN
             IMAX = K + IDAMAX( N-K, A( K+1, K ), 1 )
@@ -457,10 +359,9 @@
             COLMAX = ZERO
          END IF
 *
-         IF( (MAX( ABSAKK, COLMAX ).EQ.ZERO) .OR. DISNAN(ABSAKK) ) THEN
+         IF( MAX( ABSAKK, COLMAX ).EQ.ZERO ) THEN
 *
-*           Column K is zero or underflow, or contains a NaN:
-*           set INFO and continue
+*           Column K is zero: set INFO and continue
 *
             IF( INFO.EQ.0 )
      $         INFO = K
@@ -538,7 +439,7 @@
 *
 *                 Perform a rank-1 update of A(k+1:n,k+1:n) as
 *
-*                 A := A - L(k)*D(k)*L(k)**T = A - W(k)*(1/D(k))*W(k)**T
+*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)'
 *
                   D11 = ONE / A( K, K )
                   CALL DSYR( UPLO, N-K, -D11, A( K+1, K ), 1,
@@ -556,7 +457,7 @@
 *
 *                 Perform a rank-2 update of A(k+2:n,k+2:n) as
 *
-*                 A := A - ( (A(k) A(k+1))*D(k)**(-1) ) * (A(k) A(k+1))**T
+*                 A := A - ( (A(k) A(k+1))*D(k)**(-1) ) * (A(k) A(k+1))'
 *
 *                 where L(k) and L(k+1) are the k-th and (k+1)-th
 *                 columns of L
