@@ -1,248 +1,10 @@
-*> \brief \b SBDSQR
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*> \htmlonly
-*> Download SBDSQR + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/sbdsqr.f">
-*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/sbdsqr.f">
-*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/sbdsqr.f">
-*> [TXT]</a>
-*> \endhtmlonly
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE SBDSQR( UPLO, N, NCVT, NRU, NCC, D, E, VT, LDVT, U,
-*                          LDU, C, LDC, WORK, INFO )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER          UPLO
-*       INTEGER            INFO, LDC, LDU, LDVT, N, NCC, NCVT, NRU
-*       ..
-*       .. Array Arguments ..
-*       REAL               C( LDC, * ), D( * ), E( * ), U( LDU, * ),
-*      $                   VT( LDVT, * ), WORK( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> SBDSQR computes the singular values and, optionally, the right and/or
-*> left singular vectors from the singular value decomposition (SVD) of
-*> a real N-by-N (upper or lower) bidiagonal matrix B using the implicit
-*> zero-shift QR algorithm.  The SVD of B has the form
-*>
-*>    B = Q * S * P**T
-*>
-*> where S is the diagonal matrix of singular values, Q is an orthogonal
-*> matrix of left singular vectors, and P is an orthogonal matrix of
-*> right singular vectors.  If left singular vectors are requested, this
-*> subroutine actually returns U*Q instead of Q, and, if right singular
-*> vectors are requested, this subroutine returns P**T*VT instead of
-*> P**T, for given real input matrices U and VT.  When U and VT are the
-*> orthogonal matrices that reduce a general matrix A to bidiagonal
-*> form:  A = U*B*VT, as computed by SGEBRD, then
-*>
-*>    A = (U*Q) * S * (P**T*VT)
-*>
-*> is the SVD of A.  Optionally, the subroutine may also compute Q**T*C
-*> for a given real input matrix C.
-*>
-*> See "Computing  Small Singular Values of Bidiagonal Matrices With
-*> Guaranteed High Relative Accuracy," by J. Demmel and W. Kahan,
-*> LAPACK Working Note #3 (or SIAM J. Sci. Statist. Comput. vol. 11,
-*> no. 5, pp. 873-912, Sept 1990) and
-*> "Accurate singular values and differential qd algorithms," by
-*> B. Parlett and V. Fernando, Technical Report CPAM-554, Mathematics
-*> Department, University of California at Berkeley, July 1992
-*> for a detailed description of the algorithm.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] UPLO
-*> \verbatim
-*>          UPLO is CHARACTER*1
-*>          = 'U':  B is upper bidiagonal;
-*>          = 'L':  B is lower bidiagonal.
-*> \endverbatim
-*>
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>          The order of the matrix B.  N >= 0.
-*> \endverbatim
-*>
-*> \param[in] NCVT
-*> \verbatim
-*>          NCVT is INTEGER
-*>          The number of columns of the matrix VT. NCVT >= 0.
-*> \endverbatim
-*>
-*> \param[in] NRU
-*> \verbatim
-*>          NRU is INTEGER
-*>          The number of rows of the matrix U. NRU >= 0.
-*> \endverbatim
-*>
-*> \param[in] NCC
-*> \verbatim
-*>          NCC is INTEGER
-*>          The number of columns of the matrix C. NCC >= 0.
-*> \endverbatim
-*>
-*> \param[in,out] D
-*> \verbatim
-*>          D is REAL array, dimension (N)
-*>          On entry, the n diagonal elements of the bidiagonal matrix B.
-*>          On exit, if INFO=0, the singular values of B in decreasing
-*>          order.
-*> \endverbatim
-*>
-*> \param[in,out] E
-*> \verbatim
-*>          E is REAL array, dimension (N-1)
-*>          On entry, the N-1 offdiagonal elements of the bidiagonal
-*>          matrix B.
-*>          On exit, if INFO = 0, E is destroyed; if INFO > 0, D and E
-*>          will contain the diagonal and superdiagonal elements of a
-*>          bidiagonal matrix orthogonally equivalent to the one given
-*>          as input.
-*> \endverbatim
-*>
-*> \param[in,out] VT
-*> \verbatim
-*>          VT is REAL array, dimension (LDVT, NCVT)
-*>          On entry, an N-by-NCVT matrix VT.
-*>          On exit, VT is overwritten by P**T * VT.
-*>          Not referenced if NCVT = 0.
-*> \endverbatim
-*>
-*> \param[in] LDVT
-*> \verbatim
-*>          LDVT is INTEGER
-*>          The leading dimension of the array VT.
-*>          LDVT >= max(1,N) if NCVT > 0; LDVT >= 1 if NCVT = 0.
-*> \endverbatim
-*>
-*> \param[in,out] U
-*> \verbatim
-*>          U is REAL array, dimension (LDU, N)
-*>          On entry, an NRU-by-N matrix U.
-*>          On exit, U is overwritten by U * Q.
-*>          Not referenced if NRU = 0.
-*> \endverbatim
-*>
-*> \param[in] LDU
-*> \verbatim
-*>          LDU is INTEGER
-*>          The leading dimension of the array U.  LDU >= max(1,NRU).
-*> \endverbatim
-*>
-*> \param[in,out] C
-*> \verbatim
-*>          C is REAL array, dimension (LDC, NCC)
-*>          On entry, an N-by-NCC matrix C.
-*>          On exit, C is overwritten by Q**T * C.
-*>          Not referenced if NCC = 0.
-*> \endverbatim
-*>
-*> \param[in] LDC
-*> \verbatim
-*>          LDC is INTEGER
-*>          The leading dimension of the array C.
-*>          LDC >= max(1,N) if NCC > 0; LDC >=1 if NCC = 0.
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is REAL array, dimension (LWORK)
-*>          LWORK = 4*N, if NCVT = NRU = NCC = 0, and
-*>          LWORK = 4*(N-1), otherwise
-*> \endverbatim
-*>
-*> \param[out] INFO
-*> \verbatim
-*>          INFO is INTEGER
-*>          = 0:  successful exit
-*>          < 0:  If INFO = -i, the i-th argument had an illegal value
-*>          > 0:
-*>             if NCVT = NRU = NCC = 0,
-*>                = 1, a split was marked by a positive value in E
-*>                = 2, current block of Z not diagonalized after 30*N
-*>                     iterations (in inner while loop)
-*>                = 3, termination criterion of outer while loop not met
-*>                     (program created more than N unreduced blocks)
-*>             else NCVT = NRU = NCC = 0,
-*>                   the algorithm did not converge; D and E contain the
-*>                   elements of a bidiagonal matrix which is orthogonally
-*>                   similar to the input matrix B;  if INFO = i, i
-*>                   elements of E have not converged to zero.
-*> \endverbatim
-*
-*> \par Internal Parameters:
-*  =========================
-*>
-*> \verbatim
-*>  TOLMUL  REAL, default = max(10,min(100,EPS**(-1/8)))
-*>          TOLMUL controls the convergence criterion of the QR loop.
-*>          If it is positive, TOLMUL*EPS is the desired relative
-*>             precision in the computed singular values.
-*>          If it is negative, abs(TOLMUL*EPS*sigma_max) is the
-*>             desired absolute accuracy in the computed singular
-*>             values (corresponds to relative accuracy
-*>             abs(TOLMUL*EPS) in the largest singular value.
-*>          abs(TOLMUL) should be between 1 and 1/EPS, and preferably
-*>             between 10 (for fast convergence) and .1/EPS
-*>             (for there to be some accuracy in the results).
-*>          Default is to lose at either one eighth or 2 of the
-*>             available decimal digits in each computed singular value
-*>             (whichever is smaller).
-*>
-*>  MAXITR  INTEGER, default = 6
-*>          MAXITR controls the maximum number of passes of the
-*>          algorithm through its inner loop. The algorithms stops
-*>          (and so fails to converge) if the number of passes
-*>          through the inner loop exceeds MAXITR*N**2.
-*> \endverbatim
-*
-*> \par Note:
-*  ===========
-*>
-*> \verbatim
-*>  Bug report from Cezary Dendek.
-*>  On March 23rd 2017, the INTEGER variable MAXIT = MAXITR*N**2 is
-*>  removed since it can overflow pretty easily (for N larger or equal
-*>  than 18,919). We instead use MAXITDIVN = MAXITR*N.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup bdsqr
-*
-*  =====================================================================
       SUBROUTINE SBDSQR( UPLO, N, NCVT, NRU, NCC, D, E, VT, LDVT, U,
      $                   LDU, C, LDC, WORK, INFO )
 *
-*  -- LAPACK computational routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -253,6 +15,122 @@
      $                   VT( LDVT, * ), WORK( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  SBDSQR computes the singular value decomposition (SVD) of a real
+*  N-by-N (upper or lower) bidiagonal matrix B:  B = Q * S * P' (P'
+*  denotes the transpose of P), where S is a diagonal matrix with
+*  non-negative diagonal elements (the singular values of B), and Q
+*  and P are orthogonal matrices.
+*
+*  The routine computes S, and optionally computes U * Q, P' * VT,
+*  or Q' * C, for given real input matrices U, VT, and C.
+*
+*  See "Computing  Small Singular Values of Bidiagonal Matrices With
+*  Guaranteed High Relative Accuracy," by J. Demmel and W. Kahan,
+*  LAPACK Working Note #3 (or SIAM J. Sci. Statist. Comput. vol. 11,
+*  no. 5, pp. 873-912, Sept 1990) and
+*  "Accurate singular values and differential qd algorithms," by
+*  B. Parlett and V. Fernando, Technical Report CPAM-554, Mathematics
+*  Department, University of California at Berkeley, July 1992
+*  for a detailed description of the algorithm.
+*
+*  Arguments
+*  =========
+*
+*  UPLO    (input) CHARACTER*1
+*          = 'U':  B is upper bidiagonal;
+*          = 'L':  B is lower bidiagonal.
+*
+*  N       (input) INTEGER
+*          The order of the matrix B.  N >= 0.
+*
+*  NCVT    (input) INTEGER
+*          The number of columns of the matrix VT. NCVT >= 0.
+*
+*  NRU     (input) INTEGER
+*          The number of rows of the matrix U. NRU >= 0.
+*
+*  NCC     (input) INTEGER
+*          The number of columns of the matrix C. NCC >= 0.
+*
+*  D       (input/output) REAL array, dimension (N)
+*          On entry, the n diagonal elements of the bidiagonal matrix B.
+*          On exit, if INFO=0, the singular values of B in decreasing
+*          order.
+*
+*  E       (input/output) REAL array, dimension (N)
+*          On entry, the elements of E contain the
+*          offdiagonal elements of the bidiagonal matrix whose SVD
+*          is desired. On normal exit (INFO = 0), E is destroyed.
+*          If the algorithm does not converge (INFO > 0), D and E
+*          will contain the diagonal and superdiagonal elements of a
+*          bidiagonal matrix orthogonally equivalent to the one given
+*          as input. E(N) is used for workspace.
+*
+*  VT      (input/output) REAL array, dimension (LDVT, NCVT)
+*          On entry, an N-by-NCVT matrix VT.
+*          On exit, VT is overwritten by P' * VT.
+*          VT is not referenced if NCVT = 0.
+*
+*  LDVT    (input) INTEGER
+*          The leading dimension of the array VT.
+*          LDVT >= max(1,N) if NCVT > 0; LDVT >= 1 if NCVT = 0.
+*
+*  U       (input/output) REAL array, dimension (LDU, N)
+*          On entry, an NRU-by-N matrix U.
+*          On exit, U is overwritten by U * Q.
+*          U is not referenced if NRU = 0.
+*
+*  LDU     (input) INTEGER
+*          The leading dimension of the array U.  LDU >= max(1,NRU).
+*
+*  C       (input/output) REAL array, dimension (LDC, NCC)
+*          On entry, an N-by-NCC matrix C.
+*          On exit, C is overwritten by Q' * C.
+*          C is not referenced if NCC = 0.
+*
+*  LDC     (input) INTEGER
+*          The leading dimension of the array C.
+*          LDC >= max(1,N) if NCC > 0; LDC >=1 if NCC = 0.
+*
+*  WORK    (workspace) REAL array, dimension
+*            2*N  if only singular values wanted (NCVT = NRU = NCC = 0)
+*            max( 1, 4*N-4 ) otherwise
+*
+*  INFO    (output) INTEGER
+*          = 0:  successful exit
+*          < 0:  If INFO = -i, the i-th argument had an illegal value
+*          > 0:  the algorithm did not converge; D and E contain the
+*                elements of a bidiagonal matrix which is orthogonally
+*                similar to the input matrix B;  if INFO = i, i
+*                elements of E have not converged to zero.
+*
+*  Internal Parameters
+*  ===================
+*
+*  TOLMUL  REAL, default = max(10,min(100,EPS**(-1/8)))
+*          TOLMUL controls the convergence criterion of the QR loop.
+*          If it is positive, TOLMUL*EPS is the desired relative
+*             precision in the computed singular values.
+*          If it is negative, abs(TOLMUL*EPS*sigma_max) is the
+*             desired absolute accuracy in the computed singular
+*             values (corresponds to relative accuracy
+*             abs(TOLMUL*EPS) in the largest singular value.
+*          abs(TOLMUL) should be between 1 and 1/EPS, and preferably
+*             between 10 (for fast convergence) and .1/EPS
+*             (for there to be some accuracy in the results).
+*          Default is to lose at either one eighth or 2 of the
+*             available decimal digits in each computed singular value
+*             (whichever is smaller).
+*
+*  MAXITR  INTEGER, default = 6
+*          MAXITR controls the maximum number of passes of the
+*          algorithm through its inner loop. The algorithms stops
+*          (and so fails to converge) if the number of passes
+*          through the inner loop exceeds MAXITR*N**2.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -275,11 +153,11 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            LOWER, ROTATE
-      INTEGER            I, IDIR, ISUB, ITER, ITERDIVN, J, LL, LLL, M,
-     $                   MAXITDIVN, NM1, NM12, NM13, OLDLL, OLDM
+      INTEGER            I, IDIR, ISUB, ITER, J, LL, LLL, M, MAXIT, NM1,
+     $                   NM12, NM13, OLDLL, OLDM
       REAL               ABSE, ABSS, COSL, COSR, CS, EPS, F, G, H, MU,
      $                   OLDCS, OLDSN, R, SHIFT, SIGMN, SIGMX, SINL,
-     $                   SINR, SLL, SMAX, SMIN, SMINOA,
+     $                   SINR, SLL, SMAX, SMIN, SMINL, SMINLO, SMINOA,
      $                   SN, THRESH, TOL, TOLMUL, UNFL
 *     ..
 *     .. External Functions ..
@@ -288,8 +166,7 @@
       EXTERNAL           LSAME, SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SLARTG, SLAS2, SLASQ1, SLASR, SLASV2,
-     $                   SROT,
+      EXTERNAL           SLARTG, SLAS2, SLASQ1, SLASR, SLASV2, SROT,
      $                   SSCAL, SSWAP, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -337,11 +214,7 @@
 *
       IF( .NOT.ROTATE ) THEN
          CALL SLASQ1( N, D, E, WORK, INFO )
-*
-*     If INFO equals 2, dqds didn't finish, try to finish
-*
-         IF( INFO .NE. 2 ) RETURN
-         INFO = 0
+         RETURN
       END IF
 *
       NM1 = N - 1
@@ -370,12 +243,10 @@
 *        Update singular vectors if desired
 *
          IF( NRU.GT.0 )
-     $      CALL SLASR( 'R', 'V', 'F', NRU, N, WORK( 1 ), WORK( N ),
-     $                  U,
+     $      CALL SLASR( 'R', 'V', 'F', NRU, N, WORK( 1 ), WORK( N ), U,
      $                  LDU )
          IF( NCC.GT.0 )
-     $      CALL SLASR( 'L', 'V', 'F', N, NCC, WORK( 1 ), WORK( N ),
-     $                  C,
+     $      CALL SLASR( 'L', 'V', 'F', N, NCC, WORK( 1 ), WORK( N ), C,
      $                  LDC )
       END IF
 *
@@ -395,7 +266,7 @@
       DO 30 I = 1, N - 1
          SMAX = MAX( SMAX, ABS( E( I ) ) )
    30 CONTINUE
-      SMIN = ZERO
+      SMINL = ZERO
       IF( TOL.GE.ZERO ) THEN
 *
 *        Relative accuracy desired
@@ -412,22 +283,20 @@
    40    CONTINUE
    50    CONTINUE
          SMINOA = SMINOA / SQRT( REAL( N ) )
-         THRESH = MAX( TOL*SMINOA, MAXITR*(REAL( N )*(REAL( N )*UNFL)) )
+         THRESH = MAX( TOL*SMINOA, MAXITR*N*N*UNFL )
       ELSE
 *
 *        Absolute accuracy desired
 *
-         THRESH = MAX( ABS( TOL )*SMAX, MAXITR*(REAL( N )*
-     $           (REAL( N )*UNFL)) )
+         THRESH = MAX( ABS( TOL )*SMAX, MAXITR*N*N*UNFL )
       END IF
 *
 *     Prepare for main iteration loop for the singular values
 *     (MAXIT is the maximum number of passes through the inner
 *     loop permitted before nonconvergence signalled.)
 *
-      MAXITDIVN = MAXITR*N
-      ITERDIVN = 0
-      ITER = -1
+      MAXIT = MAXITR*N*N
+      ITER = 0
       OLDLL = -1
       OLDM = -1
 *
@@ -443,19 +312,15 @@
 *
       IF( M.LE.1 )
      $   GO TO 160
-*
-      IF( ITER.GE.N ) THEN
-         ITER = ITER - N
-         ITERDIVN = ITERDIVN + 1
-         IF( ITERDIVN.GE.MAXITDIVN )
-     $      GO TO 200
-      END IF
+      IF( ITER.GT.MAXIT )
+     $   GO TO 200
 *
 *     Find diagonal block of matrix to work on
 *
       IF( TOL.LT.ZERO .AND. ABS( D( M ) ).LE.THRESH )
      $   D( M ) = ZERO
       SMAX = ABS( D( M ) )
+      SMIN = SMAX
       DO 70 LLL = 1, M - 1
          LL = M - LLL
          ABSS = ABS( D( LL ) )
@@ -464,6 +329,7 @@
      $      D( LL ) = ZERO
          IF( ABSE.LE.THRESH )
      $      GO TO 80
+         SMIN = MIN( SMIN, ABSS )
          SMAX = MAX( SMAX, ABSS, ABSE )
    70 CONTINUE
       LL = 0
@@ -498,12 +364,10 @@
 *        Compute singular vectors, if desired
 *
          IF( NCVT.GT.0 )
-     $      CALL SROT( NCVT, VT( M-1, 1 ), LDVT, VT( M, 1 ), LDVT,
-     $                 COSR,
+     $      CALL SROT( NCVT, VT( M-1, 1 ), LDVT, VT( M, 1 ), LDVT, COSR,
      $                 SINR )
          IF( NRU.GT.0 )
-     $      CALL SROT( NRU, U( 1, M-1 ), 1, U( 1, M ), 1, COSL,
-     $                 SINL )
+     $      CALL SROT( NRU, U( 1, M-1 ), 1, U( 1, M ), 1, COSL, SINL )
          IF( NCC.GT.0 )
      $      CALL SROT( NCC, C( M-1, 1 ), LDC, C( M, 1 ), LDC, COSL,
      $                 SINL )
@@ -547,14 +411,15 @@
 *           apply convergence criterion forward
 *
             MU = ABS( D( LL ) )
-            SMIN = MU
+            SMINL = MU
             DO 100 LLL = LL, M - 1
                IF( ABS( E( LLL ) ).LE.TOL*MU ) THEN
                   E( LLL ) = ZERO
                   GO TO 60
                END IF
+               SMINLO = SMINL
                MU = ABS( D( LLL+1 ) )*( MU / ( MU+ABS( E( LLL ) ) ) )
-               SMIN = MIN( SMIN, MU )
+               SMINL = MIN( SMINL, MU )
   100       CONTINUE
          END IF
 *
@@ -575,14 +440,15 @@
 *           apply convergence criterion backward
 *
             MU = ABS( D( M ) )
-            SMIN = MU
+            SMINL = MU
             DO 110 LLL = M - 1, LL, -1
                IF( ABS( E( LLL ) ).LE.TOL*MU ) THEN
                   E( LLL ) = ZERO
                   GO TO 60
                END IF
+               SMINLO = SMINL
                MU = ABS( D( LLL ) )*( MU / ( MU+ABS( E( LLL ) ) ) )
-               SMIN = MIN( SMIN, MU )
+               SMINL = MIN( SMINL, MU )
   110       CONTINUE
          END IF
       END IF
@@ -592,7 +458,7 @@
 *     Compute shift.  First, test if shifting would ruin relative
 *     accuracy, and if so set the shift to zero.
 *
-      IF( TOL.GE.ZERO .AND. REAL( N )*TOL*( SMIN / SMAX ).LE.
+      IF( TOL.GE.ZERO .AND. N*TOL*( SMINL / SMAX ).LE.
      $    MAX( EPS, HNDRTH*TOL ) ) THEN
 *
 *        Use a zero shift to avoid loss of relative accuracy
@@ -636,8 +502,7 @@
                CALL SLARTG( D( I )*CS, E( I ), CS, SN, R )
                IF( I.GT.LL )
      $            E( I-1 ) = OLDSN*R
-               CALL SLARTG( OLDCS*R, D( I+1 )*SN, OLDCS, OLDSN,
-     $                      D( I ) )
+               CALL SLARTG( OLDCS*R, D( I+1 )*SN, OLDCS, OLDSN, D( I ) )
                WORK( I-LL+1 ) = CS
                WORK( I-LL+1+NM1 ) = SN
                WORK( I-LL+1+NM12 ) = OLDCS
@@ -653,12 +518,10 @@
      $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCVT, WORK( 1 ),
      $                     WORK( N ), VT( LL, 1 ), LDVT )
             IF( NRU.GT.0 )
-     $         CALL SLASR( 'R', 'V', 'F', NRU, M-LL+1,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'R', 'V', 'F', NRU, M-LL+1, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), U( 1, LL ), LDU )
             IF( NCC.GT.0 )
-     $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCC,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCC, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), C( LL, 1 ), LDC )
 *
 *           Test convergence
@@ -677,8 +540,7 @@
                CALL SLARTG( D( I )*CS, E( I-1 ), CS, SN, R )
                IF( I.LT.M )
      $            E( I ) = OLDSN*R
-               CALL SLARTG( OLDCS*R, D( I-1 )*SN, OLDCS, OLDSN,
-     $                      D( I ) )
+               CALL SLARTG( OLDCS*R, D( I-1 )*SN, OLDCS, OLDSN, D( I ) )
                WORK( I-LL ) = CS
                WORK( I-LL+NM1 ) = -SN
                WORK( I-LL+NM12 ) = OLDCS
@@ -691,8 +553,7 @@
 *           Update singular vectors
 *
             IF( NCVT.GT.0 )
-     $         CALL SLASR( 'L', 'V', 'B', M-LL+1, NCVT,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'L', 'V', 'B', M-LL+1, NCVT, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), VT( LL, 1 ), LDVT )
             IF( NRU.GT.0 )
      $         CALL SLASR( 'R', 'V', 'B', NRU, M-LL+1, WORK( 1 ),
@@ -747,12 +608,10 @@
      $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCVT, WORK( 1 ),
      $                     WORK( N ), VT( LL, 1 ), LDVT )
             IF( NRU.GT.0 )
-     $         CALL SLASR( 'R', 'V', 'F', NRU, M-LL+1,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'R', 'V', 'F', NRU, M-LL+1, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), U( 1, LL ), LDU )
             IF( NCC.GT.0 )
-     $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCC,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'L', 'V', 'F', M-LL+1, NCC, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), C( LL, 1 ), LDC )
 *
 *           Test convergence
@@ -799,8 +658,7 @@
 *           Update singular vectors if desired
 *
             IF( NCVT.GT.0 )
-     $         CALL SLASR( 'L', 'V', 'B', M-LL+1, NCVT,
-     $                     WORK( NM12+1 ),
+     $         CALL SLASR( 'L', 'V', 'B', M-LL+1, NCVT, WORK( NM12+1 ),
      $                     WORK( NM13+1 ), VT( LL, 1 ), LDVT )
             IF( NRU.GT.0 )
      $         CALL SLASR( 'R', 'V', 'B', NRU, M-LL+1, WORK( 1 ),
@@ -819,14 +677,7 @@
 *
   160 CONTINUE
       DO 170 I = 1, N
-         IF( D( I ).EQ.ZERO ) THEN
-*
-*           Avoid -ZERO
-*
-            D( I ) = ZERO
-         END IF
          IF( D( I ).LT.ZERO ) THEN
-
             D( I ) = -D( I )
 *
 *           Change sign of singular vectors, if desired
@@ -863,8 +714,7 @@
             IF( NRU.GT.0 )
      $         CALL SSWAP( NRU, U( 1, ISUB ), 1, U( 1, N+1-I ), 1 )
             IF( NCC.GT.0 )
-     $         CALL SSWAP( NCC, C( ISUB, 1 ), LDC, C( N+1-I, 1 ),
-     $                     LDC )
+     $         CALL SSWAP( NCC, C( ISUB, 1 ), LDC, C( N+1-I, 1 ), LDC )
          END IF
   190 CONTINUE
       GO TO 220
