@@ -1,83 +1,40 @@
-*> \brief \b CERRED
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE CERRED( PATH, NUNIT )
-* 
-*       .. Scalar Arguments ..
-*       CHARACTER*3        PATH
-*       INTEGER            NUNIT
-*       ..
-*  
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> CERRED tests the error exits for the eigenvalue driver routines for
-*> REAL matrices:
-*>
-*> PATH  driver   description
-*> ----  ------   -----------
-*> CEV   CGEEV    find eigenvalues/eigenvectors for nonsymmetric A
-*> CES   CGEES    find eigenvalues/Schur form for nonsymmetric A
-*> CVX   CGEEVX   CGEEV + balancing and condition estimation
-*> CSX   CGEESX   CGEES + balancing and condition estimation
-*> CBD   CGESVD   compute SVD of an M-by-N matrix A
-*>       CGESDD   compute SVD of an M-by-N matrix A(by divide and
-*>                conquer)
-*>       CGEJSV   compute SVD of an M-by-N matrix A where M >= N
-*>       CGESVDX  compute SVD of an M-by-N matrix A(by bisection
-*>                and inverse iteration)
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] PATH
-*> \verbatim
-*>          PATH is CHARACTER*3
-*>          The LAPACK path name for the routines to be tested.
-*> \endverbatim
-*>
-*> \param[in] NUNIT
-*> \verbatim
-*>          NUNIT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
-*
-*> \date November 2015
-*
-*> \ingroup complex_eig
-*
-*  =====================================================================
       SUBROUTINE CERRED( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  CERRED tests the error exits for the eigenvalue driver routines for
+*  REAL matrices:
+*
+*  PATH  driver   description
+*  ----  ------   -----------
+*  CEV   CGEEV    find eigenvalues/eigenvectors for nonsymmetric A
+*  CES   CGEES    find eigenvalues/Schur form for nonsymmetric A
+*  CVX   CGEEVX   CGEEV + balancing and condition estimation
+*  CSX   CGEESX   CGEES + balancing and condition estimation
+*  CBD   CGESVD   compute SVD of an M-by-N matrix A
+*        CGESDD   compute SVD of an M-by-N matrix A(by divide and
+*                 conquer)
+*
+*  Arguments
+*  =========
+*
+*  PATH    (input) CHARACTER*3
+*          The LAPACK path name for the routines to be tested.
+*
+*  NUNIT   (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -88,7 +45,7 @@
 *     ..
 *     .. Local Scalars ..
       CHARACTER*2        C2
-      INTEGER            I, IHI, ILO, INFO, J, NS, NT, SDIM
+      INTEGER            I, IHI, ILO, INFO, J, NT, SDIM
       REAL               ABNRM
 *     ..
 *     .. Local Arrays ..
@@ -97,18 +54,15 @@
       REAL               R1( NMAX ), R2( NMAX ), RW( LW ), S( NMAX )
       COMPLEX            A( NMAX, NMAX ), U( NMAX, NMAX ),
      $                   VL( NMAX, NMAX ), VR( NMAX, NMAX ),
-     $                   VT( NMAX, NMAX ), W( 10*NMAX ), X( NMAX )
+     $                   VT( NMAX, NMAX ), W( 4*NMAX ), X( NMAX )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHKXER, CGEES, CGEESX, CGEEV, CGEEVX, CGEJSV
-     $                   CGESDD, CGESVD
+      EXTERNAL           CGEES, CGEESX, CGEEV, CGEEVX, CGESDD, CGESVD,
+     $                   CHKXER
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAMEN, CSLECT
-      EXTERNAL           LSAMEN, CSLECT
-*     ..
-*     .. Intrinsic Functions ..
-      INTRINSIC          LEN_TRIM
+      LOGICAL            CSLECT, LSAMEN
+      EXTERNAL           CSLECT, LSAMEN
 *     ..
 *     .. Arrays in Common ..
       LOGICAL            SELVAL( 20 )
@@ -116,7 +70,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NOUT, SELDIM, SELOPT
 *     ..
 *     .. Common blocks ..
@@ -330,8 +284,7 @@
          CALL CHKXER( 'CGESVD', INFOT, NOUT, LERR, OK )
          NT = NT + 8
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
-     $           NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -365,133 +318,7 @@
          CALL CHKXER( 'CGESDD', INFOT, NOUT, LERR, OK )
          NT = NT - 2
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
-     $           NT
-         ELSE
-            WRITE( NOUT, FMT = 9998 )
-         END IF
-*
-*        Test CGEJSV
-*
-         SRNAMT = 'CGEJSV'
-         INFOT = 1
-         CALL CGEJSV( 'X', 'U', 'V', 'R', 'N', 'N',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 2
-         CALL CGEJSV( 'G', 'X', 'V', 'R', 'N', 'N',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 3
-         CALL CGEJSV( 'G', 'U', 'X', 'R', 'N', 'N',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 4
-         CALL CGEJSV( 'G', 'U', 'V', 'X', 'N', 'N',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 5
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'X', 'N',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 6
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'X',
-     $                 0, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 7
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
-     $                 -1, 0, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 8
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
-     $                 0, -1, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 10
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
-     $                 2, 1, A, 1, S, U, 1, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 13
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
-     $                 2, 2, A, 2, S, U, 1, VT, 2,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 15
-         CALL CGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
-     $                 2, 2, A, 2, S, U, 2, VT, 1,
-     $                 W, 1, RW, 1, IW, INFO)
-         CALL CHKXER( 'CGEJSV', INFOT, NOUT, LERR, OK )
-         NT = 11
-         IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
-     $           NT
-         ELSE
-            WRITE( NOUT, FMT = 9998 )
-         END IF
-*
-*        Test CGESVDX
-*
-         SRNAMT = 'CGESVDX'
-         INFOT = 1
-         CALL CGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 2
-         CALL CGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 3
-         CALL CGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 4
-         CALL CGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 5
-         CALL CGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 7
-         CALL CGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 8
-         CALL CGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 9
-         CALL CGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 10
-         CALL CGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
-     $                 0, 1, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 11
-         CALL CGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
-     $                 1, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 15
-         CALL CGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 16
-         CALL CGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO, 
-     $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
-         CALL CHKXER( 'CGESVDX', INFOT, NOUT, LERR, OK )
-         NT = 12
-         IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
-     $           NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
@@ -501,16 +328,15 @@
 *
       IF( .NOT.LSAMEN( 2, C2, 'BD' ) ) THEN
          IF( OK ) THEN
-            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
-     $           NT
+            WRITE( NOUT, FMT = 9999 )SRNAMT, NT
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
       END IF
 *
- 9999 FORMAT( 1X, A, ' passed the tests of the error exits (', I3,
+ 9999 FORMAT( 1X, A6, ' passed the tests of the error exits (', I3,
      $      ' tests done)' )
- 9998 FORMAT( ' *** ', A, ' failed the tests of the error exits ***' )
+ 9998 FORMAT( ' *** ', A6, ' failed the tests of the error exits ***' )
       RETURN
 *
 *     End of CERRED
