@@ -1,68 +1,31 @@
-*> \brief \b DERREC
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE DERREC( PATH, NUNIT )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER*3        PATH
-*       INTEGER            NUNIT
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> DERREC tests the error exits for the routines for eigen- condition
-*> estimation for DOUBLE PRECISION matrices:
-*>    DTRSYL, DTREXC, DTRSNA and DTRSEN.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] PATH
-*> \verbatim
-*>          PATH is CHARACTER*3
-*>          The LAPACK path name for the routines to be tested.
-*> \endverbatim
-*>
-*> \param[in] NUNIT
-*> \verbatim
-*>          NUNIT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup double_eig
-*
-*  =====================================================================
       SUBROUTINE DERREC( PATH, NUNIT )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  DERREC tests the error exits for the routines for eigen- condition
+*  estimation for DOUBLE PRECISION matrices:
+*     DTRSYL, STREXC, STRSNA and STRSEN.
+*
+*  Arguments
+*  =========
+*
+*  PATH    (input) CHARACTER*3
+*          The LAPACK path name for the routines to be tested.
+*
+*  NUNIT   (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -86,7 +49,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NOUT
 *     ..
 *     .. Common blocks ..
@@ -149,8 +112,8 @@
       INFOT = 1
       CALL DTREXC( 'X', 1, A, 1, B, 1, IFST, ILST, WORK, INFO )
       CALL CHKXER( 'DTREXC', INFOT, NOUT, LERR, OK )
-      INFOT = 2
-      CALL DTREXC( 'N', -1, A, 1, B, 1, IFST, ILST, WORK, INFO )
+      INFOT = 7
+      CALL DTREXC( 'N', 0, A, 1, B, 1, IFST, ILST, WORK, INFO )
       CALL CHKXER( 'DTREXC', INFOT, NOUT, LERR, OK )
       INFOT = 4
       ILST = 2
