@@ -1,82 +1,9 @@
-*> \brief \b SCHKEC
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE SCHKEC( THRESH, TSTERR, NIN, NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NIN, NOUT
-*       REAL               THRESH
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> SCHKEC tests eigen- condition estimation routines
-*>        SLALN2, SLASY2, SLANV2, SLAQTR, SLAEXC,
-*>        STRSYL, STREXC, STRSNA, STRSEN, STGEXC
-*>
-*> In all cases, the routine runs through a fixed set of numerical
-*> examples, subjects them to various tests, and compares the test
-*> results to a threshold THRESH. In addition, STREXC, STRSNA and STRSEN
-*> are tested by reading in precomputed examples from a file (on input
-*> unit NIN).  Output is written to output unit NOUT.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is REAL
-*>          Threshold for residual tests.  A computed test ratio passes
-*>          the threshold if it is less than THRESH.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NIN
-*> \verbatim
-*>          NIN is INTEGER
-*>          The logical unit number for input.
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The logical unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup single_eig
-*
-*  =====================================================================
       SUBROUTINE SCHKEC( THRESH, TSTERR, NIN, NOUT )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -84,29 +11,56 @@
       REAL               THRESH
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  SCHKEC tests eigen- condition estimation routines
+*         SLALN2, SLASY2, SLANV2, SLAQTR, SLAEXC,
+*         STRSYL, STREXC, STRSNA, STRSEN
+*
+*  In all cases, the routine runs through a fixed set of numerical
+*  examples, subjects them to various tests, and compares the test
+*  results to a threshold THRESH. In addition, STREXC, STRSNA and STRSEN
+*  are tested by reading in precomputed examples from a file (on input
+*  unit NIN).  Output is written to output unit NOUT.
+*
+*  Arguments
+*  =========
+*
+*  THRESH  (input) REAL
+*          Threshold for residual tests.  A computed test ratio passes
+*          the threshold if it is less than THRESH.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NIN     (input) INTEGER
+*          The logical unit number for input.
+*
+*  NOUT    (input) INTEGER
+*          The logical unit number for output.
+*
 *  =====================================================================
 *
 *     .. Local Scalars ..
       LOGICAL            OK
       CHARACTER*3        PATH
       INTEGER            KLAEXC, KLALN2, KLANV2, KLAQTR, KLASY2, KTREXC,
-     $                   KTRSEN, KTRSNA, KTRSYL, KTRSYL3, LLAEXC,
-     $                   LLALN2, LLANV2, LLAQTR, LLASY2, LTREXC, LTRSYL,
-     $                   NLANV2, NLAQTR, NLASY2, NTESTS, NTRSYL, KTGEXC,
-     $                   LTGEXC
+     $                   KTRSEN, KTRSNA, KTRSYL, LLAEXC, LLALN2, LLANV2,
+     $                   LLAQTR, LLASY2, LTREXC, LTRSYL, NLANV2, NLAQTR,
+     $                   NLASY2, NTESTS, NTRSYL
       REAL               EPS, RLAEXC, RLALN2, RLANV2, RLAQTR, RLASY2,
-     $                   RTREXC, SFMIN, RTGEXC
+     $                   RTREXC, RTRSYL, SFMIN
 *     ..
 *     .. Local Arrays ..
-      INTEGER            FTRSYL( 3 ), ITRSYL( 2 ), LTRSEN( 3 ),
-     $                   LTRSNA( 3 ), NLAEXC( 2 ), NLALN2( 2 ),
-     $                   NTGEXC( 2 ), NTREXC( 3 ), NTRSEN( 3 ),
+      INTEGER            LTRSEN( 3 ), LTRSNA( 3 ), NLAEXC( 2 ),
+     $                   NLALN2( 2 ), NTREXC( 3 ), NTRSEN( 3 ),
      $                   NTRSNA( 3 )
-      REAL               RTRSEN( 3 ), RTRSNA( 3 ), RTRSYL( 2 )
+      REAL               RTRSEN( 3 ), RTRSNA( 3 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           SERREC, SGET31, SGET32, SGET33, SGET34, SGET35,
-     $                   SGET36, SGET37, SGET38, SGET39, SGET40, SSYL01
+     $                   SGET36, SGET37, SGET38, SGET39
 *     ..
 *     .. External Functions ..
       REAL               SLAMCH
@@ -155,24 +109,10 @@
          WRITE( NOUT, FMT = 9996 )RLAEXC, LLAEXC, NLAEXC, KLAEXC
       END IF
 *
-      CALL SGET35( RTRSYL( 1 ), LTRSYL, NTRSYL, KTRSYL )
-      IF( RTRSYL( 1 ).GT.THRESH ) THEN
+      CALL SGET35( RTRSYL, LTRSYL, NTRSYL, KTRSYL )
+      IF( RTRSYL.GT.THRESH ) THEN
          OK = .FALSE.
-         WRITE( NOUT, FMT = 9995 )RTRSYL( 1 ), LTRSYL, NTRSYL, KTRSYL
-      END IF
-*
-      CALL SSYL01( THRESH, FTRSYL, RTRSYL, ITRSYL, KTRSYL3 )
-      IF( FTRSYL( 1 ).GT.0 ) THEN
-         OK = .FALSE.
-         WRITE( NOUT, FMT = 9970 )FTRSYL( 1 ), RTRSYL( 1 ), THRESH
-      END IF
-      IF( FTRSYL( 2 ).GT.0 ) THEN
-         OK = .FALSE.
-         WRITE( NOUT, FMT = 9971 )FTRSYL( 2 ), RTRSYL( 2 ), THRESH
-      END IF
-      IF( FTRSYL( 3 ).GT.0 ) THEN
-         OK = .FALSE.
-         WRITE( NOUT, FMT = 9972 )FTRSYL( 3 )
+         WRITE( NOUT, FMT = 9995 )RTRSYL, LTRSYL, NTRSYL, KTRSYL
       END IF
 *
       CALL SGET36( RTREXC, LTREXC, NTREXC, KTREXC, NIN )
@@ -202,12 +142,6 @@
          OK = .FALSE.
          WRITE( NOUT, FMT = 9991 )RLAQTR, LLAQTR, NLAQTR, KLAQTR
       END IF
-*
-      CALL SGET40( RTGEXC, LTGEXC, NTGEXC, KTGEXC, NIN )
-      IF( RTGEXC.GT.THRESH ) THEN
-         OK = .FALSE.
-         WRITE( NOUT, FMT = 9986 )RTGEXC, LTGEXC, NTGEXC, KTGEXC
-      END IF
 *
       NTESTS = KLALN2 + KLASY2 + KLANV2 + KLAEXC + KTRSYL + KTREXC +
      $         KTRSNA + KTRSEN + KLAQTR
@@ -234,7 +168,7 @@
  9991 FORMAT( ' Error in SLAQTR: RMAX =', E12.3, / ' LMAX = ', I8, ' N',
      $      'INFO=', I8, ' KNT=', I8 )
  9990 FORMAT( / 1X, 'All tests for ', A3, ' routines passed the thresh',
-     $      'old ( ', I6, ' tests run)' )
+     $      'old (', I6, ' tests run)' )
  9989 FORMAT( ' Tests of the Nonsymmetric eigenproblem condition estim',
      $      'ation routines', / ' SLALN2, SLASY2, SLANV2, SLAEXC, STRS',
      $      'YL, STREXC, STRSNA, STRSEN, SLAQTR', / )
@@ -242,14 +176,6 @@
      $      'minimum (SFMIN)             = ', E16.6, / )
  9987 FORMAT( ' Routines pass computational tests if test ratio is les',
      $      's than', F8.2, / / )
- 9986 FORMAT( ' Error in STGEXC: RMAX =', E12.3, / ' LMAX = ', I8, ' N',
-     $      'INFO=', 2I8, ' KNT=', I8 )
- 9972 FORMAT( 'STRSYL and STRSYL3 compute an inconsistent result ',
-     $      'factor in ', I8, ' tests.')
- 9971 FORMAT( 'Error in STRSYL3: ', I8, ' tests fail the threshold.', /
-     $      'Maximum test ratio =', D12.3, ' threshold =', D12.3 )
- 9970 FORMAT( 'Error in STRSYL: ', I8, ' tests fail the threshold.', /
-     $      'Maximum test ratio =', D12.3, ' threshold =', D12.3 )
 *
 *     End of SCHKEC
 *
