@@ -1,9 +1,9 @@
       SUBROUTINE SGET37( RMAX, LMAX, NINFO, KNT, NIN )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, NIN
@@ -41,9 +41,9 @@
 *          If STRSNA returns INFO nonzero on example i, LMAX(3)=i
 *
 *  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = 1 if SGEHRD returned INFO nonzero
-*          NINFO(2) = 1 if SHSEQR returned INFO nonzero
-*          NINFO(3) = 1 if STRSNA returned INFO nonzero
+*          NINFO(1) = No. of times SGEHRD returned INFO nonzero
+*          NINFO(2) = No. of times SHSEQR returned INFO nonzero
+*          NINFO(3) = No. of times STRSNA returned INFO nonzero
 *
 *  KNT     (output) INTEGER
 *          Total number of examples tested.
@@ -82,8 +82,8 @@
       EXTERNAL           SLAMCH, SLANGE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SCOPY, SGEHRD, SHSEQR, SLACPY, SSCAL, STREVC,
-     $                   STRSNA
+      EXTERNAL           SCOPY, SGEHRD, SHSEQR, SLABAD, SLACPY, SSCAL,
+     $                   STREVC, STRSNA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, REAL, SQRT
@@ -151,7 +151,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 1 ) = KNT
             NINFO( 1 ) = NINFO( 1 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 60 J = 1, N - 2
             DO 50 I = J + 2, N
@@ -166,7 +166,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 2 ) = KNT
             NINFO( 2 ) = NINFO( 2 ) + 1
-            RETURN
+            GO TO 240
          END IF
 *
 *        Compute eigenvectors
@@ -181,7 +181,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
 *
 *        Sort eigenvalues and condition numbers lexicographically
@@ -247,7 +247,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
    90    CONTINUE
 *
@@ -280,7 +281,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
   100    CONTINUE
 *
@@ -304,7 +306,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   110    CONTINUE
 *
@@ -327,7 +330,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   120    CONTINUE
 *
@@ -342,7 +346,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 130 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -360,7 +364,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 140 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -382,7 +386,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 160 I = 1, N
             IF( SEPTMP( I ).NE.SEP( I ) )
@@ -400,7 +404,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 170 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -418,7 +422,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 180 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -428,7 +432,8 @@
   180    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
 *
 *        Select first real and first complex eigenvalue
@@ -485,7 +490,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 210 I = 1, ICMP
             J = LCMP( I )
@@ -504,7 +509,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 220 I = 1, ICMP
             J = LCMP( I )
@@ -523,7 +528,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 240
          END IF
          DO 230 I = 1, ICMP
             J = LCMP( I )
@@ -534,7 +539,8 @@
   230    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
   240 CONTINUE
       GO TO 10
