@@ -1,20 +1,20 @@
-      SUBROUTINE CCHKPB( DOTYPE, NN, NVAL, NNB, NBVAL, NRHS, THRESH,
-     $                   TSTERR, NMAX, A, AFAC, AINV, B, X, XACT, WORK,
-     $                   RWORK, NOUT )
+      SUBROUTINE CCHKPB( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
+     $                   THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
+     $                   XACT, WORK, RWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            NMAX, NN, NNB, NOUT, NRHS
+      INTEGER            NMAX, NN, NNB, NNS, NOUT
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            NBVAL( * ), NVAL( * )
+      INTEGER            NBVAL( * ), NSVAL( * ), NVAL( * )
       REAL               RWORK( * )
       COMPLEX            A( * ), AFAC( * ), AINV( * ), B( * ),
      $                   WORK( * ), X( * ), XACT( * )
@@ -45,9 +45,11 @@
 *  NBVAL   (input) INTEGER array, dimension (NBVAL)
 *          The values of the blocksize NB.
 *
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
 *
 *  THRESH  (input) REAL
 *          The threshold value for the test ratios.  A result is
@@ -67,17 +69,18 @@
 *
 *  AINV    (workspace) REAL array, dimension (NMAX*NMAX)
 *
-*  B       (workspace) REAL array, dimension (NMAX*NRHS)
+*  B       (workspace) REAL array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
 *
-*  X       (workspace) REAL array, dimension (NMAX*NRHS)
+*  X       (workspace) REAL array, dimension (NMAX*NSMAX)
 *
-*  XACT    (workspace) REAL array, dimension (NMAX*NRHS)
+*  XACT    (workspace) REAL array, dimension (NMAX*NSMAX)
 *
 *  WORK    (workspace) REAL array, dimension
-*                      (NMAX*max(3,NRHS))
+*                      (NMAX*max(3,NSMAX))
 *
 *  RWORK   (workspace) REAL array, dimension
-*                      (max(NMAX,2*NRHS))
+*                      (max(NMAX,2*NSMAX))
 *
 *  NOUT    (input) INTEGER
 *          The unit number for output.
@@ -97,9 +100,9 @@
       CHARACTER          DIST, PACKIT, TYPE, UPLO, XTYPE
       CHARACTER*3        PATH
       INTEGER            I, I1, I2, IKD, IMAT, IN, INB, INFO, IOFF,
-     $                   IUPLO, IW, IZERO, K, KD, KL, KOFF, KU, LDA,
-     $                   LDAB, MODE, N, NB, NERRS, NFAIL, NIMAT, NKD,
-     $                   NRUN, NT
+     $                   IRHS, IUPLO, IW, IZERO, K, KD, KL, KOFF, KU,
+     $                   LDA, LDAB, MODE, N, NB, NERRS, NFAIL, NIMAT,
+     $                   NKD, NRHS, NRUN
       REAL               AINVNM, ANORM, CNDNUM, RCOND, RCONDC
 *     ..
 *     .. Local Arrays ..
@@ -112,7 +115,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASUM, CCOPY, CERRPO, CGET04,
-     $                   CLACPY, CLAIPD, CLARHS, CLATB4, CLATMS, CLASET,
+     $                   CLACPY, CLAIPD, CLARHS, CLASET, CLATB4, CLATMS,
      $                   CPBCON, CPBRFS, CPBT01, CPBT02, CPBT05, CPBTRF,
      $                   CPBTRS, CSWAP, XLAENV
 *     ..
@@ -135,7 +138,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'PB'
       NRUN = 0
       NFAIL = 0
@@ -334,12 +337,22 @@
      $                            LDAB )
                      CALL CPBT01( UPLO, N, KD, A, LDAB, AINV, LDAB,
      $                            RWORK, RESULT( 1 ) )
-                     NT = 1
+*
+*                    Print the test ratio if it is .GE. THRESH.
+*
+                     IF( RESULT( 1 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9999 )UPLO, N, KD, NB, IMAT,
+     $                     1, RESULT( 1 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
 *
 *                    Only do other tests if this is the first blocksize.
 *
                      IF( INB.GT.1 )
-     $                  GO TO 30
+     $                  GO TO 50
 *
 *                    Form the inverse of A so we can get a good estimate
 *                    of RCONDC = 1/(norm(A) * norm(inv(A))).
@@ -359,59 +372,78 @@
                      ELSE
                         RCONDC = ( ONE / ANORM ) / AINVNM
                      END IF
+*
+                     DO 40 IRHS = 1, NNS
+                        NRHS = NSVAL( IRHS )
 *
 *+    TEST 2
 *                    Solve and compute residual for A * X = B.
 *
-                     SRNAMT = 'CLARHS'
-                     CALL CLARHS( PATH, XTYPE, UPLO, ' ', N, N, KD, KD,
-     $                            NRHS, A, LDAB, XACT, LDA, B, LDA,
-     $                            ISEED, INFO )
-                     XTYPE = 'C'
-                     CALL CLACPY( 'Full', N, NRHS, B, LDA, X, LDA )
+                        SRNAMT = 'CLARHS'
+                        CALL CLARHS( PATH, XTYPE, UPLO, ' ', N, N, KD,
+     $                               KD, NRHS, A, LDAB, XACT, LDA, B,
+     $                               LDA, ISEED, INFO )
+                        XTYPE = 'C'
+                        CALL CLACPY( 'Full', N, NRHS, B, LDA, X, LDA )
 *
-                     SRNAMT = 'CPBTRS'
-                     CALL CPBTRS( UPLO, N, KD, NRHS, AFAC, LDAB, X, LDA,
-     $                            INFO )
+                        SRNAMT = 'CPBTRS'
+                        CALL CPBTRS( UPLO, N, KD, NRHS, AFAC, LDAB, X,
+     $                               LDA, INFO )
 *
 *                    Check error code from CPBTRS.
 *
-                     IF( INFO.NE.0 )
-     $                  CALL ALAERH( PATH, 'CPBTRS', INFO, 0, UPLO, N,
-     $                               N, KD, KD, NRHS, IMAT, NFAIL,
-     $                               NERRS, NOUT )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'CPBTRS', INFO, 0, UPLO,
+     $                                  N, N, KD, KD, NRHS, IMAT, NFAIL,
+     $                                  NERRS, NOUT )
 *
-                     CALL CLACPY( 'Full', N, NRHS, B, LDA, WORK, LDA )
-                     CALL CPBT02( UPLO, N, KD, NRHS, A, LDAB, X, LDA,
-     $                            WORK, LDA, RWORK, RESULT( 2 ) )
+                        CALL CLACPY( 'Full', N, NRHS, B, LDA, WORK,
+     $                               LDA )
+                        CALL CPBT02( UPLO, N, KD, NRHS, A, LDAB, X, LDA,
+     $                               WORK, LDA, RWORK, RESULT( 2 ) )
 *
 *+    TEST 3
 *                    Check solution from generated exact solution.
 *
-                     CALL CGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
-     $                            RESULT( 3 ) )
+                        CALL CGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
+     $                               RESULT( 3 ) )
 *
 *+    TESTS 4, 5, and 6
 *                    Use iterative refinement to improve the solution.
 *
-                     SRNAMT = 'CPBRFS'
-                     CALL CPBRFS( UPLO, N, KD, NRHS, A, LDAB, AFAC,
-     $                            LDAB, B, LDA, X, LDA, RWORK,
-     $                            RWORK( NRHS+1 ), WORK,
-     $                            RWORK( 2*NRHS+1 ), INFO )
+                        SRNAMT = 'CPBRFS'
+                        CALL CPBRFS( UPLO, N, KD, NRHS, A, LDAB, AFAC,
+     $                               LDAB, B, LDA, X, LDA, RWORK,
+     $                               RWORK( NRHS+1 ), WORK,
+     $                               RWORK( 2*NRHS+1 ), INFO )
 *
 *                    Check error code from CPBRFS.
 *
-                     IF( INFO.NE.0 )
-     $                  CALL ALAERH( PATH, 'CPBRFS', INFO, 0, UPLO, N,
-     $                               N, KD, KD, NRHS, IMAT, NFAIL,
-     $                               NERRS, NOUT )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'CPBRFS', INFO, 0, UPLO,
+     $                                  N, N, KD, KD, NRHS, IMAT, NFAIL,
+     $                                  NERRS, NOUT )
 *
-                     CALL CGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
-     $                            RESULT( 4 ) )
-                     CALL CPBT05( UPLO, N, KD, NRHS, A, LDAB, B, LDA, X,
-     $                            LDA, XACT, LDA, RWORK,
-     $                            RWORK( NRHS+1 ), RESULT( 5 ) )
+                        CALL CGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
+     $                               RESULT( 4 ) )
+                        CALL CPBT05( UPLO, N, KD, NRHS, A, LDAB, B, LDA,
+     $                               X, LDA, XACT, LDA, RWORK,
+     $                               RWORK( NRHS+1 ), RESULT( 5 ) )
+*
+*                       Print information about the tests that did not
+*                       pass the threshold.
+*
+                        DO 30 K = 2, 6
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )UPLO, N, KD,
+     $                           NRHS, IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+   30                   CONTINUE
+                        NRUN = NRUN + 5
+   40                CONTINUE
 *
 *+    TEST 7
 *                    Get an estimate of RCOND = 1/CNDNUM.
@@ -428,24 +460,18 @@
      $                               NOUT )
 *
                      RESULT( 7 ) = SGET06( RCOND, RCONDC )
-                     NT = 7
 *
-*                    Print information about the tests that did not pass
-*                    the threshold.
+*                    Print the test ratio if it is .GE. THRESH.
 *
-   30                CONTINUE
-                     DO 40 K = 1, NT
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           WRITE( NOUT, FMT = 9999 )UPLO, N, KD, NB,
-     $                        IMAT, K, RESULT( K )
-                           NFAIL = NFAIL + 1
-                        END IF
-   40                CONTINUE
-                     NRUN = NRUN + NT
+                     IF( RESULT( 7 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9997 )UPLO, N, KD, IMAT, 7,
+     $                     RESULT( 7 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
    50             CONTINUE
-*
    60          CONTINUE
    70       CONTINUE
    80    CONTINUE
@@ -457,6 +483,10 @@
 *
  9999 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ', NB=', I4,
      $      ', type ', I2, ', test ', I2, ', ratio= ', G12.5 )
+ 9998 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ', NRHS=', I3,
+     $      ', type ', I2, ', test(', I2, ') = ', G12.5 )
+ 9997 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ',', 10X,
+     $      ' type ', I2, ', test(', I2, ') = ', G12.5 )
       RETURN
 *
 *     End of CCHKPB
