@@ -1,169 +1,11 @@
-*> \brief \b CCHKTR
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE CCHKTR( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
-*                          THRESH, TSTERR, NMAX, A, AINV, B, X, XACT,
-*                          WORK, RWORK, NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NMAX, NN, NNB, NNS, NOUT
-*       REAL               THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            NBVAL( * ), NSVAL( * ), NVAL( * )
-*       REAL               RWORK( * )
-*       COMPLEX            A( * ), AINV( * ), B( * ), WORK( * ), X( * ),
-*      $                   XACT( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS(3)
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix column dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNB
-*> \verbatim
-*>          NNB is INTEGER
-*>          The number of values of NB contained in the vector NBVAL.
-*> \endverbatim
-*>
-*> \param[in] NBVAL
-*> \verbatim
-*>          NBVAL is INTEGER array, dimension (NNB)
-*>          The values of the blocksize NB.
-*> \endverbatim
-*>
-*> \param[in] NNS
-*> \verbatim
-*>          NNS is INTEGER
-*>          The number of values of NRHS contained in the vector NSVAL.
-*> \endverbatim
-*>
-*> \param[in] NSVAL
-*> \verbatim
-*>          NSVAL is INTEGER array, dimension (NNS)
-*>          The values of the number of right hand sides NRHS.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is REAL
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The leading dimension of the work arrays.
-*>          NMAX >= the maximum value of N in NVAL.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AINV
-*> \verbatim
-*>          AINV is COMPLEX array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX array, dimension (NMAX*NSMAX)
-*>          where NSMAX is the largest entry in NSVAL.
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX array, dimension
-*>                      (NMAX*max(3,NSMAX))
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is REAL array, dimension
-*>                      (max(NMAX,2*NSMAX))
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup complex_lin
-*
-*  =====================================================================
       SUBROUTINE CCHKTR( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
      $                   THRESH, TSTERR, NMAX, A, AINV, B, X, XACT,
      $                   WORK, RWORK, NOUT )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -178,13 +20,76 @@
      $                   XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix column dimension N.
+*
+*  NNB     (input) INTEGER
+*          The number of values of NB contained in the vector NBVAL.
+*
+*  NBVAL   (input) INTEGER array, dimension (NNB)
+*          The values of the blocksize NB.
+*
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
+*  THRESH  (input) REAL
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The leading dimension of the work arrays.
+*          NMAX >= the maximum value of N in NVAL.
+*
+*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX)
+*
+*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)
+*
+*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
+*
+*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
+*
+*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)
+*
+*  WORK    (workspace) COMPLEX array, dimension
+*                      (NMAX*max(3,NSMAX))
+*
+*  RWORK   (workspace) REAL array, dimension
+*                      (max(NMAX,2*NSMAX))
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            NTYPE1, NTYPES
       PARAMETER          ( NTYPE1 = 10, NTYPES = 18 )
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 10 )
+      PARAMETER          ( NTESTS = 9 )
       INTEGER            NTRAN
       PARAMETER          ( NTRAN = 3 )
       REAL               ONE, ZERO
@@ -195,14 +100,13 @@
       CHARACTER*3        PATH
       INTEGER            I, IDIAG, IMAT, IN, INB, INFO, IRHS, ITRAN,
      $                   IUPLO, K, LDA, N, NB, NERRS, NFAIL, NRHS, NRUN
-      REAL               AINVNM, ANORM, BIGNUM, DUMMY, RCOND, RCONDC,
-     $                   RCONDI, RCONDO, RES, SCALE, SLAMCH
+      REAL               AINVNM, ANORM, DUMMY, RCOND, RCONDC, RCONDI,
+     $                   RCONDO, SCALE
 *     ..
 *     .. Local Arrays ..
       CHARACTER          TRANSS( NTRAN ), UPLOS( 2 )
       INTEGER            ISEED( 4 ), ISEEDY( 4 )
-      REAL               RESULT( NTESTS ), RWORK2( 2*NMAX ),
-     $                   SCALE3( 2 )
+      REAL               RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -211,13 +115,13 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASUM, CCOPY, CERRTR, CGET04,
-     $                   CLACPY, CLARHS, CLATRS, CLATRS3, CLATTR,
-     $                   CSSCAL, CTRCON, CTRRFS, CTRT01, CTRT02, CTRT03,
-     $                   CTRT05, CTRT06, CTRTRI, CTRTRS, XLAENV, SLAMCH
+     $                   CLACPY, CLARHS, CLATRS, CLATTR, CTRCON, CTRRFS,
+     $                   CTRT01, CTRT02, CTRT03, CTRT05, CTRT06, CTRTRI,
+     $                   CTRTRS, XLAENV
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, IOUNIT
 *     ..
 *     .. Common blocks ..
@@ -237,7 +141,6 @@
 *
       PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'TR'
-      BIGNUM = SLAMCH('Overflow') / SLAMCH('Precision')
       NRUN = 0
       NFAIL = 0
       NERRS = 0
@@ -329,8 +232,8 @@
                   IF( RESULT( 1 ).GE.THRESH ) THEN
                      IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9999 )UPLO, DIAG, N, NB, IMAT,
-     $                  1, RESULT( 1 )
+                     WRITE( NOUT, FMT = 9999 )UPLO, N, NB, IMAT, 1,
+     $                  RESULT( 1 )
                      NFAIL = NFAIL + 1
                   END IF
                   NRUN = NRUN + 1
@@ -382,7 +285,7 @@
 *                       This line is needed on a Sun SPARCstation.
 *
                         IF( N.GT.0 )
-     $                     DUMMY = REAL( A( 1 ) )
+     $                     DUMMY = A( 1 )
 *
                         CALL CTRT02( UPLO, TRANS, DIAG, N, NRHS, A, LDA,
      $                               X, LDA, B, LDA, WORK, RWORK,
@@ -425,8 +328,8 @@
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALAHD( NOUT, PATH )
-                              WRITE( NOUT, FMT = 9998 )UPLO, TRANS,
-     $                           DIAG, N, NRHS, IMAT, K, RESULT( K )
+                              WRITE( NOUT, FMT = 9998 )UPLO, TRANS, N,
+     $                           NRHS, IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
    20                   CONTINUE
@@ -537,32 +440,6 @@
      $                         RWORK, ONE, B( N+1 ), LDA, X, LDA, WORK,
      $                         RESULT( 9 ) )
 *
-*+    TEST 10
-*                 Solve op(A)*X = B.
-*
-                  SRNAMT = 'CLATRS3'
-                  CALL CCOPY( N, X, 1, B, 1 )
-                  CALL CCOPY( N, X, 1, B( N+1 ), 1 )
-                  CALL CSSCAL( N, BIGNUM, B( N+1 ), 1 )
-                  CALL CLATRS3( UPLO, TRANS, DIAG, 'N', N, 2, A, LDA,
-     $                          B, MAX(1, N), SCALE3, RWORK, RWORK2,
-     $                          2*NMAX, INFO )
-*
-*                 Check error code from CLATRS3.
-*
-                  IF( INFO.NE.0 )
-     $               CALL ALAERH( PATH, 'CLATRS3', INFO, 0,
-     $                            UPLO // TRANS // DIAG // 'N', N, N,
-     $                            -1, -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
-     $                         SCALE3( 1 ), RWORK, ONE, B( 1 ), LDA,
-     $                         X, LDA, WORK, RESULT( 10 ) )
-                  CALL CSSCAL( N, BIGNUM, X, 1 )
-                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
-     $                         SCALE3( 2 ), RWORK, ONE, B( N+1 ), LDA,
-     $                         X, LDA, WORK, RES )
-                  RESULT( 10 ) = MAX( RESULT( 10 ), RES )
-*
 *                 Print information about the tests that did not pass
 *                 the threshold.
 *
@@ -577,17 +454,10 @@
                      IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                  CALL ALAHD( NOUT, PATH )
                      WRITE( NOUT, FMT = 9996 )'CLATRS', UPLO, TRANS,
-     $                  DIAG, 'Y', N, IMAT, 9, RESULT( 9 )
+     $                  DIAG, 'Y', N, IMAT, 8, RESULT( 9 )
                      NFAIL = NFAIL + 1
                   END IF
-                  IF( RESULT( 10 ).GE.THRESH ) THEN
-                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9996 )'CLATRS3', UPLO, TRANS,
-     $                  DIAG, 'N', N, IMAT, 10, RESULT( 10 )
-                     NFAIL = NFAIL + 1
-                  END IF
-                  NRUN = NRUN + 3
+                  NRUN = NRUN + 2
    90          CONTINUE
   100       CONTINUE
   110    CONTINUE
@@ -597,14 +467,13 @@
 *
       CALL ALASUM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( ' UPLO=''', A1, ''', DIAG=''', A1, ''', N=', I5, ', NB=',
+ 9999 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', N=', I5, ', NB=',
      $      I4, ', type ', I2, ', test(', I2, ')= ', G12.5 )
- 9998 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', DIAG=''', A1,
-     $      ''', N=', I5, ', NB=', I4, ', type ', I2, ',
-     $      test(', I2, ')= ', G12.5 )
+ 9998 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
+     $      A1, ''',', I5, ', ... ), type ', I2, ', ratio =', G12.5 )
  9997 FORMAT( ' NORM=''', A1, ''', UPLO =''', A1, ''', N=', I5, ',',
      $      11X, ' type ', I2, ', test(', I2, ')=', G12.5 )
- 9996 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
+ 9996 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
      $      A1, ''',', I5, ', ... ), type ', I2, ', test(', I2, ')=',
      $      G12.5 )
       RETURN
