@@ -1,159 +1,11 @@
-*> \brief \b CDRVHE
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE CDRVHE( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
-*                          A, AFAC, AINV, B, X, XACT, WORK, RWORK, IWORK,
-*                          NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NMAX, NN, NOUT, NRHS
-*       REAL               THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            IWORK( * ), NVAL( * )
-*       REAL               RWORK( * )
-*       COMPLEX            A( * ), AFAC( * ), AINV( * ), B( * ),
-*      $                   WORK( * ), X( * ), XACT( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> CDRVHE tests the driver routines CHESV and -SVX.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix dimension N.
-*> \endverbatim
-*>
-*> \param[in] NRHS
-*> \verbatim
-*>          NRHS is INTEGER
-*>          The number of right hand side vectors to be generated for
-*>          each linear system.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is REAL
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The maximum value permitted for N, used in dimensioning the
-*>          work arrays.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AFAC
-*> \verbatim
-*>          AFAC is COMPLEX array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AINV
-*> \verbatim
-*>          AINV is COMPLEX array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX array, dimension (NMAX*max(2,NRHS))
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is REAL array, dimension (NMAX+2*NRHS)
-*> \endverbatim
-*>
-*> \param[out] IWORK
-*> \verbatim
-*>          IWORK is INTEGER array, dimension (NMAX)
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup complex_lin
-*
-*  =====================================================================
       SUBROUTINE CDRVHE( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
      $                   A, AFAC, AINV, B, X, XACT, WORK, RWORK, IWORK,
      $                   NOUT )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -168,6 +20,63 @@
      $                   WORK( * ), X( * ), XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  CDRVHE tests the driver routines CHESV and -SVX.
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix dimension N.
+*
+*  NRHS    (input) INTEGER
+*          The number of right hand side vectors to be generated for
+*          each linear system.
+*
+*  THRESH  (input) REAL
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The maximum value permitted for N, used in dimensioning the
+*          work arrays.
+*
+*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX)
+*
+*  AFAC    (workspace) COMPLEX array, dimension (NMAX*NMAX)
+*
+*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)
+*
+*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*
+*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*
+*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*
+*  WORK    (workspace) COMPLEX array, dimension
+*                      (NMAX*max(2,NRHS))
+*
+*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)
+*
+*  IWORK   (workspace) INTEGER array, dimension (NMAX)
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -198,13 +107,13 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALADHD, ALAERH, ALASVM, CERRVX, CGET04, CHESV,
-     $                   CHESVX, CHET01, CHETRF, CHETRI2, CLACPY,
-     $                   CLAIPD, CLARHS, CLASET, CLATB4, CLATMS, CPOT02,
-     $                   CPOT05, XLAENV
+     $                   CHESVX, CHET01, CHETRF, CHETRI, CLACPY, CLAIPD,
+     $                   CLARHS, CLASET, CLATB4, CLATMS, CPOT02, CPOT05,
+     $                   XLAENV
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -222,7 +131,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'Complex precision'
+      PATH( 1: 1 ) = 'C'
       PATH( 2: 3 ) = 'HE'
       NRUN = 0
       NFAIL = 0
@@ -392,9 +301,8 @@
 *                    Compute inv(A) and take its norm.
 *
                      CALL CLACPY( UPLO, N, N, AFAC, LDA, AINV, LDA )
-                     LWORK = (N+NB+1)*(NB+3)
-                     CALL CHETRI2( UPLO, N, AINV, LDA, IWORK, WORK,
-     $                            LWORK, INFO )
+                     CALL CHETRI( UPLO, N, AINV, LDA, IWORK, WORK,
+     $                            INFO )
                      AINVNM = CLANHE( '1', UPLO, N, AINV, LDA, RWORK )
 *
 *                    Compute the 1-norm condition number of A.
@@ -594,9 +502,9 @@
 *
       CALL ALASVM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( 1X, A, ', UPLO=''', A1, ''', N =', I5, ', type ', I2,
+ 9999 FORMAT( 1X, A6, ', UPLO=''', A1, ''', N =', I5, ', type ', I2,
      $      ', test ', I2, ', ratio =', G12.5 )
- 9998 FORMAT( 1X, A, ', FACT=''', A1, ''', UPLO=''', A1, ''', N =', I5,
+ 9998 FORMAT( 1X, A6, ', FACT=''', A1, ''', UPLO=''', A1, ''', N =', I5,
      $      ', type ', I2, ', test ', I2, ', ratio =', G12.5 )
       RETURN
 *
