@@ -1,159 +1,10 @@
-*> \brief \b CLAVSY
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE CLAVSY( UPLO, TRANS, DIAG, N, NRHS, A, LDA, IPIV, B,
-*                          LDB, INFO )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER          DIAG, TRANS, UPLO
-*       INTEGER            INFO, LDA, LDB, N, NRHS
-*       ..
-*       .. Array Arguments ..
-*       INTEGER            IPIV( * )
-*       COMPLEX            A( LDA, * ), B( LDB, * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> CLAVSY performs one of the matrix-vector operations
-*>    x := A*x  or  x := A'*x,
-*> where x is an N element vector and  A is one of the factors
-*> from the block U*D*U' or L*D*L' factorization computed by CSYTRF.
-*>
-*> If TRANS = 'N', multiplies by U  or U * D  (or L  or L * D)
-*> If TRANS = 'T', multiplies by U' or D * U' (or L' or D * L')
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] UPLO
-*> \verbatim
-*>          UPLO is CHARACTER*1
-*>          Specifies whether the factor stored in A is upper or lower
-*>          triangular.
-*>          = 'U':  Upper triangular
-*>          = 'L':  Lower triangular
-*> \endverbatim
-*>
-*> \param[in] TRANS
-*> \verbatim
-*>          TRANS is CHARACTER*1
-*>          Specifies the operation to be performed:
-*>          = 'N':  x := A*x
-*>          = 'T':  x := A'*x
-*> \endverbatim
-*>
-*> \param[in] DIAG
-*> \verbatim
-*>          DIAG is CHARACTER*1
-*>          Specifies whether or not the diagonal blocks are unit
-*>          matrices.  If the diagonal blocks are assumed to be unit,
-*>          then A = U or A = L, otherwise A = U*D or A = L*D.
-*>          = 'U':  Diagonal blocks are assumed to be unit matrices.
-*>          = 'N':  Diagonal blocks are assumed to be non-unit matrices.
-*> \endverbatim
-*>
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>          The number of rows and columns of the matrix A.  N >= 0.
-*> \endverbatim
-*>
-*> \param[in] NRHS
-*> \verbatim
-*>          NRHS is INTEGER
-*>          The number of right hand sides, i.e., the number of vectors
-*>          x to be multiplied by A.  NRHS >= 0.
-*> \endverbatim
-*>
-*> \param[in] A
-*> \verbatim
-*>          A is COMPLEX array, dimension (LDA,N)
-*>          The block diagonal matrix D and the multipliers used to
-*>          obtain the factor U or L as computed by CSYTRF.
-*>          Stored as a 2-D triangular matrix.
-*> \endverbatim
-*>
-*> \param[in] LDA
-*> \verbatim
-*>          LDA is INTEGER
-*>          The leading dimension of the array A.  LDA >= max(1,N).
-*> \endverbatim
-*>
-*> \param[in] IPIV
-*> \verbatim
-*>          IPIV is INTEGER array, dimension (N)
-*>          Details of the interchanges and the block structure of D,
-*>          as determined by CSYTRF.
-*>
-*>          If UPLO = 'U':
-*>               If IPIV(k) > 0, then rows and columns k and IPIV(k)
-*>               were interchanged and D(k,k) is a 1-by-1 diagonal block.
-*>               (If IPIV( k ) = k, no interchange was done).
-*>
-*>               If IPIV(k) = IPIV(k-1) < 0, then rows and
-*>               columns k-1 and -IPIV(k) were interchanged,
-*>               D(k-1:k,k-1:k) is a 2-by-2 diagonal block.
-*>
-*>          If UPLO = 'L':
-*>               If IPIV(k) > 0, then rows and columns k and IPIV(k)
-*>               were interchanged and D(k,k) is a 1-by-1 diagonal block.
-*>               (If IPIV( k ) = k, no interchange was done).
-*>
-*>               If IPIV(k) = IPIV(k+1) < 0, then rows and
-*>               columns k+1 and -IPIV(k) were interchanged,
-*>               D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
-*> \endverbatim
-*>
-*> \param[in,out] B
-*> \verbatim
-*>          B is COMPLEX array, dimension (LDB,NRHS)
-*>          On entry, B contains NRHS vectors of length N.
-*>          On exit, B is overwritten with the product A * B.
-*> \endverbatim
-*>
-*> \param[in] LDB
-*> \verbatim
-*>          LDB is INTEGER
-*>          The leading dimension of the array B.  LDB >= max(1,N).
-*> \endverbatim
-*>
-*> \param[out] INFO
-*> \verbatim
-*>          INFO is INTEGER
-*>          = 0: successful exit
-*>          < 0: if INFO = -k, the k-th argument had an illegal value
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup complex_lin
-*
-*  =====================================================================
       SUBROUTINE CLAVSY( UPLO, TRANS, DIAG, N, NRHS, A, LDA, IPIV, B,
      $                   LDB, INFO )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK auxiliary routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIAG, TRANS, UPLO
@@ -164,11 +15,107 @@
       COMPLEX            A( LDA, * ), B( LDB, * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*     CLAVSY  performs one of the matrix-vector operations
+*        x := A*x  or  x := A'*x,
+*     where x is an N element vector and  A is one of the factors
+*     from the symmetric factorization computed by CSYTRF.
+*     CSYTRF produces a factorization of the form
+*          U * D * U'      or     L * D * L' ,
+*     where U (or L) is a product of permutation and unit upper (lower)
+*     triangular matrices, U' (or L') is the transpose of
+*     U (or L), and D is symmetric and block diagonal with 1 x 1 and
+*     2 x 2 diagonal blocks.  The multipliers for the transformations
+*     and the upper or lower triangular parts of the diagonal blocks
+*     are stored in the leading upper or lower triangle of the 2-D
+*     array A.
+*
+*     If TRANS = 'N' or 'n', CLAVSY multiplies either by U or U * D
+*     (or L or L * D).
+*     If TRANS = 'T' or 't', CLAVSY multiplies either by U' or D * U'
+*     (or L' or D * L' ).
+*
+*  Arguments
+*  ==========
+*
+*  UPLO   - CHARACTER*1
+*           On entry, UPLO specifies whether the triangular matrix
+*           stored in A is upper or lower triangular.
+*              UPLO = 'U' or 'u'   The matrix is upper triangular.
+*              UPLO = 'L' or 'l'   The matrix is lower triangular.
+*           Unchanged on exit.
+*
+*  TRANS  - CHARACTER*1
+*           On entry, TRANS specifies the operation to be performed as
+*           follows:
+*              TRANS = 'N' or 'n'   x := A*x.
+*              TRANS = 'T' or 't'   x := A'*x.
+*           Unchanged on exit.
+*
+*  DIAG   - CHARACTER*1
+*           On entry, DIAG specifies whether the diagonal blocks are
+*           assumed to be unit matrices:
+*              DIAG = 'U' or 'u'   Diagonal blocks are unit matrices.
+*              DIAG = 'N' or 'n'   Diagonal blocks are non-unit.
+*           Unchanged on exit.
+*
+*  N      - INTEGER
+*           On entry, N specifies the order of the matrix A.
+*           N must be at least zero.
+*           Unchanged on exit.
+*
+*  NRHS   - INTEGER
+*           On entry, NRHS specifies the number of right hand sides,
+*           i.e., the number of vectors x to be multiplied by A.
+*           NRHS must be at least zero.
+*           Unchanged on exit.
+*
+*  A      - COMPLEX array, dimension( LDA, N )
+*           On entry, A contains a block diagonal matrix and the
+*           multipliers of the transformations used to obtain it,
+*           stored as a 2-D triangular matrix.
+*           Unchanged on exit.
+*
+*  LDA    - INTEGER
+*           On entry, LDA specifies the first dimension of A as declared
+*           in the calling ( sub ) program. LDA must be at least
+*           max( 1, N ).
+*           Unchanged on exit.
+*
+*  IPIV   - INTEGER array, dimension( N )
+*           On entry, IPIV contains the vector of pivot indices as
+*           determined by CSYTRF or CHETRF.
+*           If IPIV( K ) = K, no interchange was done.
+*           If IPIV( K ) <> K but IPIV( K ) > 0, then row K was inter-
+*           changed with row IPIV( K ) and a 1 x 1 pivot block was used.
+*           If IPIV( K ) < 0 and UPLO = 'U', then row K-1 was exchanged
+*           with row | IPIV( K ) | and a 2 x 2 pivot block was used.
+*           If IPIV( K ) < 0 and UPLO = 'L', then row K+1 was exchanged
+*           with row | IPIV( K ) | and a 2 x 2 pivot block was used.
+*
+*  B      - COMPLEX array, dimension( LDB, NRHS )
+*           On entry, B contains NRHS vectors of length N.
+*           On exit, B is overwritten with the product A * B.
+*
+*  LDB    - INTEGER
+*           On entry, LDB contains the leading dimension of B as
+*           declared in the calling program.  LDB must be at least
+*           max( 1, N ).
+*           Unchanged on exit.
+*
+*  INFO   - INTEGER
+*           INFO is the error flag.
+*           On exit, a value of 0 indicates a successful exit.
+*           A negative value, say -K, indicates that the K-th argument
+*           has an illegal value.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
-      COMPLEX            CONE
-      PARAMETER          ( CONE = ( 1.0E+0, 0.0E+0 ) )
+      COMPLEX            ONE
+      PARAMETER          ( ONE = ( 1.0E+0, 0.0E+0 ) )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            NOUNIT
@@ -249,7 +196,7 @@
 *
 *                 Apply the transformation.
 *
-                  CALL CGERU( K-1, NRHS, CONE, A( 1, K ), 1, B( K, 1 ),
+                  CALL CGERU( K-1, NRHS, ONE, A( 1, K ), 1, B( K, 1 ),
      $                        LDB, B( 1, 1 ), LDB )
 *
 *                 Interchange if P(K) != I.
@@ -284,9 +231,9 @@
 *
 *                 Apply the transformations.
 *
-                  CALL CGERU( K-1, NRHS, CONE, A( 1, K ), 1, B( K, 1 ),
+                  CALL CGERU( K-1, NRHS, ONE, A( 1, K ), 1, B( K, 1 ),
      $                        LDB, B( 1, 1 ), LDB )
-                  CALL CGERU( K-1, NRHS, CONE, A( 1, K+1 ), 1,
+                  CALL CGERU( K-1, NRHS, ONE, A( 1, K+1 ), 1,
      $                        B( K+1, 1 ), LDB, B( 1, 1 ), LDB )
 *
 *                 Interchange if P(K) != I.
@@ -331,7 +278,7 @@
 *
 *                 Apply the transformation.
 *
-                  CALL CGERU( N-K, NRHS, CONE, A( K+1, K ), 1,
+                  CALL CGERU( N-K, NRHS, ONE, A( K+1, K ), 1,
      $                        B( K, 1 ), LDB, B( K+1, 1 ), LDB )
 *
 *                 Interchange if a permutation was applied at the
@@ -367,9 +314,9 @@
 *
 *                 Apply the transformation.
 *
-                  CALL CGERU( N-K, NRHS, CONE, A( K+1, K ), 1,
+                  CALL CGERU( N-K, NRHS, ONE, A( K+1, K ), 1,
      $                        B( K, 1 ), LDB, B( K+1, 1 ), LDB )
-                  CALL CGERU( N-K, NRHS, CONE, A( K+1, K-1 ), 1,
+                  CALL CGERU( N-K, NRHS, ONE, A( K+1, K-1 ), 1,
      $                        B( K-1, 1 ), LDB, B( K+1, 1 ), LDB )
 *
 *                 Interchange if a permutation was applied at the
@@ -416,8 +363,8 @@
 *
 *                 Apply the transformation
 *
-                  CALL CGEMV( 'Transpose', K-1, NRHS, CONE, B, LDB,
-     $                        A( 1, K ), 1, CONE, B( K, 1 ), LDB )
+                  CALL CGEMV( 'Transpose', K-1, NRHS, ONE, B, LDB,
+     $                        A( 1, K ), 1, ONE, B( K, 1 ), LDB )
                END IF
                IF( NOUNIT )
      $            CALL CSCAL( NRHS, A( K, K ), B( K, 1 ), LDB )
@@ -437,10 +384,10 @@
 *
 *                 Apply the transformations
 *
-                  CALL CGEMV( 'Transpose', K-2, NRHS, CONE, B, LDB,
-     $                        A( 1, K ), 1, CONE, B( K, 1 ), LDB )
-                  CALL CGEMV( 'Transpose', K-2, NRHS, CONE, B, LDB,
-     $                        A( 1, K-1 ), 1, CONE, B( K-1, 1 ), LDB )
+                  CALL CGEMV( 'Transpose', K-2, NRHS, ONE, B, LDB,
+     $                        A( 1, K ), 1, ONE, B( K, 1 ), LDB )
+                  CALL CGEMV( 'Transpose', K-2, NRHS, ONE, B, LDB,
+     $                        A( 1, K-1 ), 1, ONE, B( K-1, 1 ), LDB )
                END IF
 *
 *              Multiply by the diagonal block if non-unit.
@@ -488,8 +435,8 @@
 *
 *                 Apply the transformation
 *
-                  CALL CGEMV( 'Transpose', N-K, NRHS, CONE, B( K+1, 1 ),
-     $                       LDB, A( K+1, K ), 1, CONE, B( K, 1 ), LDB )
+                  CALL CGEMV( 'Transpose', N-K, NRHS, ONE, B( K+1, 1 ),
+     $                        LDB, A( K+1, K ), 1, ONE, B( K, 1 ), LDB )
                END IF
                IF( NOUNIT )
      $            CALL CSCAL( NRHS, A( K, K ), B( K, 1 ), LDB )
@@ -509,11 +456,11 @@
 *
 *                 Apply the transformation
 *
-                  CALL CGEMV( 'Transpose', N-K-1, NRHS, CONE,
-     $                        B( K+2, 1 ), LDB, A( K+2, K+1 ), 1, CONE,
+                  CALL CGEMV( 'Transpose', N-K-1, NRHS, ONE,
+     $                        B( K+2, 1 ), LDB, A( K+2, K+1 ), 1, ONE,
      $                        B( K+1, 1 ), LDB )
-                  CALL CGEMV( 'Transpose', N-K-1, NRHS, CONE,
-     $                        B( K+2, 1 ), LDB, A( K+2, K ), 1, CONE,
+                  CALL CGEMV( 'Transpose', N-K-1, NRHS, ONE,
+     $                        B( K+2, 1 ), LDB, A( K+2, K ), 1, ONE,
      $                        B( K, 1 ), LDB )
                END IF
 *
