@@ -1,117 +1,75 @@
-*> \brief \b SCHKAA
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       PROGRAM SCHKAA
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> SCHKAA is the main test program for the REAL LAPACK
-*> linear equation routines
-*>
-*> The program must be driven by a short data file. The first 15 records
-*> (not including the first comment  line) specify problem dimensions
-*> and program options using list-directed input. The remaining lines
-*> specify the LAPACK test paths and the number of matrix types to use
-*> in testing.  An annotated example of a data file can be obtained by
-*> deleting the first 3 characters from the following 40 lines:
-*> Data file for testing REAL LAPACK linear eqn. routines
-*> 7                      Number of values of M
-*> 0 1 2 3 5 10 16        Values of M (row dimension)
-*> 7                      Number of values of N
-*> 0 1 2 3 5 10 16        Values of N (column dimension)
-*> 1                      Number of values of NRHS
-*> 2                      Values of NRHS (number of right hand sides)
-*> 5                      Number of values of NB
-*> 1 3 3 3 20             Values of NB (the blocksize)
-*> 1 0 5 9 1              Values of NX (crossover point)
-*> 3                      Number of values of RANK
-*> 30 50 90               Values of rank (as a % of N)
-*> 20.0                   Threshold value of test ratio
-*> T                      Put T to test the LAPACK routines
-*> T                      Put T to test the driver routines
-*> T                      Put T to test the error exits
-*> SGE   11               List types on next line if 0 < NTYPES < 11
-*> SGB    8               List types on next line if 0 < NTYPES <  8
-*> SGT   12               List types on next line if 0 < NTYPES < 12
-*> SPO    9               List types on next line if 0 < NTYPES <  9
-*> SPS    9               List types on next line if 0 < NTYPES <  9
-*> SPP    9               List types on next line if 0 < NTYPES <  9
-*> SPB    8               List types on next line if 0 < NTYPES <  8
-*> SPT   12               List types on next line if 0 < NTYPES < 12
-*> SSY   10               List types on next line if 0 < NTYPES < 10
-*> SSR   10               List types on next line if 0 < NTYPES < 10
-*> SSK   10               List types on next line if 0 < NTYPES < 10
-*> SSA   10               List types on next line if 0 < NTYPES < 10
-*> SSP   10               List types on next line if 0 < NTYPES < 10
-*> STR   18               List types on next line if 0 < NTYPES < 18
-*> STP   18               List types on next line if 0 < NTYPES < 18
-*> STB   17               List types on next line if 0 < NTYPES < 17
-*> SQR    8               List types on next line if 0 < NTYPES <  8
-*> SRQ    8               List types on next line if 0 < NTYPES <  8
-*> SLQ    8               List types on next line if 0 < NTYPES <  8
-*> SQL    8               List types on next line if 0 < NTYPES <  8
-*> SQP    6               List types on next line if 0 < NTYPES <  6
-*> STZ    3               List types on next line if 0 < NTYPES <  3
-*> SLS    6               List types on next line if 0 < NTYPES <  6
-*> SEQ
-*> SQT
-*> SQX
-*> \endverbatim
-*
-*  Parameters:
-*  ==========
-*
-*> \verbatim
-*>  NMAX    INTEGER
-*>          The maximum allowable value for M and N.
-*>
-*>  MAXIN   INTEGER
-*>          The number of different values that can be used for each of
-*>          M, N, NRHS, NB, NX and RANK
-*>
-*>  MAXRHS  INTEGER
-*>          The maximum number of right hand sides
-*>
-*>  MATMAX  INTEGER
-*>          The maximum number of matrix types to use for testing
-*>
-*>  NIN     INTEGER
-*>          The unit number for input
-*>
-*>  NOUT    INTEGER
-*>          The unit number for output
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \date April 2012
-*
-*> \ingroup single_lin
-*
-*  =====================================================================
       PROGRAM SCHKAA
 *
-*  -- LAPACK test routine (version 3.7.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     April 2012
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
+*
+*  Purpose
+*  =======
+*
+*  SCHKAA is the main test program for the REAL LAPACK
+*  linear equation routines
+*
+*  The program must be driven by a short data file. The first 14 records
+*  specify problem dimensions and program options using list-directed
+*  input.  The remaining lines specify the LAPACK test paths and the
+*  number of matrix types to use in testing.  An annotated example of a
+*  data file can be obtained by deleting the first 3 characters from the
+*  following 36 lines:
+*  Data file for testing REAL LAPACK linear eqn. routines
+*  7                      Number of values of M
+*  0 1 2 3 5 10 16        Values of M (row dimension)
+*  7                      Number of values of N
+*  0 1 2 3 5 10 16        Values of N (column dimension)
+*  1                      Number of values of NRHS
+*  2                      Values of NRHS (number of right hand sides)
+*  5                      Number of values of NB
+*  1 3 3 3 20             Values of NB (the blocksize)
+*  1 0 5 9 1              Values of NX (crossover point)
+*  20.0                   Threshold value of test ratio
+*  T                      Put T to test the LAPACK routines
+*  T                      Put T to test the driver routines
+*  T                      Put T to test the error exits
+*  SGE   11               List types on next line if 0 < NTYPES < 11
+*  SGB    8               List types on next line if 0 < NTYPES <  8
+*  SGT   12               List types on next line if 0 < NTYPES < 12
+*  SPO    9               List types on next line if 0 < NTYPES <  9
+*  SPP    9               List types on next line if 0 < NTYPES <  9
+*  SPB    8               List types on next line if 0 < NTYPES <  8
+*  SPT   12               List types on next line if 0 < NTYPES < 12
+*  SSY   10               List types on next line if 0 < NTYPES < 10
+*  SSP   10               List types on next line if 0 < NTYPES < 10
+*  STR   18               List types on next line if 0 < NTYPES < 18
+*  STP   18               List types on next line if 0 < NTYPES < 18
+*  STB   17               List types on next line if 0 < NTYPES < 17
+*  SQR    8               List types on next line if 0 < NTYPES <  8
+*  SRQ    8               List types on next line if 0 < NTYPES <  8
+*  SLQ    8               List types on next line if 0 < NTYPES <  8
+*  SQL    8               List types on next line if 0 < NTYPES <  8
+*  SQP    6               List types on next line if 0 < NTYPES <  6
+*  STZ    3               List types on next line if 0 < NTYPES <  3
+*  SLS    6               List types on next line if 0 < NTYPES <  6
+*  SEQ
+*
+*  Internal Parameters
+*  ===================
+*
+*  NMAX    INTEGER
+*          The maximum allowable value for N
+*
+*  MAXIN   INTEGER
+*          The number of different values that can be used for each of
+*          M, N, NRHS, NB, and NX
+*
+*  MAXRHS  INTEGER
+*          The maximum number of right hand sides
+*
+*  NIN     INTEGER
+*          The unit number for input
+*
+*  NOUT    INTEGER
+*          The unit number for output
 *
 *  =====================================================================
 *
@@ -137,19 +95,17 @@
       CHARACTER*10       INTSTR
       CHARACTER*72       ALINE
       INTEGER            I, IC, J, K, LA, LAFAC, LDA, NB, NM, NMATS, NN,
-     $                   NNB, NNB2, NNS, NRHS, NTYPES, NRANK,
-     $                   VERS_MAJOR, VERS_MINOR, VERS_PATCH
+     $                   NNB, NNB2, NNS, NRHS, NTYPES
       REAL               EPS, S1, S2, THREQ, THRESH
 *     ..
 *     .. Local Arrays ..
       LOGICAL            DOTYPE( MATMAX )
       INTEGER            IWORK( 25*NMAX ), MVAL( MAXIN ),
      $                   NBVAL( MAXIN ), NBVAL2( MAXIN ),
-     $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN ),
-     $                   RANKVAL( MAXIN ), PIV( NMAX )
+     $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN )
       REAL               A( ( KDMAX+1 )*NMAX, 7 ), B( NMAX*MAXRHS, 4 ),
-     $                   E( NMAX ), RWORK( 5*NMAX+2*MAXRHS ),
-     $                   S( 2*NMAX ), WORK( NMAX, NMAX+MAXRHS+30 )
+     $                   RWORK( 5*NMAX+2*MAXRHS ), S( 2*NMAX ),
+     $                   WORK( NMAX, NMAX+MAXRHS+30 )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME, LSAMEN
@@ -158,17 +114,15 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAREQ, SCHKEQ, SCHKGB, SCHKGE, SCHKGT, SCHKLQ,
-     $                   SCHKPB, SCHKPO, SCHKPS, SCHKPP, SCHKPT, SCHKQ3,
-     $                   SCHKQL, SCHKQR, SCHKRQ, SCHKSP, SCHKSY,
-     $                   SCHKSY_ROOK, SCHKSY_RK, SCHKSY_AA, SCHKTB,
+     $                   SCHKPB, SCHKPO, SCHKPP, SCHKPT, SCHKQ3, SCHKQL,
+     $                   SCHKQP, SCHKQR, SCHKRQ, SCHKSP, SCHKSY, SCHKTB,
      $                   SCHKTP, SCHKTR, SCHKTZ, SDRVGB, SDRVGE, SDRVGT,
      $                   SDRVLS, SDRVPB, SDRVPO, SDRVPP, SDRVPT, SDRVSP,
-     $                   SDRVSY, SDRVSY_ROOK, SDRVSY_RK, SDRVSY_AA,
-     $                   ILAVER, SCHKLQTP, SCHKQRT, SCHKQRTP
+     $                   SDRVSY
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Arrays in Common ..
@@ -194,8 +148,7 @@
 *
 *     Report values of parameters.
 *
-      CALL ILAVER( VERS_MAJOR, VERS_MINOR, VERS_PATCH )
-      WRITE( NOUT, FMT = 9994 ) VERS_MAJOR, VERS_MINOR, VERS_PATCH
+      WRITE( NOUT, FMT = 9994 )
 *
 *     Read the values of M
 *
@@ -319,32 +272,6 @@
       IF( NNB.GT.0 )
      $   WRITE( NOUT, FMT = 9993 )'NX  ', ( NXVAL( I ), I = 1, NNB )
 *
-*     Read the values of RANKVAL
-*
-      READ( NIN, FMT = * )NRANK
-      IF( NN.LT.1 ) THEN
-         WRITE( NOUT, FMT = 9996 )' NRANK ', NRANK, 1
-         NRANK = 0
-         FATAL = .TRUE.
-      ELSE IF( NN.GT.MAXIN ) THEN
-         WRITE( NOUT, FMT = 9995 )' NRANK ', NRANK, MAXIN
-         NRANK = 0
-         FATAL = .TRUE.
-      END IF
-      READ( NIN, FMT = * )( RANKVAL( I ), I = 1, NRANK )
-      DO I = 1, NRANK
-         IF( RANKVAL( I ).LT.0 ) THEN
-            WRITE( NOUT, FMT = 9996 )' RANK  ', RANKVAL( I ), 0
-            FATAL = .TRUE.
-         ELSE IF( RANKVAL( I ).GT.100 ) THEN
-            WRITE( NOUT, FMT = 9995 )' RANK  ', RANKVAL( I ), 100
-            FATAL = .TRUE.
-         END IF
-      END DO
-      IF( NRANK.GT.0 )
-     $   WRITE( NOUT, FMT = 9993 )'RANK % OF N',
-     $   ( RANKVAL( I ), I = 1, NRANK )
-*
 *     Read the threshold value for the test ratios.
 *
       READ( NIN, FMT = * )THRESH
@@ -524,23 +451,6 @@
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'PS' ) ) THEN
-*
-*        PS:  positive semi-definite matrices
-*
-         NTYPES = 9
-*
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKPS( DOTYPE, NN, NVAL, NNB2, NBVAL2, NRANK,
-     $                   RANKVAL, THRESH, TSTERR, LDA, A( 1, 1 ),
-     $                   A( 1, 2 ), A( 1, 3 ), PIV, WORK, RWORK,
-     $                   NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'PP' ) ) THEN
 *
@@ -617,8 +527,7 @@
 *
       ELSE IF( LSAMEN( 2, C2, 'SY' ) ) THEN
 *
-*        SY:  symmetric indefinite matrices,
-*             with partial (Bunch-Kaufman) pivoting algorithm
+*        SY:  symmetric indefinite matrices
 *
          NTYPES = 10
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
@@ -640,91 +549,10 @@
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SR' ) ) THEN
-*
-*        SR:  symmetric indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKSY_ROOK(DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                       THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                       A( 1, 3 ), B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                       WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL SDRVSY_ROOK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                        LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                        B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                        WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SK' ) ) THEN
-*
-*        SK:  symmetric indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm,
-*             differnet matrix storage format than SR path version.
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKSY_RK( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                      THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                      E, A( 1, 3 ), B( 1, 1 ), B( 1, 2 ),
-     $                      B( 1, 3 ), WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL SDRVSY_RK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                      LDA, A( 1, 1 ), A( 1, 2 ), E, A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                      WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SA' ) ) THEN
-*
-*        SA:  symmetric indefinite matrices,
-*             with partial (Aasen's) pivoting algorithm
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKSY_AA( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS,
-     $                         NSVAL, THRESH, TSTERR, LDA,
-     $                         A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                         B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL SDRVSY_AA( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                         LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                         B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-        ELSE
-           WRITE( NOUT, FMT = 9988 )PATH
-        END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'SP' ) ) THEN
 *
-*        SP:  symmetric indefinite packed matrices,
-*             with partial (Bunch-Kaufman) pivoting algorithm
+*        SP:  symmetric indefinite packed matrices
 *
          NTYPES = 10
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
@@ -824,7 +652,7 @@
      $                   NRHS, THRESH, TSTERR, NMAX, A( 1, 1 ),
      $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
      $                   B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), B( 1, 4 ),
-     $                   WORK, RWORK, NOUT )
+     $                   WORK, RWORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -841,7 +669,7 @@
      $                   NRHS, THRESH, TSTERR, NMAX, A( 1, 1 ),
      $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
      $                   B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), B( 1, 4 ),
-     $                   WORK, RWORK, NOUT )
+     $                   WORK, RWORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -871,9 +699,12 @@
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
 *
          IF( TSTCHK ) THEN
+            CALL SCHKQP( DOTYPE, NM, MVAL, NN, NVAL, THRESH, TSTERR,
+     $                   A( 1, 1 ), A( 1, 2 ), B( 1, 1 ), B( 1, 2 ),
+     $                   B( 1, 3 ), WORK, IWORK, NOUT )
             CALL SCHKQ3( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NXVAL,
      $                   THRESH, A( 1, 1 ), A( 1, 2 ), B( 1, 1 ),
-     $                   B( 1, 3 ), WORK, IWORK, NOUT )
+     $                   B( 1, 2 ), B( 1, 3 ), WORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -887,7 +718,7 @@
 *
          IF( TSTCHK ) THEN
             CALL SCHKTZ( DOTYPE, NM, MVAL, NN, NVAL, THRESH, TSTERR,
-     $                   A( 1, 1 ), A( 1, 2 ), B( 1, 1 ),
+     $                   A( 1, 1 ), A( 1, 2 ), B( 1, 1 ), B( 1, 2 ),
      $                   B( 1, 3 ), WORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
@@ -904,7 +735,7 @@
             CALL SDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
      $                   NBVAL, NXVAL, THRESH, TSTERR, A( 1, 1 ),
      $                   A( 1, 2 ), B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                   RWORK, RWORK( NMAX+1 ), NOUT )
+     $                   RWORK, RWORK( NMAX+1 ), WORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
@@ -919,61 +750,6 @@
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'QT' ) ) THEN
-*
-*        QT:  QRT routines for general matrices
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKQRT( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                    NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'QX' ) ) THEN
-*
-*        QX:  QRT routines for triangular-pentagonal matrices
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKQRTP( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TQ' ) ) THEN
-*
-*        TQ:  LQT routines for general matrices
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKLQT( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                    NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'XQ' ) ) THEN
-*
-*        XQ:  LQT routines for triangular-pentagonal matrices
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKLQTP( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TS' ) ) THEN
-*
-*        TS:  QR routines for tall-skinny matrices
-*
-         IF( TSTCHK ) THEN
-            CALL SCHKTSQR( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
 *
       ELSE
 *
@@ -1000,7 +776,7 @@
  9995 FORMAT( ' Invalid input value: ', A4, '=', I6, '; must be <=',
      $      I6 )
  9994 FORMAT( ' Tests of the REAL LAPACK routines ',
-     $      / ' LAPACK VERSION ', I1, '.', I1, '.', I1,
+     $      / ' LAPACK VERSION 3.0, released June 30, 1999 ',
      $      / / ' The following parameter values will be used:' )
  9993 FORMAT( 4X, A4, ':  ', 10I6, / 11X, 10I6 )
  9992 FORMAT( / ' Routines pass computational tests if test ratio is ',
