@@ -1,124 +1,77 @@
-*> \brief \b ZCHKAA
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       PROGRAM ZCHKAA
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZCHKAA is the main test program for the COMPLEX*16 linear equation
-*> routines.
-*>
-*> The program must be driven by a short data file. The first 15 records
-*> (not including the first comment  line) specify problem dimensions
-*> and program options using list-directed input. The remaining lines
-*> specify the LAPACK test paths and the number of matrix types to use
-*> in testing.  An annotated example of a data file can be obtained by
-*> deleting the first 3 characters from the following 42 lines:
-*> Data file for testing COMPLEX*16 LAPACK linear equation routines
-*> 7                      Number of values of M
-*> 0 1 2 3 5 10 16        Values of M (row dimension)
-*> 7                      Number of values of N
-*> 0 1 2 3 5 10 16        Values of N (column dimension)
-*> 1                      Number of values of NRHS
-*> 2                      Values of NRHS (number of right hand sides)
-*> 5                      Number of values of NB
-*> 1 3 3 3 20             Values of NB (the blocksize)
-*> 1 0 5 9 1              Values of NX (crossover point)
-*> 3                      Number of values of RANK
-*> 30 50 90               Values of rank (as a % of N)
-*> 30.0                   Threshold value of test ratio
-*> T                      Put T to test the LAPACK routines
-*> T                      Put T to test the driver routines
-*> T                      Put T to test the error exits
-*> ZGE   11               List types on next line if 0 < NTYPES < 11
-*> ZGB    8               List types on next line if 0 < NTYPES <  8
-*> ZGT   12               List types on next line if 0 < NTYPES < 12
-*> ZPO    9               List types on next line if 0 < NTYPES <  9
-*> ZPS    9               List types on next line if 0 < NTYPES <  9
-*> ZPP    9               List types on next line if 0 < NTYPES <  9
-*> ZPB    8               List types on next line if 0 < NTYPES <  8
-*> ZPT   12               List types on next line if 0 < NTYPES < 12
-*> ZHE   10               List types on next line if 0 < NTYPES < 10
-*> ZHR   10               List types on next line if 0 < NTYPES < 10
-*> ZHK   10               List types on next line if 0 < NTYPES < 10
-*> ZHA   10               List types on next line if 0 < NTYPES < 10
-*> ZH2   10               List types on next line if 0 < NTYPES < 10
-*> ZSA   11               List types on next line if 0 < NTYPES < 10
-*> ZS2   11               List types on next line if 0 < NTYPES < 10
-*> ZHP   10               List types on next line if 0 < NTYPES < 10
-*> ZSY   11               List types on next line if 0 < NTYPES < 11
-*> ZSR   11               List types on next line if 0 < NTYPES < 11
-*> ZSK   11               List types on next line if 0 < NTYPES < 11
-*> ZSP   11               List types on next line if 0 < NTYPES < 11
-*> ZTR   18               List types on next line if 0 < NTYPES < 18
-*> ZTP   18               List types on next line if 0 < NTYPES < 18
-*> ZTB   17               List types on next line if 0 < NTYPES < 17
-*> ZQR    8               List types on next line if 0 < NTYPES <  8
-*> ZRQ    8               List types on next line if 0 < NTYPES <  8
-*> ZLQ    8               List types on next line if 0 < NTYPES <  8
-*> ZQL    8               List types on next line if 0 < NTYPES <  8
-*> ZQP    6               List types on next line if 0 < NTYPES <  6
-*> ZTZ    3               List types on next line if 0 < NTYPES <  3
-*> ZLS    6               List types on next line if 0 < NTYPES <  6
-*> ZEQ
-*> ZQT
-*> ZQX
-*> \endverbatim
-*
-*  Parameters:
-*  ==========
-*
-*> \verbatim
-*>  NMAX    INTEGER
-*>          The maximum allowable value for M and N.
-*>
-*>  MAXIN   INTEGER
-*>          The number of different values that can be used for each of
-*>          M, N, NRHS, NB, NX and RANK
-*>
-*>  MAXRHS  INTEGER
-*>          The maximum number of right hand sides
-*>
-*>  MATMAX  INTEGER
-*>          The maximum number of matrix types to use for testing
-*>
-*>  NIN     INTEGER
-*>          The unit number for input
-*>
-*>  NOUT    INTEGER
-*>          The unit number for output
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \date November 2017
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       PROGRAM ZCHKAA
 *
-*  -- LAPACK test routine (version 3.8.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2017
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
+*
+*  Purpose
+*  =======
+*
+*  ZCHKAA is the main test program for the COMPLEX*16 linear equation
+*  routines.
+*
+*  The program must be driven by a short data file. The first 14 records
+*  specify problem dimensions and program options using list-directed
+*  input.  The remaining lines specify the LAPACK test paths and the
+*  number of matrix types to use in testing.  An annotated example of a
+*  data file can be obtained by deleting the first 3 characters from the
+*  following 38 lines:
+*  Data file for testing COMPLEX*16 LAPACK linear equation routines
+*  7                      Number of values of M
+*  0 1 2 3 5 10 16        Values of M (row dimension)
+*  7                      Number of values of N
+*  0 1 2 3 5 10 16        Values of N (column dimension)
+*  1                      Number of values of NRHS
+*  2                      Values of NRHS (number of right hand sides)
+*  5                      Number of values of NB
+*  1 3 3 3 20             Values of NB (the blocksize)
+*  1 0 5 9 1              Values of NX (crossover point)
+*  30.0                   Threshold value of test ratio
+*  T                      Put T to test the LAPACK routines
+*  T                      Put T to test the driver routines
+*  T                      Put T to test the error exits
+*  ZGE   11               List types on next line if 0 < NTYPES < 11
+*  ZGB    8               List types on next line if 0 < NTYPES <  8
+*  ZGT   12               List types on next line if 0 < NTYPES < 12
+*  ZPO    9               List types on next line if 0 < NTYPES <  9
+*  ZPP    9               List types on next line if 0 < NTYPES <  9
+*  ZPB    8               List types on next line if 0 < NTYPES <  8
+*  ZPT   12               List types on next line if 0 < NTYPES < 12
+*  ZHE   10               List types on next line if 0 < NTYPES < 10
+*  ZHP   10               List types on next line if 0 < NTYPES < 10
+*  ZSY   11               List types on next line if 0 < NTYPES < 11
+*  ZSP   11               List types on next line if 0 < NTYPES < 11
+*  ZTR   18               List types on next line if 0 < NTYPES < 18
+*  ZTP   18               List types on next line if 0 < NTYPES < 18
+*  ZTB   17               List types on next line if 0 < NTYPES < 17
+*  ZQR    8               List types on next line if 0 < NTYPES <  8
+*  ZRQ    8               List types on next line if 0 < NTYPES <  8
+*  ZLQ    8               List types on next line if 0 < NTYPES <  8
+*  ZQL    8               List types on next line if 0 < NTYPES <  8
+*  ZQP    6               List types on next line if 0 < NTYPES <  6
+*  ZTZ    3               List types on next line if 0 < NTYPES <  3
+*  ZLS    6               List types on next line if 0 < NTYPES <  6
+*  ZEQ
+*
+*  Internal Parameters
+*  ===================
+*
+*  NMAX    INTEGER
+*          The maximum allowable value for N.
+*
+*  MAXIN   INTEGER
+*          The number of different values that can be used for each of
+*          M, N, or NB
+*
+*  MAXRHS  INTEGER
+*          The maximum number of right hand sides
+*
+*  NIN     INTEGER
+*          The unit number for input
+*
+*  NOUT    INTEGER
+*          The unit number for output
 *
 *  =====================================================================
 *
@@ -144,19 +97,17 @@
       CHARACTER*10       INTSTR
       CHARACTER*72       ALINE
       INTEGER            I, IC, J, K, LA, LAFAC, LDA, NB, NM, NMATS, NN,
-     $                   NNB, NNB2, NNS, NRHS, NTYPES, NRANK,
-     $                   VERS_MAJOR, VERS_MINOR, VERS_PATCH
+     $                   NNB, NNB2, NNS, NRHS, NTYPES
       DOUBLE PRECISION   EPS, S1, S2, THREQ, THRESH
 *     ..
 *     .. Local Arrays ..
       LOGICAL            DOTYPE( MATMAX )
       INTEGER            IWORK( 25*NMAX ), MVAL( MAXIN ),
      $                   NBVAL( MAXIN ), NBVAL2( MAXIN ),
-     $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN ),
-     $                   RANKVAL( MAXIN ), PIV( NMAX )
+     $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN )
       DOUBLE PRECISION   RWORK( 150*NMAX+2*MAXRHS ), S( 2*NMAX )
       COMPLEX*16         A( ( KDMAX+1 )*NMAX, 7 ), B( NMAX*MAXRHS, 4 ),
-     $                   E( NMAX ),  WORK( NMAX, NMAX+MAXRHS+10 )
+     $                   WORK( NMAX, NMAX+MAXRHS+10 )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME, LSAMEN
@@ -165,21 +116,15 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAREQ, ZCHKEQ, ZCHKGB, ZCHKGE, ZCHKGT, ZCHKHE,
-     $                   ZCHKHE_ROOK, ZCHKHE_RK, ZCHKHE_AA, ZCHKHP,
-     $                   ZCHKLQ, ZCHKPB, ZCHKPO, ZCHKPS, ZCHKPP, ZCHKPT,
-     $                   ZCHKQ3, ZCHKQL, ZCHKQR, ZCHKRQ, ZCHKSP, ZCHKSY,
-     $                   ZCHKSY_ROOK, ZCHKSY_RK, ZCHKSY_AA, ZCHKTB,
-     $                   ZCHKTP, ZCHKTR, ZCHKTZ, ZDRVGB, ZDRVGE, ZDRVGT,
-     $                   ZDRVHE, ZDRVHE_ROOK, ZDRVHE_RK, ZDRVHE_AA,
-     $                   ZDRVHE_AA_2STAGE, ZDRVHP, ZDRVLS, ZDRVPB, 
-     $                   ZDRVPO, ZDRVPP, ZDRVPT, ZDRVSP, ZDRVSY,
-     $                   ZDRVSY_ROOK, ZDRVSY_RK, ZDRVSY_AA,
-     $                   ZDRVSY_AA_2STAGE, ILAVER, ZCHKQRT, ZCHKQRTP,
-     $                   ZCHKLQT, ZCHKLQTP, ZCHKTSQR
+     $                   ZCHKHP, ZCHKLQ, ZCHKPB, ZCHKPO, ZCHKPP, ZCHKPT,
+     $                   ZCHKQ3, ZCHKQL, ZCHKQP, ZCHKQR, ZCHKRQ, ZCHKSP,
+     $                   ZCHKSY, ZCHKTB, ZCHKTP, ZCHKTR, ZCHKTZ, ZDRVGB,
+     $                   ZDRVGE, ZDRVGT, ZDRVHE, ZDRVHP, ZDRVLS, ZDRVPB,
+     $                   ZDRVPO, ZDRVPP, ZDRVPT, ZDRVSP, ZDRVSY
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Arrays in Common ..
@@ -205,8 +150,7 @@
 *
 *     Report values of parameters.
 *
-      CALL ILAVER( VERS_MAJOR, VERS_MINOR, VERS_PATCH )
-      WRITE( NOUT, FMT = 9994 ) VERS_MAJOR, VERS_MINOR, VERS_PATCH
+      WRITE( NOUT, FMT = 9994 )
 *
 *     Read the values of M
 *
@@ -330,32 +274,6 @@
       IF( NNB.GT.0 )
      $   WRITE( NOUT, FMT = 9993 )'NX  ', ( NXVAL( I ), I = 1, NNB )
 *
-*     Read the values of RANKVAL
-*
-      READ( NIN, FMT = * )NRANK
-      IF( NN.LT.1 ) THEN
-         WRITE( NOUT, FMT = 9996 )' NRANK ', NRANK, 1
-         NRANK = 0
-         FATAL = .TRUE.
-      ELSE IF( NN.GT.MAXIN ) THEN
-         WRITE( NOUT, FMT = 9995 )' NRANK ', NRANK, MAXIN
-         NRANK = 0
-         FATAL = .TRUE.
-      END IF
-      READ( NIN, FMT = * )( RANKVAL( I ), I = 1, NRANK )
-      DO I = 1, NRANK
-         IF( RANKVAL( I ).LT.0 ) THEN
-            WRITE( NOUT, FMT = 9996 )' RANK  ', RANKVAL( I ), 0
-            FATAL = .TRUE.
-         ELSE IF( RANKVAL( I ).GT.100 ) THEN
-            WRITE( NOUT, FMT = 9995 )' RANK  ', RANKVAL( I ), 100
-            FATAL = .TRUE.
-         END IF
-      END DO
-      IF( NRANK.GT.0 )
-     $   WRITE( NOUT, FMT = 9993 )'RANK % OF N',
-     $   ( RANKVAL( I ), I = 1, NRANK )
-*
 *     Read the threshold value for the test ratios.
 *
       READ( NIN, FMT = * )THRESH
@@ -533,23 +451,6 @@
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'PS' ) ) THEN
-*
-*        PS:  positive semi-definite matrices
-*
-         NTYPES = 9
-*
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKPS( DOTYPE, NN, NVAL, NNB2, NBVAL2, NRANK,
-     $                   RANKVAL, THRESH, TSTERR, LDA, A( 1, 1 ),
-     $                   A( 1, 2 ), A( 1, 3 ), PIV, WORK, RWORK,
-     $                   NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'PP' ) ) THEN
 *
@@ -648,115 +549,6 @@
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
-
-      ELSE IF( LSAMEN( 2, C2, 'HR' ) ) THEN
-*
-*        HR:  Hermitian indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm,
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKHE_ROOK(DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                       THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                       A( 1, 3 ), B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                       WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVHE_ROOK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                        LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                        B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                        RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'HK' ) ) THEN
-*
-*        HK:  Hermitian indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm,
-*             differnet matrix storage format than HR path version.
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKHE_RK ( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                       THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                       E, A( 1, 3 ), B( 1, 1 ), B( 1, 2 ),
-     $                       B( 1, 3 ), WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVHE_RK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                      LDA, A( 1, 1 ), A( 1, 2 ), E, A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                      RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'HA' ) ) THEN
-*
-*        HA:  Hermitian matrices,
-*             Aasen Algorithm
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKHE_AA( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS,
-     $                         NSVAL, THRESH, TSTERR, LDA,
-     $                         A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                         B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVHE_AA( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                         LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                              B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'H2' ) ) THEN
-*
-*        H2:  Hermitian matrices,
-*             with partial (Aasen's) pivoting algorithm
-*
-         NTYPES = 10
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKHE_AA_2STAGE( DOTYPE, NN, NVAL, NNB2, NBVAL2,
-     $                         NNS, NSVAL, THRESH, TSTERR, LDA,
-     $                         A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                         B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVHE_AA_2STAGE(
-     $                         DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                         LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                              B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                         WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
 *
       ELSE IF( LSAMEN( 2, C2, 'HP' ) ) THEN
 *
@@ -785,8 +577,7 @@
 *
       ELSE IF( LSAMEN( 2, C2, 'SY' ) ) THEN
 *
-*        SY:  symmetric indefinite matrices,
-*             with partial (Bunch-Kaufman) pivoting algorithm
+*        SY:  symmetric indefinite matrices
 *
          NTYPES = 11
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
@@ -808,117 +599,10 @@
          ELSE
             WRITE( NOUT, FMT = 9988 )PATH
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SR' ) ) THEN
-*
-*        SR:  symmetric indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm
-*
-         NTYPES = 11
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKSY_ROOK(DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                       THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                       A( 1, 3 ), B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                       WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVSY_ROOK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                        LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                        B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                        RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SK' ) ) THEN
-*
-*        SK:  symmetric indefinite matrices,
-*             with bounded Bunch-Kaufman (rook) pivoting algorithm,
-*             differnet matrix storage format than SR path version.
-*
-         NTYPES = 11
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKSY_RK( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                      THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                      E, A( 1, 3 ), B( 1, 1 ), B( 1, 2 ),
-     $                      B( 1, 3 ), WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVSY_RK( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                      LDA, A( 1, 1 ), A( 1, 2 ), E, A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                      RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'SA' ) ) THEN
-*
-*        SA:  symmetric indefinite matrices with Aasen's algorithm,
-*
-         NTYPES = 11
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKSY_AA( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS, NSVAL,
-     $                      THRESH, TSTERR, LDA, A( 1, 1 ), A( 1, 2 ),
-     $                      A( 1, 3 ), B( 1, 1 ), B( 1, 2 ),
-     $                      B( 1, 3 ), WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVSY_AA( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                      LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                      RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'S2' ) ) THEN
-*
-*        S2:  symmetric indefinite matrices with Aasen's algorithm
-*             2 stage
-*
-         NTYPES = 11
-         CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKSY_AA_2STAGE( DOTYPE, NN, NVAL, NNB2, NBVAL2, NNS,
-     $                      NSVAL, THRESH, TSTERR, LDA,
-     $                      A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ),
-     $                      WORK, RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-         IF( TSTDRV ) THEN
-            CALL ZDRVSY_AA_2STAGE(
-     $                      DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR,
-     $                      LDA, A( 1, 1 ), A( 1, 2 ), A( 1, 3 ),
-     $                      B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), WORK,
-     $                      RWORK, IWORK, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9988 )PATH
-         END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'SP' ) ) THEN
 *
-*        SP:  symmetric indefinite packed matrices,
-*             with partial (Bunch-Kaufman) pivoting algorithm
+*        SP:  symmetric indefinite packed matrices
 *
          NTYPES = 11
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
@@ -1016,7 +700,7 @@
      $                   NRHS, THRESH, TSTERR, NMAX, A( 1, 1 ),
      $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
      $                   B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), B( 1, 4 ),
-     $                   WORK, RWORK, NOUT )
+     $                   WORK, RWORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -1033,7 +717,7 @@
      $                   NRHS, THRESH, TSTERR, NMAX, A( 1, 1 ),
      $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
      $                   B( 1, 1 ), B( 1, 2 ), B( 1, 3 ), B( 1, 4 ),
-     $                   WORK, RWORK, NOUT )
+     $                   WORK, RWORK, IWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -1075,7 +759,7 @@
 *
          IF( TSTCHK ) THEN
             CALL ZCHKTZ( DOTYPE, NM, MVAL, NN, NVAL, THRESH, TSTERR,
-     $                   A( 1, 1 ), A( 1, 2 ), S( 1 ),
+     $                   A( 1, 1 ), A( 1, 2 ), S( 1 ), S( NMAX+1 ),
      $                   B( 1, 1 ), WORK, RWORK, NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
@@ -1089,9 +773,12 @@
          CALL ALAREQ( PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT )
 *
          IF( TSTCHK ) THEN
+            CALL ZCHKQP( DOTYPE, NM, MVAL, NN, NVAL, THRESH, TSTERR,
+     $                   A( 1, 1 ), A( 1, 2 ), S( 1 ), S( NMAX+1 ),
+     $                   B( 1, 1 ), WORK, RWORK, IWORK, NOUT )
             CALL ZCHKQ3( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NXVAL,
      $                   THRESH, A( 1, 1 ), A( 1, 2 ), S( 1 ),
-     $                   B( 1, 1 ), WORK, RWORK, IWORK,
+     $                   S( NMAX+1 ), B( 1, 1 ), WORK, RWORK, IWORK,
      $                   NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
@@ -1108,96 +795,8 @@
             CALL ZDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
      $                   NBVAL, NXVAL, THRESH, TSTERR, A( 1, 1 ),
      $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
-     $                   S( 1 ), S( NMAX+1 ), NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-*
-      ELSE IF( LSAMEN( 2, C2, 'QT' ) ) THEN
-*
-*        QT:  QRT routines for general matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKQRT( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                    NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'QX' ) ) THEN
-*
-*        QX:  QRT routines for triangular-pentagonal matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKQRTP( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TQ' ) ) THEN
-*
-*        TQ:  LQT routines for general matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKLQT( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                    NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'XQ' ) ) THEN
-*
-*        XQ:  LQT routines for triangular-pentagonal matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKLQTP( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TS' ) ) THEN
-*
-*        TS:  QR routines for tall-skinny matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKTSQR( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TQ' ) ) THEN
-*
-*        TQ:  LQT routines for general matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKLQT( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                    NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'XQ' ) ) THEN
-*
-*        XQ:  LQT routines for triangular-pentagonal matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKLQTP( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
-         ELSE
-            WRITE( NOUT, FMT = 9989 )PATH
-         END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'TS' ) ) THEN
-*
-*        TS:  QR routines for tall-skinny matrices
-*
-         IF( TSTCHK ) THEN
-            CALL ZCHKTSQR( THRESH, TSTERR, NM, MVAL, NN, NVAL, NNB,
-     $                     NBVAL, NOUT )
+     $                   S( 1 ), S( NMAX+1 ), WORK, RWORK, IWORK,
+     $                   NOUT )
          ELSE
             WRITE( NOUT, FMT = 9989 )PATH
          END IF
@@ -1227,7 +826,7 @@
  9995 FORMAT( ' Invalid input value: ', A4, '=', I6, '; must be <=',
      $      I6 )
  9994 FORMAT( ' Tests of the COMPLEX*16 LAPACK routines ',
-     $      / ' LAPACK VERSION ', I1, '.', I1, '.', I1,
+     $      / ' LAPACK VERSION 3.0, released June 30, 1999 ',
      $      / / ' The following parameter values will be used:' )
  9993 FORMAT( 4X, A4, ':  ', 10I6, / 11X, 10I6 )
  9992 FORMAT( / ' Routines pass computational tests if test ratio is ',
