@@ -1,192 +1,11 @@
-*> \brief \b ZCHKGE
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
-*                          NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
-*                          X, XACT, WORK, RWORK, IWORK, NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NM, NMAX, NN, NNB, NNS, NOUT
-*       DOUBLE PRECISION   THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
-*      $                   NVAL( * )
-*       DOUBLE PRECISION   RWORK( * )
-*       COMPLEX*16         A( * ), AFAC( * ), AINV( * ), B( * ),
-*      $                   WORK( * ), X( * ), XACT( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZCHKGE tests ZGETRF, -TRI, -TRS, -RFS, and -CON.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NM
-*> \verbatim
-*>          NM is INTEGER
-*>          The number of values of M contained in the vector MVAL.
-*> \endverbatim
-*>
-*> \param[in] MVAL
-*> \verbatim
-*>          MVAL is INTEGER array, dimension (NM)
-*>          The values of the matrix row dimension M.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix column dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNB
-*> \verbatim
-*>          NNB is INTEGER
-*>          The number of values of NB contained in the vector NBVAL.
-*> \endverbatim
-*>
-*> \param[in] NBVAL
-*> \verbatim
-*>          NBVAL is INTEGER array, dimension (NNB)
-*>          The values of the blocksize NB.
-*> \endverbatim
-*>
-*> \param[in] NNS
-*> \verbatim
-*>          NNS is INTEGER
-*>          The number of values of NRHS contained in the vector NSVAL.
-*> \endverbatim
-*>
-*> \param[in] NSVAL
-*> \verbatim
-*>          NSVAL is INTEGER array, dimension (NNS)
-*>          The values of the number of right hand sides NRHS.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is DOUBLE PRECISION
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The maximum value permitted for M or N, used in dimensioning
-*>          the work arrays.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AFAC
-*> \verbatim
-*>          AFAC is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AINV
-*> \verbatim
-*>          AINV is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*>          where NSMAX is the largest entry in NSVAL.
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX*16 array, dimension
-*>                      (NMAX*max(3,NSMAX))
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension
-*>                      (max(2*NMAX,2*NSMAX+NWORK))
-*> \endverbatim
-*>
-*> \param[out] IWORK
-*> \verbatim
-*>          IWORK is INTEGER array, dimension (NMAX)
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
      $                   NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
      $                   X, XACT, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -202,6 +21,83 @@
      $                   WORK( * ), X( * ), XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZCHKGE tests ZGETRF, -TRI, -TRS, -RFS, and -CON.
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NM      (input) INTEGER
+*          The number of values of M contained in the vector MVAL.
+*
+*  MVAL    (input) INTEGER array, dimension (NM)
+*          The values of the matrix row dimension M.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix column dimension N.
+*
+*  NNB     (input) INTEGER
+*          The number of values of NB contained in the vector NBVAL.
+*
+*  NBVAL   (input) INTEGER array, dimension (NBVAL)
+*          The values of the blocksize NB.
+*
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
+*  NRHS    (input) INTEGER
+*          The number of right hand side vectors to be generated for
+*          each linear system.
+*
+*  THRESH  (input) DOUBLE PRECISION
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The maximum value permitted for M or N, used in dimensioning
+*          the work arrays.
+*
+*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AINV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
+*
+*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  WORK    (workspace) COMPLEX*16 array, dimension
+*                      (NMAX*max(3,NSMAX))
+*
+*  RWORK   (workspace) DOUBLE PRECISION array, dimension
+*                      (max(2*NMAX,2*NSMAX+NWORK))
+*
+*  IWORK   (workspace) INTEGER array, dimension (NMAX)
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -244,7 +140,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -270,7 +166,6 @@
 *
 *     Test the error exits
 *
-      CALL XLAENV( 1, 1 )
       IF( TSTERR )
      $   CALL ZERRGE( PATH, NOUT )
       INFOT = 0
@@ -516,7 +411,7 @@
                         CALL ZGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
      $                               RESULT( 5 ) )
                         CALL ZGET07( TRANS, N, NRHS, A, LDA, B, LDA, X,
-     $                               LDA, XACT, LDA, RWORK, .TRUE.,
+     $                               LDA, XACT, LDA, RWORK,
      $                               RWORK( NRHS+1 ), RESULT( 6 ) )
 *
 *                       Print information about the tests that did not
@@ -572,7 +467,7 @@
                      IF( RESULT( 8 ).GE.THRESH ) THEN
                         IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                     CALL ALAHD( NOUT, PATH )
-                        WRITE( NOUT, FMT = 9997 )NORM, N, IMAT, 8,
+                        WRITE( NOUT, FMT = 9997 )NORM, N, NB, IMAT, 8,
      $                     RESULT( 8 )
                         NFAIL = NFAIL + 1
                      END IF
@@ -589,11 +484,11 @@
       CALL ALASUM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
  9999 FORMAT( ' M = ', I5, ', N =', I5, ', NB =', I4, ', type ', I2,
-     $      ', test(', I2, ') =', G12.5 )
- 9998 FORMAT( ' TRANS=''', A1, ''', N =', I5, ', NRHS=', I3, ', type ',
-     $      I2, ', test(', I2, ') =', G12.5 )
- 9997 FORMAT( ' NORM =''', A1, ''', N =', I5, ',', 10X, ' type ', I2,
-     $      ', test(', I2, ') =', G12.5 )
+     $      ', test ', I2, ', ratio =', G12.5 )
+ 9998 FORMAT( ' TRANS=''', A1, ''', N =', I5, ', NB =', I4, ', type ',
+     $      I2, ', test ', I2, ', ratio =', G12.5 )
+ 9997 FORMAT( ' NORM =''', A1, ''', N =', I5, ', NB =', I4, ', type ',
+     $      I2, ', test ', I2, ', ratio =', G12.5 )
       RETURN
 *
 *     End of ZCHKGE
