@@ -1,205 +1,11 @@
-*> \brief \b ZCHKLQ
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZCHKLQ( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NXVAL,
-*                          NRHS, THRESH, TSTERR, NMAX, A, AF, AQ, AL, AC,
-*                          B, X, XACT, TAU, WORK, RWORK, NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NM, NMAX, NN, NNB, NOUT, NRHS
-*       DOUBLE PRECISION   THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            MVAL( * ), NBVAL( * ), NVAL( * ),
-*      $                   NXVAL( * )
-*       DOUBLE PRECISION   RWORK( * )
-*       COMPLEX*16         A( * ), AC( * ), AF( * ), AL( * ), AQ( * ),
-*      $                   B( * ), TAU( * ), WORK( * ), X( * ), XACT( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZCHKLQ tests ZGELQF, ZUNGLQ and CUNMLQ.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NM
-*> \verbatim
-*>          NM is INTEGER
-*>          The number of values of M contained in the vector MVAL.
-*> \endverbatim
-*>
-*> \param[in] MVAL
-*> \verbatim
-*>          MVAL is INTEGER array, dimension (NM)
-*>          The values of the matrix row dimension M.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix column dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNB
-*> \verbatim
-*>          NNB is INTEGER
-*>          The number of values of NB and NX contained in the
-*>          vectors NBVAL and NXVAL.  The blocking parameters are used
-*>          in pairs (NB,NX).
-*> \endverbatim
-*>
-*> \param[in] NBVAL
-*> \verbatim
-*>          NBVAL is INTEGER array, dimension (NNB)
-*>          The values of the blocksize NB.
-*> \endverbatim
-*>
-*> \param[in] NXVAL
-*> \verbatim
-*>          NXVAL is INTEGER array, dimension (NNB)
-*>          The values of the crossover point NX.
-*> \endverbatim
-*>
-*> \param[in] NRHS
-*> \verbatim
-*>          NRHS is INTEGER
-*>          The number of right hand side vectors to be generated for
-*>          each linear system.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is DOUBLE PRECISION
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The maximum value permitted for M or N, used in dimensioning
-*>          the work arrays.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AF
-*> \verbatim
-*>          AF is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AQ
-*> \verbatim
-*>          AQ is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AL
-*> \verbatim
-*>          AL is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AC
-*> \verbatim
-*>          AC is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX*16 array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX*16 array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX*16 array, dimension (NMAX*NRHS)
-*> \endverbatim
-*>
-*> \param[out] TAU
-*> \verbatim
-*>          TAU is COMPLEX*16 array, dimension (NMAX)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension (NMAX)
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \date December 2016
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZCHKLQ( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NXVAL,
      $                   NRHS, THRESH, TSTERR, NMAX, A, AF, AQ, AL, AC,
-     $                   B, X, XACT, TAU, WORK, RWORK, NOUT )
+     $                   B, X, XACT, TAU, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 3.7.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -208,13 +14,92 @@
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            MVAL( * ), NBVAL( * ), NVAL( * ),
+      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NVAL( * ),
      $                   NXVAL( * )
       DOUBLE PRECISION   RWORK( * )
       COMPLEX*16         A( * ), AC( * ), AF( * ), AL( * ), AQ( * ),
      $                   B( * ), TAU( * ), WORK( * ), X( * ), XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZCHKLQ tests ZGELQF, ZUNGLQ and CUNMLQ.
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NM      (input) INTEGER
+*          The number of values of M contained in the vector MVAL.
+*
+*  MVAL    (input) INTEGER array, dimension (NM)
+*          The values of the matrix row dimension M.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix column dimension N.
+*
+*  NNB     (input) INTEGER
+*          The number of values of NB and NX contained in the
+*          vectors NBVAL and NXVAL.  The blocking parameters are used
+*          in pairs (NB,NX).
+*
+*  NBVAL   (input) INTEGER array, dimension (NNB)
+*          The values of the blocksize NB.
+*
+*  NXVAL   (input) INTEGER array, dimension (NNB)
+*          The values of the crossover point NX.
+*
+*  NRHS    (input) INTEGER
+*          The number of right hand side vectors to be generated for
+*          each linear system.
+*
+*  THRESH  (input) DOUBLE PRECISION
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The maximum value permitted for M or N, used in dimensioning
+*          the work arrays.
+*
+*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AF      (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AQ      (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AL      (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AC      (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
+*
+*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
+*
+*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
+*
+*  TAU     (workspace) COMPLEX*16 array, dimension (NMAX)
+*
+*  WORK    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX)
+*
+*  IWORK   (workspace) INTEGER array, dimension (NMAX)
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -247,7 +132,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -346,9 +231,6 @@
                      CALL XLAENV( 1, NB )
                      NX = NXVAL( INB )
                      CALL XLAENV( 3, NX )
-                     DO I = 1, NTESTS
-                        RESULT( I ) = ZERO
-                     END DO
                      NT = 2
                      IF( IK.EQ.1 ) THEN
 *
@@ -363,6 +245,9 @@
 *
                         CALL ZLQT02( M, N, K, A, AF, AQ, AL, LDA, TAU,
      $                               WORK, LWORK, RWORK, RESULT( 1 ) )
+                     ELSE
+                        RESULT( 1 ) = ZERO
+                        RESULT( 2 ) = ZERO
                      END IF
                      IF( M.GE.K ) THEN
 *
@@ -405,7 +290,14 @@
      $                                  LDA, X, LDA, B, LDA, RWORK,
      $                                  RESULT( 7 ) )
                            NT = NT + 1
+                        ELSE
+                           RESULT( 7 ) = ZERO
                         END IF
+                     ELSE
+                        RESULT( 3 ) = ZERO
+                        RESULT( 4 ) = ZERO
+                        RESULT( 5 ) = ZERO
+                        RESULT( 6 ) = ZERO
                      END IF
 *
 *                    Print information about the tests that did not
