@@ -1,177 +1,11 @@
-*> \brief \b ZCHKPO
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZCHKPO( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
-*                          THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
-*                          XACT, WORK, RWORK, NOUT )
-* 
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NMAX, NN, NNB, NNS, NOUT
-*       DOUBLE PRECISION   THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            NBVAL( * ), NSVAL( * ), NVAL( * )
-*       DOUBLE PRECISION   RWORK( * )
-*       COMPLEX*16         A( * ), AFAC( * ), AINV( * ), B( * ),
-*      $                   WORK( * ), X( * ), XACT( * )
-*       ..
-*  
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZCHKPO tests ZPOTRF, -TRI, -TRS, -RFS, and -CON
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNB
-*> \verbatim
-*>          NNB is INTEGER
-*>          The number of values of NB contained in the vector NBVAL.
-*> \endverbatim
-*>
-*> \param[in] NBVAL
-*> \verbatim
-*>          NBVAL is INTEGER array, dimension (NBVAL)
-*>          The values of the blocksize NB.
-*> \endverbatim
-*>
-*> \param[in] NNS
-*> \verbatim
-*>          NNS is INTEGER
-*>          The number of values of NRHS contained in the vector NSVAL.
-*> \endverbatim
-*>
-*> \param[in] NSVAL
-*> \verbatim
-*>          NSVAL is INTEGER array, dimension (NNS)
-*>          The values of the number of right hand sides NRHS.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is DOUBLE PRECISION
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The maximum value permitted for N, used in dimensioning the
-*>          work arrays.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AFAC
-*> \verbatim
-*>          AFAC is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] AINV
-*> \verbatim
-*>          AINV is COMPLEX*16 array, dimension (NMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*>          where NSMAX is the largest entry in NSVAL.
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX*16 array, dimension
-*>                      (NMAX*max(3,NSMAX))
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension
-*>                      (NMAX+2*NSMAX)
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
-*
-*> \date November 2011
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZCHKPO( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
      $                   THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
      $                   XACT, WORK, RWORK, NOUT )
 *
-*  -- LAPACK test routine (version 3.4.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2011
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     September 30, 1994
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -186,6 +20,71 @@
      $                   WORK( * ), X( * ), XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZCHKPO tests ZPOTRF, -TRI, -TRS, -RFS, and -CON
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix dimension N.
+*
+*  NNB     (input) INTEGER
+*          The number of values of NB contained in the vector NBVAL.
+*
+*  NBVAL   (input) INTEGER array, dimension (NBVAL)
+*          The values of the blocksize NB.
+*
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
+*  THRESH  (input) DOUBLE PRECISION
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The maximum value permitted for N, used in dimensioning the
+*          work arrays.
+*
+*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  AINV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
+*
+*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
+*
+*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  WORK    (workspace) COMPLEX*16 array, dimension
+*                      (NMAX*max(3,NSMAX))
+*
+*  RWORK   (workspace) DOUBLE PRECISION array, dimension
+*                      (max(NMAX,2*NSMAX))
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -222,7 +121,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -425,6 +324,7 @@
                      CALL ZLARHS( PATH, XTYPE, UPLO, ' ', N, N, KL, KU,
      $                            NRHS, A, LDA, XACT, LDA, B, LDA,
      $                            ISEED, INFO )
+                     XTYPE = 'C'
                      CALL ZLACPY( 'Full', N, NRHS, B, LDA, X, LDA )
 *
                      SRNAMT = 'ZPOTRS'
