@@ -1,160 +1,11 @@
-*> \brief \b ZCHKTP
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZCHKTP( DOTYPE, NN, NVAL, NNS, NSVAL, THRESH, TSTERR,
-*                          NMAX, AP, AINVP, B, X, XACT, WORK, RWORK,
-*                          NOUT )
-*
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NMAX, NN, NNS, NOUT
-*       DOUBLE PRECISION   THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            NSVAL( * ), NVAL( * )
-*       DOUBLE PRECISION   RWORK( * )
-*       COMPLEX*16         AINVP( * ), AP( * ), B( * ), WORK( * ), X( * ),
-*      $                   XACT( * )
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZCHKTP tests ZTPTRI, -TRS, -RFS, and -CON, and ZLATPS
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix column dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNS
-*> \verbatim
-*>          NNS is INTEGER
-*>          The number of values of NRHS contained in the vector NSVAL.
-*> \endverbatim
-*>
-*> \param[in] NSVAL
-*> \verbatim
-*>          NSVAL is INTEGER array, dimension (NNS)
-*>          The values of the number of right hand sides NRHS.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is DOUBLE PRECISION
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[in] NMAX
-*> \verbatim
-*>          NMAX is INTEGER
-*>          The leading dimension of the work arrays.  NMAX >= the
-*>          maximumm value of N in NVAL.
-*> \endverbatim
-*>
-*> \param[out] AP
-*> \verbatim
-*>          AP is COMPLEX*16 array, dimension (NMAX*(NMAX+1)/2)
-*> \endverbatim
-*>
-*> \param[out] AINVP
-*> \verbatim
-*>          AINVP is COMPLEX*16 array, dimension (NMAX*(NMAX+1)/2)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*>          where NSMAX is the largest entry in NSVAL.
-*> \endverbatim
-*>
-*> \param[out] X
-*> \verbatim
-*>          X is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] XACT
-*> \verbatim
-*>          XACT is COMPLEX*16 array, dimension (NMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX*16 array, dimension
-*>                      (NMAX*max(3,NSMAX))
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension
-*>                      (max(NMAX,2*NSMAX))
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \date December 2016
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZCHKTP( DOTYPE, NN, NVAL, NNS, NSVAL, THRESH, TSTERR,
      $                   NMAX, AP, AINVP, B, X, XACT, WORK, RWORK,
      $                   NOUT )
 *
-*  -- LAPACK test routine (version 3.7.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -169,6 +20,63 @@
      $                   XACT( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZCHKTP tests ZTPTRI, -TRS, -RFS, and -CON, and ZLATPS
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix column dimension N.
+*
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
+*  THRESH  (input) DOUBLE PRECISION
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  NMAX    (input) INTEGER
+*          The leading dimension of the work arrays.  NMAX >= the
+*          maximumm value of N in NVAL.
+*
+*  AP      (workspace) COMPLEX*16 array, dimension (NMAX*(NMAX+1)/2)
+*
+*  AINVP   (workspace) COMPLEX*16 array, dimension (NMAX*(NMAX+1)/2)
+*
+*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
+*
+*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NSMAX)
+*
+*  WORK    (workspace) COMPLEX*16 array, dimension
+*                      (NMAX*max(3,NSMAX))
+*
+*  RWORK   (workspace) DOUBLE PRECISION array, dimension
+*                      (max(NMAX,2*NSMAX))
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -207,7 +115,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, IOUNIT
 *     ..
 *     .. Common blocks ..
@@ -311,7 +219,7 @@
                IF( RESULT( 1 ).GE.THRESH ) THEN
                   IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $               CALL ALAHD( NOUT, PATH )
-                  WRITE( NOUT, FMT = 9999 )UPLO, DIAG, N, IMAT, 1,
+                  WRITE( NOUT, FMT = 9999 )UPLO, N, IMAT, 1,
      $               RESULT( 1 )
                   NFAIL = NFAIL + 1
                END IF
@@ -395,8 +303,8 @@
                         IF( RESULT( K ).GE.THRESH ) THEN
                            IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                        CALL ALAHD( NOUT, PATH )
-                           WRITE( NOUT, FMT = 9998 )UPLO, TRANS, DIAG,
-     $                        N, NRHS, IMAT, K, RESULT( K )
+                           WRITE( NOUT, FMT = 9998 )UPLO, TRANS, N,
+     $                        NRHS, IMAT, K, RESULT( K )
                            NFAIL = NFAIL + 1
                         END IF
    20                CONTINUE
@@ -434,8 +342,8 @@
                   IF( RESULT( 7 ).GE.THRESH ) THEN
                      IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9997 ) 'ZTPCON', NORM, UPLO,
-     $                  DIAG, N, IMAT, 7, RESULT( 7 )
+                     WRITE( NOUT, FMT = 9997 )NORM, UPLO, N, IMAT, 7,
+     $                  RESULT( 7 )
                      NFAIL = NFAIL + 1
                   END IF
                   NRUN = NRUN + 1
@@ -533,14 +441,13 @@
 *
       CALL ALASUM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( ' UPLO=''', A1, ''', DIAG=''', A1, ''', N=', I5,
+ 9999 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', N=', I5,
      $      ', type ', I2, ', test(', I2, ')= ', G12.5 )
- 9998 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', DIAG=''', A1,
-     $      ''', N=', I5, ''', NRHS=', I5, ', type ', I2, ', test(',
-     $      I2, ')= ', G12.5 )
- 9997 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ''', A1, ''',',
-     $      I5, ', ... ), type ', I2, ', test(', I2, ')=', G12.5 )
- 9996 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
+ 9998 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
+     $      A1, ''',', I5, ', ... ), type ', I2, ', ratio =', G12.5 )
+ 9997 FORMAT( ' NORM=''', A1, ''', UPLO =''', A1, ''', N=', I5, ',',
+     $      11X, ' type ', I2, ', test(', I2, ')=', G12.5 )
+ 9996 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
      $      A1, ''',', I5, ', ... ), type ', I2, ', test(', I2, ')=',
      $      G12.5 )
       RETURN
