@@ -1,218 +1,11 @@
-*> \brief \b ZDRVLS
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
-*                          NBVAL, NXVAL, THRESH, TSTERR, A, COPYA, B,
-*                          COPYB, C, S, COPYS, WORK, RWORK, IWORK, NOUT )
-* 
-*       .. Scalar Arguments ..
-*       LOGICAL            TSTERR
-*       INTEGER            NM, NN, NNB, NNS, NOUT
-*       DOUBLE PRECISION   THRESH
-*       ..
-*       .. Array Arguments ..
-*       LOGICAL            DOTYPE( * )
-*       INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
-*      $                   NVAL( * ), NXVAL( * )
-*       DOUBLE PRECISION   COPYS( * ), RWORK( * ), S( * )
-*       COMPLEX*16         A( * ), B( * ), C( * ), COPYA( * ), COPYB( * ),
-*      $                   WORK( * )
-*       ..
-*  
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZDRVLS tests the least squares driver routines ZGELS, CGELSS, ZGELSY
-*> and CGELSD.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] DOTYPE
-*> \verbatim
-*>          DOTYPE is LOGICAL array, dimension (NTYPES)
-*>          The matrix types to be used for testing.  Matrices of type j
-*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*>          The matrix of type j is generated as follows:
-*>          j=1: A = U*D*V where U and V are random unitary matrices
-*>               and D has random entries (> 0.1) taken from a uniform
-*>               distribution (0,1). A is full rank.
-*>          j=2: The same of 1, but A is scaled up.
-*>          j=3: The same of 1, but A is scaled down.
-*>          j=4: A = U*D*V where U and V are random unitary matrices
-*>               and D has 3*min(M,N)/4 random entries (> 0.1) taken
-*>               from a uniform distribution (0,1) and the remaining
-*>               entries set to 0. A is rank-deficient.
-*>          j=5: The same of 4, but A is scaled up.
-*>          j=6: The same of 5, but A is scaled down.
-*> \endverbatim
-*>
-*> \param[in] NM
-*> \verbatim
-*>          NM is INTEGER
-*>          The number of values of M contained in the vector MVAL.
-*> \endverbatim
-*>
-*> \param[in] MVAL
-*> \verbatim
-*>          MVAL is INTEGER array, dimension (NM)
-*>          The values of the matrix row dimension M.
-*> \endverbatim
-*>
-*> \param[in] NN
-*> \verbatim
-*>          NN is INTEGER
-*>          The number of values of N contained in the vector NVAL.
-*> \endverbatim
-*>
-*> \param[in] NVAL
-*> \verbatim
-*>          NVAL is INTEGER array, dimension (NN)
-*>          The values of the matrix column dimension N.
-*> \endverbatim
-*>
-*> \param[in] NNB
-*> \verbatim
-*>          NNB is INTEGER
-*>          The number of values of NB and NX contained in the
-*>          vectors NBVAL and NXVAL.  The blocking parameters are used
-*>          in pairs (NB,NX).
-*> \endverbatim
-*>
-*> \param[in] NBVAL
-*> \verbatim
-*>          NBVAL is INTEGER array, dimension (NNB)
-*>          The values of the blocksize NB.
-*> \endverbatim
-*>
-*> \param[in] NXVAL
-*> \verbatim
-*>          NXVAL is INTEGER array, dimension (NNB)
-*>          The values of the crossover point NX.
-*> \endverbatim
-*>
-*> \param[in] NNS
-*> \verbatim
-*>          NNS is INTEGER
-*>          The number of values of NRHS contained in the vector NSVAL.
-*> \endverbatim
-*>
-*> \param[in] NSVAL
-*> \verbatim
-*>          NSVAL is INTEGER array, dimension (NNS)
-*>          The values of the number of right hand sides NRHS.
-*> \endverbatim
-*>
-*> \param[in] THRESH
-*> \verbatim
-*>          THRESH is DOUBLE PRECISION
-*>          The threshold value for the test ratios.  A result is
-*>          included in the output file if RESULT >= THRESH.  To have
-*>          every test ratio printed, use THRESH = 0.
-*> \endverbatim
-*>
-*> \param[in] TSTERR
-*> \verbatim
-*>          TSTERR is LOGICAL
-*>          Flag that indicates whether error exits are to be tested.
-*> \endverbatim
-*>
-*> \param[out] A
-*> \verbatim
-*>          A is COMPLEX*16 array, dimension (MMAX*NMAX)
-*>          where MMAX is the maximum value of M in MVAL and NMAX is the
-*>          maximum value of N in NVAL.
-*> \endverbatim
-*>
-*> \param[out] COPYA
-*> \verbatim
-*>          COPYA is COMPLEX*16 array, dimension (MMAX*NMAX)
-*> \endverbatim
-*>
-*> \param[out] B
-*> \verbatim
-*>          B is COMPLEX*16 array, dimension (MMAX*NSMAX)
-*>          where MMAX is the maximum value of M in MVAL and NSMAX is the
-*>          maximum value of NRHS in NSVAL.
-*> \endverbatim
-*>
-*> \param[out] COPYB
-*> \verbatim
-*>          COPYB is COMPLEX*16 array, dimension (MMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] C
-*> \verbatim
-*>          C is COMPLEX*16 array, dimension (MMAX*NSMAX)
-*> \endverbatim
-*>
-*> \param[out] S
-*> \verbatim
-*>          S is DOUBLE PRECISION array, dimension
-*>                      (min(MMAX,NMAX))
-*> \endverbatim
-*>
-*> \param[out] COPYS
-*> \verbatim
-*>          COPYS is DOUBLE PRECISION array, dimension
-*>                      (min(MMAX,NMAX))
-*> \endverbatim
-*>
-*> \param[out] WORK
-*> \verbatim
-*>          WORK is COMPLEX*16 array, dimension
-*>                      (MMAX*NMAX + 4*NMAX + MMAX).
-*> \endverbatim
-*>
-*> \param[out] RWORK
-*> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension (5*NMAX-1)
-*> \endverbatim
-*>
-*> \param[out] IWORK
-*> \verbatim
-*>          IWORK is INTEGER array, dimension (15*NMAX)
-*> \endverbatim
-*>
-*> \param[in] NOUT
-*> \verbatim
-*>          NOUT is INTEGER
-*>          The unit number for output.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
-*
-*> \date November 2015
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
      $                   NBVAL, NXVAL, THRESH, TSTERR, A, COPYA, B,
      $                   COPYB, C, S, COPYS, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -228,13 +21,104 @@
      $                   WORK( * )
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZDRVLS tests the least squares driver routines ZGELS, CGELSX, CGELSS,
+*  ZGELSY and CGELSD.
+*
+*  Arguments
+*  =========
+*
+*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
+*          The matrix types to be used for testing.  Matrices of type j
+*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*          The matrix of type j is generated as follows:
+*          j=1: A = U*D*V where U and V are random unitary matrices
+*               and D has random entries (> 0.1) taken from a uniform
+*               distribution (0,1). A is full rank.
+*          j=2: The same of 1, but A is scaled up.
+*          j=3: The same of 1, but A is scaled down.
+*          j=4: A = U*D*V where U and V are random unitary matrices
+*               and D has 3*min(M,N)/4 random entries (> 0.1) taken
+*               from a uniform distribution (0,1) and the remaining
+*               entries set to 0. A is rank-deficient.
+*          j=5: The same of 4, but A is scaled up.
+*          j=6: The same of 5, but A is scaled down.
+*
+*  NM      (input) INTEGER
+*          The number of values of M contained in the vector MVAL.
+*
+*  MVAL    (input) INTEGER array, dimension (NM)
+*          The values of the matrix row dimension M.
+*
+*  NN      (input) INTEGER
+*          The number of values of N contained in the vector NVAL.
+*
+*  NVAL    (input) INTEGER array, dimension (NN)
+*          The values of the matrix column dimension N.
+*
+*  NNB     (input) INTEGER
+*          The number of values of NB and NX contained in the
+*          vectors NBVAL and NXVAL.  The blocking parameters are used
+*          in pairs (NB,NX).
+*
+*  NBVAL   (input) INTEGER array, dimension (NNB)
+*          The values of the blocksize NB.
+*
+*  NXVAL   (input) INTEGER array, dimension (NNB)
+*          The values of the crossover point NX.
+*
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
+*  THRESH  (input) DOUBLE PRECISION
+*          The threshold value for the test ratios.  A result is
+*          included in the output file if RESULT >= THRESH.  To have
+*          every test ratio printed, use THRESH = 0.
+*
+*  TSTERR  (input) LOGICAL
+*          Flag that indicates whether error exits are to be tested.
+*
+*  A       (workspace) COMPLEX*16 array, dimension (MMAX*NMAX)
+*          where MMAX is the maximum value of M in MVAL and NMAX is the
+*          maximum value of N in NVAL.
+*
+*  COPYA   (workspace) COMPLEX*16 array, dimension (MMAX*NMAX)
+*
+*  B       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)
+*          where MMAX is the maximum value of M in MVAL and NSMAX is the
+*          maximum value of NRHS in NSVAL.
+*
+*  COPYB   (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)
+*
+*  C       (workspace) COMPLEX*16 array, dimension (MMAX*NSMAX)
+*
+*  S       (workspace) DOUBLE PRECISION array, dimension
+*                      (min(MMAX,NMAX))
+*
+*  COPYS   (workspace) DOUBLE PRECISION array, dimension
+*                      (min(MMAX,NMAX))
+*
+*  WORK    (workspace) COMPLEX*16 array, dimension
+*                      (MMAX*NMAX + 4*NMAX + MMAX).
+*
+*  RWORK   (workspace) DOUBLE PRECISION array, dimension (5*NMAX-1)
+*
+*  IWORK   (workspace) INTEGER array, dimension (NMAX)
+*
+*  NOUT    (input) INTEGER
+*          The unit number for output.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 14 )
-      INTEGER            SMLSIZ
-      PARAMETER          ( SMLSIZ = 25 )
+      PARAMETER          ( NTESTS = 18 )
       DOUBLE PRECISION   ONE, ZERO
       PARAMETER          ( ONE = 1.0D+0, ZERO = 0.0D+0 )
       COMPLEX*16         CONE, CZERO
@@ -260,7 +144,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASVM, DAXPY, DLASRT, XLAENV,
-     $                   ZDSCAL, ZERRLS, ZGELS, ZGELSD, ZGELSS,
+     $                   ZDSCAL, ZERRLS, ZGELS, ZGELSD, ZGELSS, ZGELSX,
      $                   ZGELSY, ZGEMM, ZLACPY, ZLARNV, ZQRT13, ZQRT15,
      $                   ZQRT16
 *     ..
@@ -269,7 +153,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*32       SRNAMT
+      CHARACTER*6        SRNAMT
       INTEGER            INFOT, IOUNIT
 *     ..
 *     .. Common blocks ..
@@ -299,7 +183,6 @@
 *
 *     Test the error exits
 *
-      CALL XLAENV( 9, SMLSIZ )
       IF( TSTERR )
      $   CALL ZERRLS( PATH, NOUT )
 *
@@ -442,8 +325,79 @@
 *
 *                    workspace used: MAX(M+MIN(M,N),NRHS*MIN(M,N),2*N+M)
 *
+                     DO 50 J = 1, N
+                        IWORK( J ) = 0
+   50                CONTINUE
                      LDWORK = MAX( 1, M )
 *
+*                    Test ZGELSX
+*
+*                    ZGELSX:  Compute the minimum-norm solution X
+*                    to min( norm( A * X - B ) )
+*                    using a complete orthogonal factorization.
+*
+                     CALL ZLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                     CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, B, LDB )
+*
+                     SRNAMT = 'ZGELSX'
+                     CALL ZGELSX( M, N, NRHS, A, LDA, B, LDB, IWORK,
+     $                            RCOND, CRANK, WORK, RWORK, INFO )
+*
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'ZGELSX', INFO, 0, ' ', M, N,
+     $                               NRHS, -1, NB, ITYPE, NFAIL, NERRS,
+     $                               NOUT )
+*
+*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )
+*
+*                    Test 3:  Compute relative error in svd
+*                             workspace: M*N + 4*MIN(M,N) + MAX(M,N)
+*
+                     RESULT( 3 ) = ZQRT12( CRANK, CRANK, A, LDA, COPYS,
+     $                             WORK, LWORK, RWORK )
+*
+*                    Test 4:  Compute error in solution
+*                             workspace:  M*NRHS + M
+*
+                     CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                            LDWORK )
+                     CALL ZQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                            LDA, B, LDB, WORK, LDWORK, RWORK,
+     $                            RESULT( 4 ) )
+*
+*                    Test 5:  Check norm of r'*A
+*                             workspace: NRHS*(M+N)
+*
+                     RESULT( 5 ) = ZERO
+                     IF( M.GT.CRANK )
+     $                  RESULT( 5 ) = ZQRT17( 'No transpose', 1, M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, COPYB,
+     $                                LDB, C, WORK, LWORK )
+*
+*                    Test 6:  Check if x is in the rowspace of A
+*                             workspace: (M+NRHS)*(N+2)
+*
+                     RESULT( 6 ) = ZERO
+*
+                     IF( N.GT.CRANK )
+     $                  RESULT( 6 ) = ZQRT14( 'No transpose', M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, WORK,
+     $                                LWORK )
+*
+*                    Print information about the tests that did not
+*                    pass the threshold.
+*
+                     DO 60 K = 3, 6
+                        IF( RESULT( K ).GE.THRESH ) THEN
+                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                        CALL ALAHD( NOUT, PATH )
+                           WRITE( NOUT, FMT = 9998 )M, N, NRHS, 0,
+     $                        ITYPE, K, RESULT( K )
+                           NFAIL = NFAIL + 1
+                        END IF
+   60                CONTINUE
+                     NRUN = NRUN + 4
+*
 *                    Loop for testing different block sizes.
 *
                      DO 90 INB = 1, NNB
@@ -485,39 +439,39 @@
 *
 *                       workspace used: 2*MNMIN+NB*NB+NB*MAX(N,NRHS)
 *
-*                       Test 3:  Compute relative error in svd
+*                       Test 7:  Compute relative error in svd
 *                                workspace: M*N + 4*MIN(M,N) + MAX(M,N)
 *
-                        RESULT( 3 ) = ZQRT12( CRANK, CRANK, A, LDA,
+                        RESULT( 7 ) = ZQRT12( CRANK, CRANK, A, LDA,
      $                                COPYS, WORK, LWORK, RWORK )
 *
-*                       Test 4:  Compute error in solution
+*                       Test 8:  Compute error in solution
 *                                workspace:  M*NRHS + M
 *
                         CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
      $                               LDWORK )
                         CALL ZQRT16( 'No transpose', M, N, NRHS, COPYA,
      $                               LDA, B, LDB, WORK, LDWORK, RWORK,
-     $                               RESULT( 4 ) )
+     $                               RESULT( 8 ) )
 *
-*                       Test 5:  Check norm of r'*A
+*                       Test 9:  Check norm of r'*A
 *                                workspace: NRHS*(M+N)
 *
-                        RESULT( 5 ) = ZERO
+                        RESULT( 9 ) = ZERO
                         IF( M.GT.CRANK )
-     $                     RESULT( 5 ) = ZQRT17( 'No transpose', 1, M,
+     $                     RESULT( 9 ) = ZQRT17( 'No transpose', 1, M,
      $                                   N, NRHS, COPYA, LDA, B, LDB,
      $                                   COPYB, LDB, C, WORK, LWORK )
 *
-*                       Test 6:  Check if x is in the rowspace of A
+*                       Test 10:  Check if x is in the rowspace of A
 *                                workspace: (M+NRHS)*(N+2)
 *
-                        RESULT( 6 ) = ZERO
+                        RESULT( 10 ) = ZERO
 *
                         IF( N.GT.CRANK )
-     $                     RESULT( 6 ) = ZQRT14( 'No transpose', M, N,
-     $                                   NRHS, COPYA, LDA, B, LDB,
-     $                                   WORK, LWORK )
+     $                     RESULT( 10 ) = ZQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
 *
 *                       Test ZGELSS
 *
@@ -541,62 +495,6 @@
 *                       workspace used: 3*min(m,n) +
 *                                       max(2*min(m,n),nrhs,max(m,n))
 *
-*                       Test 7:  Compute relative error in svd
-*
-                        IF( RANK.GT.0 ) THEN
-                           CALL DAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
-                           RESULT( 7 ) = DASUM( MNMIN, S, 1 ) /
-     $                                   DASUM( MNMIN, COPYS, 1 ) /
-     $                                   ( EPS*DBLE( MNMIN ) )
-                        ELSE
-                           RESULT( 7 ) = ZERO
-                        END IF
-*
-*                       Test 8:  Compute error in solution
-*
-                        CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
-     $                               LDWORK )
-                        CALL ZQRT16( 'No transpose', M, N, NRHS, COPYA,
-     $                               LDA, B, LDB, WORK, LDWORK, RWORK,
-     $                               RESULT( 8 ) )
-*
-*                       Test 9:  Check norm of r'*A
-*
-                        RESULT( 9 ) = ZERO
-                        IF( M.GT.CRANK )
-     $                     RESULT( 9 ) = ZQRT17( 'No transpose', 1, M,
-     $                                   N, NRHS, COPYA, LDA, B, LDB,
-     $                                   COPYB, LDB, C, WORK, LWORK )
-*
-*                       Test 10:  Check if x is in the rowspace of A
-*
-                        RESULT( 10 ) = ZERO
-                        IF( N.GT.CRANK )
-     $                     RESULT( 10 ) = ZQRT14( 'No transpose', M, N,
-     $                                    NRHS, COPYA, LDA, B, LDB,
-     $                                    WORK, LWORK )
-*
-*                       Test ZGELSD
-*
-*                       ZGELSD:  Compute the minimum-norm solution X
-*                       to min( norm( A * X - B ) ) using a
-*                       divide and conquer SVD.
-*
-                        CALL XLAENV( 9, 25 )
-*
-                        CALL ZLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
-                        CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, B,
-     $                               LDB )
-*
-                        SRNAMT = 'ZGELSD'
-                        CALL ZGELSD( M, N, NRHS, A, LDA, B, LDB, S,
-     $                               RCOND, CRANK, WORK, LWORK, RWORK,
-     $                               IWORK, INFO )
-                        IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'ZGELSD', INFO, 0, ' ', M,
-     $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
-     $                                  NERRS, NOUT )
-*
 *                       Test 11:  Compute relative error in svd
 *
                         IF( RANK.GT.0 ) THEN
@@ -632,10 +530,67 @@
      $                                    NRHS, COPYA, LDA, B, LDB,
      $                                    WORK, LWORK )
 *
+*                       Test ZGELSD
+*
+*                       ZGELSD:  Compute the minimum-norm solution X
+*                       to min( norm( A * X - B ) ) using a
+*                       divide and conquer SVD.
+*
+                        CALL XLAENV( 9, 25 )
+*
+                        CALL ZLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                        CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, B,
+     $                               LDB )
+*
+                        SRNAMT = 'ZGELSD'
+                        CALL ZGELSD( M, N, NRHS, A, LDA, B, LDB, S,
+     $                               RCOND, CRANK, WORK, LWORK, RWORK,
+     $                               IWORK, INFO )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'ZGELSD', INFO, 0, ' ', M,
+     $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
+     $                                  NERRS, NOUT )
+*
+*                       Test 15:  Compute relative error in svd
+*
+                        IF( RANK.GT.0 ) THEN
+                           CALL DLASRT( 'D', MNMIN, S, INFO )
+                           CALL DAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
+                           RESULT( 15 ) = DASUM( MNMIN, S, 1 ) /
+     $                                    DASUM( MNMIN, COPYS, 1 ) /
+     $                                    ( EPS*DBLE( MNMIN ) )
+                        ELSE
+                           RESULT( 15 ) = ZERO
+                        END IF
+*
+*                       Test 16:  Compute error in solution
+*
+                        CALL ZLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                               LDWORK )
+                        CALL ZQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                               LDA, B, LDB, WORK, LDWORK, RWORK,
+     $                               RESULT( 16 ) )
+*
+*                       Test 17:  Check norm of r'*A
+*
+                        RESULT( 17 ) = ZERO
+                        IF( M.GT.CRANK )
+     $                     RESULT( 17 ) = ZQRT17( 'No transpose', 1, M,
+     $                                    N, NRHS, COPYA, LDA, B, LDB,
+     $                                    COPYB, LDB, C, WORK, LWORK )
+*
+*                       Test 18:  Check if x is in the rowspace of A
+*
+                        RESULT( 18 ) = ZERO
+                        IF( N.GT.CRANK )
+     $                     RESULT( 18 ) = ZQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
+*
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 80 K = 3, NTESTS
+                        DO 80 K = 7, NTESTS
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALAHD( NOUT, PATH )
