@@ -1,127 +1,10 @@
-*> \brief \b ZLATB4
-*
-*  =========== DOCUMENTATION ===========
-*
-* Online html documentation available at
-*            http://www.netlib.org/lapack/explore-html/
-*
-*  Definition:
-*  ===========
-*
-*       SUBROUTINE ZLATB4( PATH, IMAT, M, N, TYPE, KL, KU, ANORM, MODE,
-*                          CNDNUM, DIST )
-*
-*       .. Scalar Arguments ..
-*       CHARACTER          DIST, TYPE
-*       CHARACTER*3        PATH
-*       INTEGER            IMAT, KL, KU, M, MODE, N
-*       DOUBLE PRECISION   ANORM, CNDNUM
-*       ..
-*
-*
-*> \par Purpose:
-*  =============
-*>
-*> \verbatim
-*>
-*> ZLATB4 sets parameters for the matrix generator based on the type of
-*> matrix to be generated.
-*> \endverbatim
-*
-*  Arguments:
-*  ==========
-*
-*> \param[in] PATH
-*> \verbatim
-*>          PATH is CHARACTER*3
-*>          The LAPACK path name.
-*> \endverbatim
-*>
-*> \param[in] IMAT
-*> \verbatim
-*>          IMAT is INTEGER
-*>          An integer key describing which matrix to generate for this
-*>          path.
-*> \endverbatim
-*>
-*> \param[in] M
-*> \verbatim
-*>          M is INTEGER
-*>          The number of rows in the matrix to be generated.
-*> \endverbatim
-*>
-*> \param[in] N
-*> \verbatim
-*>          N is INTEGER
-*>          The number of columns in the matrix to be generated.
-*> \endverbatim
-*>
-*> \param[out] TYPE
-*> \verbatim
-*>          TYPE is CHARACTER*1
-*>          The type of the matrix to be generated:
-*>          = 'S':  symmetric matrix
-*>          = 'H':  Hermitian matrix
-*>          = 'P':  Hermitian positive (semi)definite matrix
-*>          = 'N':  nonsymmetric matrix
-*> \endverbatim
-*>
-*> \param[out] KL
-*> \verbatim
-*>          KL is INTEGER
-*>          The lower band width of the matrix to be generated.
-*> \endverbatim
-*>
-*> \param[out] KU
-*> \verbatim
-*>          KU is INTEGER
-*>          The upper band width of the matrix to be generated.
-*> \endverbatim
-*>
-*> \param[out] ANORM
-*> \verbatim
-*>          ANORM is DOUBLE PRECISION
-*>          The desired norm of the matrix to be generated.  The diagonal
-*>          matrix of singular values or eigenvalues is scaled by this
-*>          value.
-*> \endverbatim
-*>
-*> \param[out] MODE
-*> \verbatim
-*>          MODE is INTEGER
-*>          A key indicating how to choose the vector of eigenvalues.
-*> \endverbatim
-*>
-*> \param[out] CNDNUM
-*> \verbatim
-*>          CNDNUM is DOUBLE PRECISION
-*>          The desired condition number.
-*> \endverbatim
-*>
-*> \param[out] DIST
-*> \verbatim
-*>          DIST is CHARACTER*1
-*>          The type of distribution to be used by the random number
-*>          generator.
-*> \endverbatim
-*
-*  Authors:
-*  ========
-*
-*> \author Univ. of Tennessee
-*> \author Univ. of California Berkeley
-*> \author Univ. of Colorado Denver
-*> \author NAG Ltd.
-*
-*> \ingroup complex16_lin
-*
-*  =====================================================================
       SUBROUTINE ZLATB4( PATH, IMAT, M, N, TYPE, KL, KU, ANORM, MODE,
      $                   CNDNUM, DIST )
 *
-*  -- LAPACK test routine --
-*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
-*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*  -- LAPACK test routine (version 3.0) --
+*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
+*     Courant Institute, Argonne National Lab, and Rice University
+*     February 29, 1992
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, TYPE
@@ -130,6 +13,55 @@
       DOUBLE PRECISION   ANORM, CNDNUM
 *     ..
 *
+*  Purpose
+*  =======
+*
+*  ZLATB4 sets parameters for the matrix generator based on the type of
+*  matrix to be generated.
+*
+*  Arguments
+*  =========
+*
+*  PATH    (input) CHARACTER*3
+*          The LAPACK path name.
+*
+*  IMAT    (input) INTEGER
+*          An integer key describing which matrix to generate for this
+*          path.
+*
+*  M       (input) INTEGER
+*          The number of rows in the matrix to be generated.
+*
+*  N       (input) INTEGER
+*          The number of columns in the matrix to be generated.
+*
+*  TYPE    (output) CHARACTER*1
+*          The type of the matrix to be generated:
+*          = 'S':  symmetric matrix
+*          = 'P':  symmetric positive (semi)definite matrix
+*          = 'N':  nonsymmetric matrix
+*
+*  KL      (output) INTEGER
+*          The lower band width of the matrix to be generated.
+*
+*  KU      (output) INTEGER
+*          The upper band width of the matrix to be generated.
+*
+*  ANORM   (output) DOUBLE PRECISION
+*          The desired norm of the matrix to be generated.  The diagonal
+*          matrix of singular values or eigenvalues is scaled by this
+*          value.
+*
+*  MODE    (output) INTEGER
+*          A key indicating how to choose the vector of eigenvalues.
+*
+*  CNDNUM  (output) DOUBLE PRECISION
+*          The desired condition number.
+*
+*  DIST    (output) CHARACTER*1
+*          The type of distribution to be used by the random number
+*          generator.
+*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -337,10 +269,12 @@
             ANORM = ONE
          END IF
 *
-      ELSE IF( LSAMEN( 2, C2, 'PO' ) .OR. LSAMEN( 2, C2, 'PP' ) ) THEN
+      ELSE IF( LSAMEN( 2, C2, 'PO' ) .OR. LSAMEN( 2, C2, 'PP' ) .OR.
+     $         LSAMEN( 2, C2, 'HE' ) .OR. LSAMEN( 2, C2, 'HP' ) .OR.
+     $         LSAMEN( 2, C2, 'SY' ) .OR. LSAMEN( 2, C2, 'SP' ) ) THEN
 *
-*        xPO, xPP: Set parameters to generate a
-*        symmetric or Hermitian positive definite matrix.
+*        xPO, xPP, xHE, xHP, xSY, xSP: Set parameters to generate a
+*        symmetric or Hermitian matrix.
 *
 *        Set TYPE, the type of matrix to be generated.
 *
@@ -372,43 +306,6 @@
          ELSE
             ANORM = ONE
          END IF
-*
-      ELSE IF( LSAMEN( 2, C2, 'HE' ) .OR. LSAMEN( 2, C2, 'HP' ) .OR.
-     $         LSAMEN( 2, C2, 'SY' ) .OR. LSAMEN( 2, C2, 'SP' ) ) THEN
-*
-*        xHE, xHP, xSY, xSP: Set parameters to generate a
-*        symmetric or Hermitian matrix.
-*
-*        Set TYPE, the type of matrix to be generated.
-*
-         TYPE = C2( 1: 1 )
-*
-*        Set the lower and upper bandwidths.
-*
-         IF( IMAT.EQ.1 ) THEN
-            KL = 0
-         ELSE
-            KL = MAX( N-1, 0 )
-         END IF
-         KU = KL
-*
-*        Set the condition number and norm.
-*
-         IF( IMAT.EQ.7 ) THEN
-            CNDNUM = BADC1
-         ELSE IF( IMAT.EQ.8 ) THEN
-            CNDNUM = BADC2
-         ELSE
-            CNDNUM = TWO
-         END IF
-*
-         IF( IMAT.EQ.9 ) THEN
-            ANORM = SMALL
-         ELSE IF( IMAT.EQ.10 ) THEN
-            ANORM = LARGE
-         ELSE
-            ANORM = ONE
-         END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'PB' ) ) THEN
 *
@@ -517,18 +414,17 @@
 *
 *        Set the norm and condition number.
 *
-         MAT = ABS( IMAT )
-         IF( MAT.EQ.2 .OR. MAT.EQ.8 ) THEN
+         IF( IMAT.EQ.2 .OR. IMAT.EQ.8 ) THEN
             CNDNUM = BADC1
-         ELSE IF( MAT.EQ.3 .OR. MAT.EQ.9 ) THEN
+         ELSE IF( IMAT.EQ.3 .OR. IMAT.EQ.9 ) THEN
             CNDNUM = BADC2
          ELSE
             CNDNUM = TWO
          END IF
 *
-         IF( MAT.EQ.4 ) THEN
+         IF( IMAT.EQ.4 ) THEN
             ANORM = SMALL
-         ELSE IF( MAT.EQ.5 ) THEN
+         ELSE IF( IMAT.EQ.5 ) THEN
             ANORM = LARGE
          ELSE
             ANORM = ONE
