@@ -4,10 +4,10 @@
      $                   RWORK, LLWORK, IWORK, TIMES, LDT1, LDT2, LDT3,
      $                   OPCNTS, LDO1, LDO2, LDO3, INFO )
 *
-*  -- LAPACK timing routine (version 2.0) --
+*  -- LAPACK timing routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     November 14, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER*80       LINE
@@ -44,9 +44,9 @@
 *          On entry, LINE contains the input line which requested
 *          this routine.  This line may contain a subroutine name,
 *          such as CHETRD, indicating that only routine CHETRD will
-*          be timed, or it may contain a generic name, such as SST.
+*          be timed, or it may contain a generic name, such as CST.
 *          In this case, the rest of the line is scanned for the
-*          first 11 non-blank characters, corresponding to the eleven
+*          first 12 non-blank characters, corresponding to the twelve
 *          combinations of subroutine and options:
 *          LAPACK:
 *             1: CHETRD
@@ -57,10 +57,11 @@
 *             6. SSTEBZ+CSTEIN+CUNMTR
 *             7. CUNGTR+CSTEDC(COMPQ='V')
 *             8. CSTEDC(COMPQ='I')+CUNMTR
+*             9. CSTEGR(COMPQ='V')
 *          EISPACK:
-*             9: HTRIDI (compare with CHETRD)
-*            10: IMTQL1 (compare w/ CSTEQR -- VECT='N')
-*            11: IMTQL2+HTRIBK (compare w/ CUNGTR+CSTEQR(VECT='V') )
+*            10: HTRIDI (compare with CHETRD)
+*            11: IMTQL1 (compare w/ CSTEQR -- VECT='N')
+*            12: IMTQL2+HTRIBK (compare w/ CUNGTR+CSTEQR(VECT='V') )
 *          If a character is 'T' or 't', the corresponding routine in
 *          this path is timed.  If the entire line is blank, all the
 *          routines in the path are timed.
@@ -234,17 +235,17 @@
 *
 *     .. Parameters ..
       INTEGER            MAXTYP, NSUBS
-      PARAMETER          ( MAXTYP = 4, NSUBS = 11 )
+      PARAMETER          ( MAXTYP = 4, NSUBS = 12 )
       REAL               ZERO, ONE, TWO
-      PARAMETER          ( ZERO = 0.0E+0, ONE = 1.0E+0, TWO = 2.0E+0 )
+      PARAMETER          ( ZERO = 0.0E0, ONE = 1.0E0, TWO = 2.0E0 )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            RUNHTR, RUNTRD
       CHARACTER          UPLO
-      INTEGER            I, IC, IINFO, IL, ILWORK, IMODE, IN, IPAR,
-     $                   ISUB, ITYPE, IU, J, J1, J2, J3, J4, LASTL, LDA,
-     $                   LDU, LGN, LIWEDC, LRWEDC, LWEDC, M, MTYPES, N,
-     $                   NB, NSPLIT
+      INTEGER            I, IC, IINFO, IL, ILWORK, IMODE, IN, IPAR, 
+     $                   ISUB, ITYPE, IU, J, J1, J2, J3, J4, LASTL, LDA, 
+     $                   LDU, LGN, LIWEDC, LIWEVR, LRWEDC, LWEDC, LWEVR, 
+     $                   M, MTYPES, N, NB, NSPLIT
       REAL               ABSTOL, S1, S2, TIME, ULP, ULPINV, UNTIME, VL,
      $                   VU
 *     ..
@@ -260,10 +261,10 @@
       EXTERNAL           SECOND, SLAMCH, SOPLA
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ATIMIN, CHETRD, CLACPY, CLATMS, CPTEQR, CSTEDC,
-     $                   CSTEIN, CSTEQR, CUNGTR, CUNMTR, HTRIBK, HTRIDI,
-     $                   IMTQL1, IMTQL2, SCOPY, SLASET, SPRTBE, SSTEBZ,
-     $                   XLAENV
+      EXTERNAL           ATIMIN, CHETRD, CLACPY, CLATMS, CPTEQR, CSTEDC, 
+     $                   CSTEGR, CSTEIN, CSTEQR, CUNGTR, CUNMTR, HTRIBK, 
+     $                   HTRIDI, IMTQL1, IMTQL2, SCOPY, SLASET, SPRTBE, 
+     $                   SSTEBZ, XLAENV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, AIMAG, INT, LOG, MAX, MIN, REAL
@@ -279,8 +280,9 @@
      $                   'CUNGTR+CSTEQR(V)', 'CPTEQR(N)',
      $                   'CUNGTR+CPTEQR(V)', 'SSTEBZ+CSTEIN+CUNMTR',
      $                   'CUNGTR+CSTEDC(V)', 'CSTEDC(I)+CUNMTR',
-     $                   'HTRIDI', 'IMTQL1', 'IMTQL2+HTRIBK' /
-      DATA               INPARM / 2, 1, 2, 1, 2, 2, 1, 1, 1, 1, 1 /
+     $                   'CSTEGR(V)', 'HTRIDI', 'IMTQL1',
+     $                   'IMTQL2+HTRIBK' /
+      DATA               INPARM / 2, 1, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1 /
       DATA               PNAMES / 'LDA', 'NB', 'bad1', 'bad2' /
       DATA               KMODE / 4, 3, 1, 5 /
 *     ..
@@ -327,20 +329,23 @@
 *
       RUNTRD = .FALSE.
       IF( TIMSUB( 2 ) .OR. TIMSUB( 3 ) .OR. TIMSUB( 4 ) .OR.
-     $    TIMSUB( 5 ) )RUNTRD = .TRUE.
+     $    TIMSUB( 5 ) .OR. TIMSUB( 6 ) .OR. TIMSUB( 7 ) .OR.
+     $    TIMSUB( 8 ) .OR. TIMSUB( 9 ) ) 
+     $   RUNTRD = .TRUE.
 *
 *     Check to see whether HTRIDI must be run.
 *
 *     RUNHTR -- if HTRIDI must be run.
 *
       RUNHTR = .FALSE.
-      IF( TIMSUB( 7 ) .OR. TIMSUB( 8 ) )
+      IF( TIMSUB( 10 ) .OR. TIMSUB( 11 ) .OR. TIMSUB( 12 ) )
      $   RUNHTR = .TRUE.
 *
 *     Various Constants
 *
       ULP = SLAMCH( 'Epsilon' )*SLAMCH( 'Base' )
       ULPINV = ONE / ULP
+      CALL XLAENV( 9, 25 )
 *
 *     Zero out OPCNTS, TIMES
 *
@@ -357,7 +362,7 @@
 *
 *     Do for each value of N:
 *
-      DO 620 IN = 1, NSIZES
+      DO 650 IN = 1, NSIZES
 *
          N = NN( IN )
          IF( N.GT.0 ) THEN
@@ -369,10 +374,14 @@
             LWEDC = 1 + 4*N + 2*N*LGN + 3*N**2
             LRWEDC = 1 + 3*N + 2*N*LGN + 3*N**2
             LIWEDC = 6 + 6*N + 5*N*LGN
+            LWEVR = 18*N
+            LIWEVR = 10*N
          ELSE
             LWEDC = 8
             LRWEDC = 7
             LIWEDC = 12
+            LWEVR = 1
+            LIWEVR = 1
          END IF
 *
 *        Do for each .TRUE. value in DOTYPE:
@@ -380,9 +389,9 @@
          MTYPES = MIN( MAXTYP, NTYPES )
          IF( NTYPES.EQ.MAXTYP+1 .AND. NSIZES.EQ.1 )
      $      MTYPES = NTYPES
-         DO 610 ITYPE = 1, MTYPES
+         DO 640 ITYPE = 1, MTYPES
             IF( .NOT.DOTYPE( ITYPE ) )
-     $         GO TO 610
+     $         GO TO 640
 *
 *           Save random number seed for error messages
 *
@@ -405,7 +414,7 @@
                   WRITE( NOUT, FMT = 9997 )'CLATMS', IINFO, N, ITYPE,
      $               0, IOLDSD
                   INFO = ABS( IINFO )
-                  GO TO 610
+                  GO TO 640
                END IF
             END IF
 *
@@ -874,7 +883,7 @@
                   CALL XLAENV( 2, 2 )
                   CALL XLAENV( 3, NB )
 *
-*                 Time  CSTEQR + CUNMTR
+*                 Time  CSTEDC + CUNMTR
 *
                   IC = 0
                   OPS = ZERO
@@ -924,6 +933,60 @@
   370          CONTINUE
             END IF
 *
+*           Time CSTEGR(COMPQ='V') for each pair NNB(j), LDAS(j)
+*
+            IF( TIMSUB( 9 ) ) THEN
+               DO 400 IPAR = 1, NPARMS
+                  LDA = LDAS( IPAR )
+                  NB = MIN( N, NNB( IPAR ) )
+                  CALL XLAENV( 1, NB )
+                  CALL XLAENV( 2, 2 )
+                  CALL XLAENV( 3, NB )
+*
+                  ABSTOL = ZERO
+                  VL = ZERO
+                  VU = ZERO
+                  IL = 1
+                  IU = N
+                  IC = 0
+                  OPS = ZERO
+                  S1 = SECOND( )
+  380             CONTINUE
+                  CALL SCOPY( N, D, 1, RWORK, 1 )
+                  CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
+                  CALL CSTEGR( 'V', 'A', N, RWORK, RWORK( LDA+1 ),
+     $                         VL, VU, IL, IU, ABSTOL, M,
+     $                         RWORK( 2*LDA+1 ), Z, LDA, IWORK,
+     $                         RWORK( 3*LDA+1 ), LWEVR,
+     $                         IWORK( 2*LDA+1 ), LIWEVR, INFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUT, FMT = 9997 )SUBNAM( 9 ), IINFO, N,
+     $                  ITYPE, IPAR, IOLDSD
+                     INFO = ABS( IINFO )
+                     GO TO 400
+                  END IF
+                  S2 = SECOND( )
+                  TIME = S2 - S1
+                  IC = IC + 1
+                  IF( TIME.LT.TIMMIN )
+     $               GO TO 380
+*
+*                 Subtract the time used in SCOPY.
+*
+                  S1 = SECOND( )
+                  DO 390 J = 1, IC
+                     CALL SCOPY( N, D, 1, RWORK, 1 )
+                     CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
+  390             CONTINUE
+                  S2 = SECOND( )
+                  UNTIME = S2 - S1
+*
+                  TIMES( IPAR, ITYPE, IN, 9 ) = MAX( TIME-UNTIME,
+     $               ZERO ) / REAL( IC )
+                  OPCNTS( IPAR, ITYPE, IN, 9 ) = OPS / REAL( IC )
+  400          CONTINUE
+            END IF
+*
 *-----------------------------------------------------------------------
 *
 *           Time the EISPACK Routines
@@ -931,22 +994,22 @@
 *           Skip routines if N <= 0 (EISPACK requirement)
 *
             IF( N.LE.0 )
-     $         GO TO 610
+     $         GO TO 640
 *
 *           Time HTRIDI for each LDAS(j)
 *
-            IF( TIMSUB( 9 ) ) THEN
-               DO 450 IPAR = 1, NPARMS
+            IF( TIMSUB( 10 ) ) THEN
+               DO 480 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has come up before, just use
 *                 the value previously computed.
 *
                   LASTL = 0
-                  DO 380 J = 1, IPAR - 1
+                  DO 410 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTL = J
-  380             CONTINUE
+  410             CONTINUE
 *
                   IF( LASTL.EQ.0 ) THEN
 *
@@ -955,52 +1018,52 @@
                      IC = 0
                      OPS = ZERO
                      S1 = SECOND( )
-  390                CONTINUE
-                     DO 410 J2 = 0, N - 1
-                        DO 400 J1 = 1, N
+  420                CONTINUE
+                     DO 440 J2 = 0, N - 1
+                        DO 430 J1 = 1, N
                            URE( J1+LDA*J2 ) = REAL( A( J1+N*J2 ) )
                            UIM( J1+LDA*J2 ) = AIMAG( A( J1+N*J2 ) )
-  400                   CONTINUE
-  410                CONTINUE
+  430                   CONTINUE
+  440                CONTINUE
                      CALL HTRIDI( LDA, N, URE, UIM, D, E, RWORK, TAURE )
                      S2 = SECOND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 390
+     $                  GO TO 420
 *
 *                    Subtract the time used in copying A.
 *
                      S1 = SECOND( )
-                     DO 440 J = 1, IC
-                        DO 430 J2 = 0, N - 1
-                           DO 420 J1 = 1, N
+                     DO 470 J = 1, IC
+                        DO 460 J2 = 0, N - 1
+                           DO 450 J1 = 1, N
                               ZRE( J1+LDA*J2 ) = REAL( A( J1+N*J2 ) )
                               ZIM( J1+LDA*J2 ) = AIMAG( A( J1+N*J2 ) )
-  420                      CONTINUE
-  430                   CONTINUE
-  440                CONTINUE
+  450                      CONTINUE
+  460                   CONTINUE
+  470                CONTINUE
                      S2 = SECOND( )
                      UNTIME = S2 - S1
-                     TIMES( IPAR, ITYPE, IN, 9 ) = MAX( TIME-UNTIME,
+                     TIMES( IPAR, ITYPE, IN, 10 ) = MAX( TIME-UNTIME,
      $                  ZERO ) / REAL( IC )
-                     OPCNTS( IPAR, ITYPE, IN, 9 ) = OPS / REAL( IC )
+                     OPCNTS( IPAR, ITYPE, IN, 10 ) = OPS / REAL( IC )
                      LDU = LDA
                   ELSE
-                     OPCNTS( IPAR, ITYPE, IN, 9 ) = OPCNTS( LASTL,
-     $                  ITYPE, IN, 9 )
-                     TIMES( IPAR, ITYPE, IN, 9 ) = TIMES( LASTL, ITYPE,
-     $                  IN, 9 )
+                     OPCNTS( IPAR, ITYPE, IN, 10 ) = OPCNTS( LASTL,
+     $                  ITYPE, IN, 10 )
+                     TIMES( IPAR, ITYPE, IN, 10 ) = TIMES( LASTL, ITYPE,
+     $                  IN, 10 )
                   END IF
-  450          CONTINUE
+  480          CONTINUE
             ELSE
                IF( RUNHTR ) THEN
-                  DO 470 J2 = 0, N - 1
-                     DO 460 J1 = 1, N
+                  DO 500 J2 = 0, N - 1
+                     DO 490 J1 = 1, N
                         URE( J1+N*J2 ) = REAL( A( J1+N*J2 ) )
                         UIM( J1+N*J2 ) = AIMAG( A( J1+N*J2 ) )
-  460                CONTINUE
-  470             CONTINUE
+  490                CONTINUE
+  500             CONTINUE
                   CALL HTRIDI( N, N, URE, UIM, D, E, RWORK, TAURE )
                   LDU = N
                END IF
@@ -1008,18 +1071,18 @@
 *
 *           Time IMTQL1 for each LDAS(j)
 *
-            IF( TIMSUB( 10 ) ) THEN
-               DO 510 IPAR = 1, NPARMS
+            IF( TIMSUB( 11 ) ) THEN
+               DO 540 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has come up before, just use
 *                 the value previously computed.
 *
                   LASTL = 0
-                  DO 480 J = 1, IPAR - 1
+                  DO 510 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTL = J
-  480             CONTINUE
+  510             CONTINUE
 *
                   IF( LASTL.EQ.0 ) THEN
 *
@@ -1028,114 +1091,29 @@
                      IC = 0
                      OPS = ZERO
                      S1 = SECOND( )
-  490                CONTINUE
+  520                CONTINUE
                      CALL SCOPY( N, D, 1, RWORK, 1 )
                      CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
                      CALL IMTQL1( N, RWORK, RWORK( LDA+1 ), IINFO )
                      IF( IINFO.NE.0 ) THEN
-                        WRITE( NOUT, FMT = 9997 )SUBNAM( 10 ), IINFO,
+                        WRITE( NOUT, FMT = 9997 )SUBNAM( 11 ), IINFO,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 520
+                        GO TO 550
                      END IF
                      S2 = SECOND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 490
+     $                  GO TO 520
 *
 *                    Subtract the time used in SCOPY
 *
                      S1 = SECOND( )
-                     DO 500 J = 1, IC
+                     DO 530 J = 1, IC
                         CALL SCOPY( N, D, 1, RWORK, 1 )
                         CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
-  500                CONTINUE
-                     S2 = SECOND( )
-                     UNTIME = S2 - S1
-*
-                     TIMES( IPAR, ITYPE, IN, 10 ) = MAX( TIME-UNTIME,
-     $                  ZERO ) / REAL( IC )
-                     OPCNTS( IPAR, ITYPE, IN, 10 ) = OPS / REAL( IC )
-                  ELSE
-                     OPCNTS( IPAR, ITYPE, IN, 10 ) = OPCNTS( LASTL,
-     $                  ITYPE, IN, 10 )
-                     TIMES( IPAR, ITYPE, IN, 10 ) = TIMES( LASTL, ITYPE,
-     $                  IN, 10 )
-                  END IF
-  510          CONTINUE
-            END IF
-  520       CONTINUE
-*
-*           Time IMTQL2 + HTRIBK for each LDAS(j)
-*
-            IF( TIMSUB( 11 ) ) THEN
-               DO 600 IPAR = 1, NPARMS
-                  LDA = LDAS( IPAR )
-*
-*                 If this value of LDA has come up before, just use
-*                 the value previously computed.
-*
-                  LASTL = 0
-                  DO 530 J = 1, IPAR - 1
-                     IF( LDA.EQ.LDAS( J ) )
-     $                  LASTL = J
-  530             CONTINUE
-*
-                  IF( LASTL.EQ.0 ) THEN
-*
-*                    Change leading dimension of U
-*
-                     IF( LDA.GT.LDU ) THEN
-                        DO 550 J2 = N - 1, 1, -1
-                           DO 540 J1 = N, 1, -1
-                              URE( J1+LDA*J2 ) = URE( J1+LDU*J2 )
-                              UIM( J1+LDA*J2 ) = UIM( J1+LDU*J2 )
-  540                      CONTINUE
-  550                   CONTINUE
-                        LDU = LDA
-                     ELSE IF( LDA.LT.LDU ) THEN
-                        DO 570 J2 = 1, N - 1
-                           DO 560 J1 = 1, N
-                              URE( J1+LDA*J2 ) = URE( J1+LDU*J2 )
-                              UIM( J1+LDA*J2 ) = UIM( J1+LDU*J2 )
-  560                      CONTINUE
-  570                   CONTINUE
-                        LDU = LDA
-                     END IF
-*
-*                    Time IMTQL2 + HTRIBK
-*
-                     IC = 0
-                     OPS = ZERO
-                     S1 = SECOND( )
-  580                CONTINUE
-                     CALL SCOPY( N, D, 1, RWORK, 1 )
-                     CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
-                     CALL SLASET( 'Full', N, N, ZERO, ONE, ZRE, LDA )
-                     CALL IMTQL2( LDA, N, RWORK, RWORK( LDA+1 ), ZRE,
-     $                            IINFO )
-                     IF( IINFO.NE.0 ) THEN
-                        WRITE( NOUT, FMT = 9997 )SUBNAM( 9 ), IINFO, N,
-     $                     ITYPE, IPAR, IOLDSD
-                        INFO = ABS( IINFO )
-                        GO TO 610
-                     END IF
-                     CALL HTRIBK( LDA, N, URE, UIM, TAURE, N, ZRE, ZIM )
-                     S2 = SECOND( )
-                     TIME = S2 - S1
-                     IC = IC + 1
-                     IF( TIME.LT.TIMMIN )
-     $                  GO TO 580
-*
-*                    Subtract the time used in copying
-*
-                     S1 = SECOND( )
-                     DO 590 J = 1, IC
-                        CALL SCOPY( N, D, 1, RWORK, 1 )
-                        CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
-                        CALL SLASET( 'Full', N, N, ZERO, ONE, ZRE, LDA )
-  590                CONTINUE
+  530                CONTINUE
                      S2 = SECOND( )
                      UNTIME = S2 - S1
 *
@@ -1148,17 +1126,102 @@
                      TIMES( IPAR, ITYPE, IN, 11 ) = TIMES( LASTL, ITYPE,
      $                  IN, 11 )
                   END IF
-  600          CONTINUE
+  540          CONTINUE
+            END IF
+  550       CONTINUE
+*
+*           Time IMTQL2 + HTRIBK for each LDAS(j)
+*
+            IF( TIMSUB( 12 ) ) THEN
+               DO 630 IPAR = 1, NPARMS
+                  LDA = LDAS( IPAR )
+*
+*                 If this value of LDA has come up before, just use
+*                 the value previously computed.
+*
+                  LASTL = 0
+                  DO 560 J = 1, IPAR - 1
+                     IF( LDA.EQ.LDAS( J ) )
+     $                  LASTL = J
+  560             CONTINUE
+*
+                  IF( LASTL.EQ.0 ) THEN
+*
+*                    Change leading dimension of U
+*
+                     IF( LDA.GT.LDU ) THEN
+                        DO 580 J2 = N - 1, 1, -1
+                           DO 570 J1 = N, 1, -1
+                              URE( J1+LDA*J2 ) = URE( J1+LDU*J2 )
+                              UIM( J1+LDA*J2 ) = UIM( J1+LDU*J2 )
+  570                      CONTINUE
+  580                   CONTINUE
+                        LDU = LDA
+                     ELSE IF( LDA.LT.LDU ) THEN
+                        DO 600 J2 = 1, N - 1
+                           DO 590 J1 = 1, N
+                              URE( J1+LDA*J2 ) = URE( J1+LDU*J2 )
+                              UIM( J1+LDA*J2 ) = UIM( J1+LDU*J2 )
+  590                      CONTINUE
+  600                   CONTINUE
+                        LDU = LDA
+                     END IF
+*
+*                    Time IMTQL2 + HTRIBK
+*
+                     IC = 0
+                     OPS = ZERO
+                     S1 = SECOND( )
+  610                CONTINUE
+                     CALL SCOPY( N, D, 1, RWORK, 1 )
+                     CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
+                     CALL SLASET( 'Full', N, N, ZERO, ONE, ZRE, LDA )
+                     CALL IMTQL2( LDA, N, RWORK, RWORK( LDA+1 ), ZRE,
+     $                            IINFO )
+                     IF( IINFO.NE.0 ) THEN
+                        WRITE( NOUT, FMT = 9997 )SUBNAM( 12 ), IINFO, N,
+     $                     ITYPE, IPAR, IOLDSD
+                        INFO = ABS( IINFO )
+                        GO TO 640
+                     END IF
+                     CALL HTRIBK( LDA, N, URE, UIM, TAURE, N, ZRE, ZIM )
+                     S2 = SECOND( )
+                     TIME = S2 - S1
+                     IC = IC + 1
+                     IF( TIME.LT.TIMMIN )
+     $                  GO TO 610
+*
+*                    Subtract the time used in copying
+*
+                     S1 = SECOND( )
+                     DO 620 J = 1, IC
+                        CALL SCOPY( N, D, 1, RWORK, 1 )
+                        CALL SCOPY( N-1, E, 1, RWORK( LDA+1 ), 1 )
+                        CALL SLASET( 'Full', N, N, ZERO, ONE, ZRE, LDA )
+  620                CONTINUE
+                     S2 = SECOND( )
+                     UNTIME = S2 - S1
+*
+                     TIMES( IPAR, ITYPE, IN, 12 ) = MAX( TIME-UNTIME,
+     $                  ZERO ) / REAL( IC )
+                     OPCNTS( IPAR, ITYPE, IN, 12 ) = OPS / REAL( IC )
+                  ELSE
+                     OPCNTS( IPAR, ITYPE, IN, 12 ) = OPCNTS( LASTL,
+     $                  ITYPE, IN, 12 )
+                     TIMES( IPAR, ITYPE, IN, 12 ) = TIMES( LASTL, ITYPE,
+     $                  IN, 12 )
+                  END IF
+  630          CONTINUE
             END IF
 *
-  610    CONTINUE
-  620 CONTINUE
+  640    CONTINUE
+  650 CONTINUE
 *
 *-----------------------------------------------------------------------
 *
 *     Print a table of results for each timed routine.
 *
-      DO 630 ISUB = 1, NSUBS
+      DO 660 ISUB = 1, NSUBS
          IF( TIMSUB( ISUB ) ) THEN
             CALL SPRTBE( SUBNAM( ISUB ), MTYPES, DOTYPE, NSIZES, NN,
      $                   INPARM( ISUB ), PNAMES, NPARMS, LDAS, NNB,
@@ -1166,7 +1229,7 @@
      $                   LDO2, TIMES( 1, 1, 1, ISUB ), LDT1, LDT2,
      $                   RWORK, LLWORK, NOUT )
          END IF
-  630 CONTINUE
+  660 CONTINUE
 *
  9997 FORMAT( ' CTIM22: ', A, ' returned INFO=', I6, '.', / 9X, 'N=',
      $      I6, ', ITYPE=', I6, ', IPAR=', I6, ', ISEED=(',
